/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Intrinsic Function Source Fragment                                         *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_IR_INTRINSIC_HEXAGON_ENUMS_H
#define LLVM_IR_INTRINSIC_HEXAGON_ENUMS_H
namespace llvm::Intrinsic {
enum HEXAGONIntrinsics : unsigned {
// Enum values for intrinsics.
    hexagon_A2_abs = 3881,                            // llvm.hexagon.A2.abs
    hexagon_A2_absp,                           // llvm.hexagon.A2.absp
    hexagon_A2_abssat,                         // llvm.hexagon.A2.abssat
    hexagon_A2_add,                            // llvm.hexagon.A2.add
    hexagon_A2_addh_h16_hh,                    // llvm.hexagon.A2.addh.h16.hh
    hexagon_A2_addh_h16_hl,                    // llvm.hexagon.A2.addh.h16.hl
    hexagon_A2_addh_h16_lh,                    // llvm.hexagon.A2.addh.h16.lh
    hexagon_A2_addh_h16_ll,                    // llvm.hexagon.A2.addh.h16.ll
    hexagon_A2_addh_h16_sat_hh,                // llvm.hexagon.A2.addh.h16.sat.hh
    hexagon_A2_addh_h16_sat_hl,                // llvm.hexagon.A2.addh.h16.sat.hl
    hexagon_A2_addh_h16_sat_lh,                // llvm.hexagon.A2.addh.h16.sat.lh
    hexagon_A2_addh_h16_sat_ll,                // llvm.hexagon.A2.addh.h16.sat.ll
    hexagon_A2_addh_l16_hl,                    // llvm.hexagon.A2.addh.l16.hl
    hexagon_A2_addh_l16_ll,                    // llvm.hexagon.A2.addh.l16.ll
    hexagon_A2_addh_l16_sat_hl,                // llvm.hexagon.A2.addh.l16.sat.hl
    hexagon_A2_addh_l16_sat_ll,                // llvm.hexagon.A2.addh.l16.sat.ll
    hexagon_A2_addi,                           // llvm.hexagon.A2.addi
    hexagon_A2_addp,                           // llvm.hexagon.A2.addp
    hexagon_A2_addpsat,                        // llvm.hexagon.A2.addpsat
    hexagon_A2_addsat,                         // llvm.hexagon.A2.addsat
    hexagon_A2_addsp,                          // llvm.hexagon.A2.addsp
    hexagon_A2_and,                            // llvm.hexagon.A2.and
    hexagon_A2_andir,                          // llvm.hexagon.A2.andir
    hexagon_A2_andp,                           // llvm.hexagon.A2.andp
    hexagon_A2_aslh,                           // llvm.hexagon.A2.aslh
    hexagon_A2_asrh,                           // llvm.hexagon.A2.asrh
    hexagon_A2_combine_hh,                     // llvm.hexagon.A2.combine.hh
    hexagon_A2_combine_hl,                     // llvm.hexagon.A2.combine.hl
    hexagon_A2_combine_lh,                     // llvm.hexagon.A2.combine.lh
    hexagon_A2_combine_ll,                     // llvm.hexagon.A2.combine.ll
    hexagon_A2_combineii,                      // llvm.hexagon.A2.combineii
    hexagon_A2_combinew,                       // llvm.hexagon.A2.combinew
    hexagon_A2_max,                            // llvm.hexagon.A2.max
    hexagon_A2_maxp,                           // llvm.hexagon.A2.maxp
    hexagon_A2_maxu,                           // llvm.hexagon.A2.maxu
    hexagon_A2_maxup,                          // llvm.hexagon.A2.maxup
    hexagon_A2_min,                            // llvm.hexagon.A2.min
    hexagon_A2_minp,                           // llvm.hexagon.A2.minp
    hexagon_A2_minu,                           // llvm.hexagon.A2.minu
    hexagon_A2_minup,                          // llvm.hexagon.A2.minup
    hexagon_A2_neg,                            // llvm.hexagon.A2.neg
    hexagon_A2_negp,                           // llvm.hexagon.A2.negp
    hexagon_A2_negsat,                         // llvm.hexagon.A2.negsat
    hexagon_A2_not,                            // llvm.hexagon.A2.not
    hexagon_A2_notp,                           // llvm.hexagon.A2.notp
    hexagon_A2_or,                             // llvm.hexagon.A2.or
    hexagon_A2_orir,                           // llvm.hexagon.A2.orir
    hexagon_A2_orp,                            // llvm.hexagon.A2.orp
    hexagon_A2_roundsat,                       // llvm.hexagon.A2.roundsat
    hexagon_A2_sat,                            // llvm.hexagon.A2.sat
    hexagon_A2_satb,                           // llvm.hexagon.A2.satb
    hexagon_A2_sath,                           // llvm.hexagon.A2.sath
    hexagon_A2_satub,                          // llvm.hexagon.A2.satub
    hexagon_A2_satuh,                          // llvm.hexagon.A2.satuh
    hexagon_A2_sub,                            // llvm.hexagon.A2.sub
    hexagon_A2_subh_h16_hh,                    // llvm.hexagon.A2.subh.h16.hh
    hexagon_A2_subh_h16_hl,                    // llvm.hexagon.A2.subh.h16.hl
    hexagon_A2_subh_h16_lh,                    // llvm.hexagon.A2.subh.h16.lh
    hexagon_A2_subh_h16_ll,                    // llvm.hexagon.A2.subh.h16.ll
    hexagon_A2_subh_h16_sat_hh,                // llvm.hexagon.A2.subh.h16.sat.hh
    hexagon_A2_subh_h16_sat_hl,                // llvm.hexagon.A2.subh.h16.sat.hl
    hexagon_A2_subh_h16_sat_lh,                // llvm.hexagon.A2.subh.h16.sat.lh
    hexagon_A2_subh_h16_sat_ll,                // llvm.hexagon.A2.subh.h16.sat.ll
    hexagon_A2_subh_l16_hl,                    // llvm.hexagon.A2.subh.l16.hl
    hexagon_A2_subh_l16_ll,                    // llvm.hexagon.A2.subh.l16.ll
    hexagon_A2_subh_l16_sat_hl,                // llvm.hexagon.A2.subh.l16.sat.hl
    hexagon_A2_subh_l16_sat_ll,                // llvm.hexagon.A2.subh.l16.sat.ll
    hexagon_A2_subp,                           // llvm.hexagon.A2.subp
    hexagon_A2_subri,                          // llvm.hexagon.A2.subri
    hexagon_A2_subsat,                         // llvm.hexagon.A2.subsat
    hexagon_A2_svaddh,                         // llvm.hexagon.A2.svaddh
    hexagon_A2_svaddhs,                        // llvm.hexagon.A2.svaddhs
    hexagon_A2_svadduhs,                       // llvm.hexagon.A2.svadduhs
    hexagon_A2_svavgh,                         // llvm.hexagon.A2.svavgh
    hexagon_A2_svavghs,                        // llvm.hexagon.A2.svavghs
    hexagon_A2_svnavgh,                        // llvm.hexagon.A2.svnavgh
    hexagon_A2_svsubh,                         // llvm.hexagon.A2.svsubh
    hexagon_A2_svsubhs,                        // llvm.hexagon.A2.svsubhs
    hexagon_A2_svsubuhs,                       // llvm.hexagon.A2.svsubuhs
    hexagon_A2_swiz,                           // llvm.hexagon.A2.swiz
    hexagon_A2_sxtb,                           // llvm.hexagon.A2.sxtb
    hexagon_A2_sxth,                           // llvm.hexagon.A2.sxth
    hexagon_A2_sxtw,                           // llvm.hexagon.A2.sxtw
    hexagon_A2_tfr,                            // llvm.hexagon.A2.tfr
    hexagon_A2_tfrih,                          // llvm.hexagon.A2.tfrih
    hexagon_A2_tfril,                          // llvm.hexagon.A2.tfril
    hexagon_A2_tfrp,                           // llvm.hexagon.A2.tfrp
    hexagon_A2_tfrpi,                          // llvm.hexagon.A2.tfrpi
    hexagon_A2_tfrsi,                          // llvm.hexagon.A2.tfrsi
    hexagon_A2_vabsh,                          // llvm.hexagon.A2.vabsh
    hexagon_A2_vabshsat,                       // llvm.hexagon.A2.vabshsat
    hexagon_A2_vabsw,                          // llvm.hexagon.A2.vabsw
    hexagon_A2_vabswsat,                       // llvm.hexagon.A2.vabswsat
    hexagon_A2_vaddb_map,                      // llvm.hexagon.A2.vaddb.map
    hexagon_A2_vaddh,                          // llvm.hexagon.A2.vaddh
    hexagon_A2_vaddhs,                         // llvm.hexagon.A2.vaddhs
    hexagon_A2_vaddub,                         // llvm.hexagon.A2.vaddub
    hexagon_A2_vaddubs,                        // llvm.hexagon.A2.vaddubs
    hexagon_A2_vadduhs,                        // llvm.hexagon.A2.vadduhs
    hexagon_A2_vaddw,                          // llvm.hexagon.A2.vaddw
    hexagon_A2_vaddws,                         // llvm.hexagon.A2.vaddws
    hexagon_A2_vavgh,                          // llvm.hexagon.A2.vavgh
    hexagon_A2_vavghcr,                        // llvm.hexagon.A2.vavghcr
    hexagon_A2_vavghr,                         // llvm.hexagon.A2.vavghr
    hexagon_A2_vavgub,                         // llvm.hexagon.A2.vavgub
    hexagon_A2_vavgubr,                        // llvm.hexagon.A2.vavgubr
    hexagon_A2_vavguh,                         // llvm.hexagon.A2.vavguh
    hexagon_A2_vavguhr,                        // llvm.hexagon.A2.vavguhr
    hexagon_A2_vavguw,                         // llvm.hexagon.A2.vavguw
    hexagon_A2_vavguwr,                        // llvm.hexagon.A2.vavguwr
    hexagon_A2_vavgw,                          // llvm.hexagon.A2.vavgw
    hexagon_A2_vavgwcr,                        // llvm.hexagon.A2.vavgwcr
    hexagon_A2_vavgwr,                         // llvm.hexagon.A2.vavgwr
    hexagon_A2_vcmpbeq,                        // llvm.hexagon.A2.vcmpbeq
    hexagon_A2_vcmpbgtu,                       // llvm.hexagon.A2.vcmpbgtu
    hexagon_A2_vcmpheq,                        // llvm.hexagon.A2.vcmpheq
    hexagon_A2_vcmphgt,                        // llvm.hexagon.A2.vcmphgt
    hexagon_A2_vcmphgtu,                       // llvm.hexagon.A2.vcmphgtu
    hexagon_A2_vcmpweq,                        // llvm.hexagon.A2.vcmpweq
    hexagon_A2_vcmpwgt,                        // llvm.hexagon.A2.vcmpwgt
    hexagon_A2_vcmpwgtu,                       // llvm.hexagon.A2.vcmpwgtu
    hexagon_A2_vconj,                          // llvm.hexagon.A2.vconj
    hexagon_A2_vmaxb,                          // llvm.hexagon.A2.vmaxb
    hexagon_A2_vmaxh,                          // llvm.hexagon.A2.vmaxh
    hexagon_A2_vmaxub,                         // llvm.hexagon.A2.vmaxub
    hexagon_A2_vmaxuh,                         // llvm.hexagon.A2.vmaxuh
    hexagon_A2_vmaxuw,                         // llvm.hexagon.A2.vmaxuw
    hexagon_A2_vmaxw,                          // llvm.hexagon.A2.vmaxw
    hexagon_A2_vminb,                          // llvm.hexagon.A2.vminb
    hexagon_A2_vminh,                          // llvm.hexagon.A2.vminh
    hexagon_A2_vminub,                         // llvm.hexagon.A2.vminub
    hexagon_A2_vminuh,                         // llvm.hexagon.A2.vminuh
    hexagon_A2_vminuw,                         // llvm.hexagon.A2.vminuw
    hexagon_A2_vminw,                          // llvm.hexagon.A2.vminw
    hexagon_A2_vnavgh,                         // llvm.hexagon.A2.vnavgh
    hexagon_A2_vnavghcr,                       // llvm.hexagon.A2.vnavghcr
    hexagon_A2_vnavghr,                        // llvm.hexagon.A2.vnavghr
    hexagon_A2_vnavgw,                         // llvm.hexagon.A2.vnavgw
    hexagon_A2_vnavgwcr,                       // llvm.hexagon.A2.vnavgwcr
    hexagon_A2_vnavgwr,                        // llvm.hexagon.A2.vnavgwr
    hexagon_A2_vraddub,                        // llvm.hexagon.A2.vraddub
    hexagon_A2_vraddub_acc,                    // llvm.hexagon.A2.vraddub.acc
    hexagon_A2_vrsadub,                        // llvm.hexagon.A2.vrsadub
    hexagon_A2_vrsadub_acc,                    // llvm.hexagon.A2.vrsadub.acc
    hexagon_A2_vsubb_map,                      // llvm.hexagon.A2.vsubb.map
    hexagon_A2_vsubh,                          // llvm.hexagon.A2.vsubh
    hexagon_A2_vsubhs,                         // llvm.hexagon.A2.vsubhs
    hexagon_A2_vsubub,                         // llvm.hexagon.A2.vsubub
    hexagon_A2_vsububs,                        // llvm.hexagon.A2.vsububs
    hexagon_A2_vsubuhs,                        // llvm.hexagon.A2.vsubuhs
    hexagon_A2_vsubw,                          // llvm.hexagon.A2.vsubw
    hexagon_A2_vsubws,                         // llvm.hexagon.A2.vsubws
    hexagon_A2_xor,                            // llvm.hexagon.A2.xor
    hexagon_A2_xorp,                           // llvm.hexagon.A2.xorp
    hexagon_A2_zxtb,                           // llvm.hexagon.A2.zxtb
    hexagon_A2_zxth,                           // llvm.hexagon.A2.zxth
    hexagon_A4_andn,                           // llvm.hexagon.A4.andn
    hexagon_A4_andnp,                          // llvm.hexagon.A4.andnp
    hexagon_A4_bitsplit,                       // llvm.hexagon.A4.bitsplit
    hexagon_A4_bitspliti,                      // llvm.hexagon.A4.bitspliti
    hexagon_A4_boundscheck,                    // llvm.hexagon.A4.boundscheck
    hexagon_A4_cmpbeq,                         // llvm.hexagon.A4.cmpbeq
    hexagon_A4_cmpbeqi,                        // llvm.hexagon.A4.cmpbeqi
    hexagon_A4_cmpbgt,                         // llvm.hexagon.A4.cmpbgt
    hexagon_A4_cmpbgti,                        // llvm.hexagon.A4.cmpbgti
    hexagon_A4_cmpbgtu,                        // llvm.hexagon.A4.cmpbgtu
    hexagon_A4_cmpbgtui,                       // llvm.hexagon.A4.cmpbgtui
    hexagon_A4_cmpheq,                         // llvm.hexagon.A4.cmpheq
    hexagon_A4_cmpheqi,                        // llvm.hexagon.A4.cmpheqi
    hexagon_A4_cmphgt,                         // llvm.hexagon.A4.cmphgt
    hexagon_A4_cmphgti,                        // llvm.hexagon.A4.cmphgti
    hexagon_A4_cmphgtu,                        // llvm.hexagon.A4.cmphgtu
    hexagon_A4_cmphgtui,                       // llvm.hexagon.A4.cmphgtui
    hexagon_A4_combineir,                      // llvm.hexagon.A4.combineir
    hexagon_A4_combineri,                      // llvm.hexagon.A4.combineri
    hexagon_A4_cround_ri,                      // llvm.hexagon.A4.cround.ri
    hexagon_A4_cround_rr,                      // llvm.hexagon.A4.cround.rr
    hexagon_A4_modwrapu,                       // llvm.hexagon.A4.modwrapu
    hexagon_A4_orn,                            // llvm.hexagon.A4.orn
    hexagon_A4_ornp,                           // llvm.hexagon.A4.ornp
    hexagon_A4_rcmpeq,                         // llvm.hexagon.A4.rcmpeq
    hexagon_A4_rcmpeqi,                        // llvm.hexagon.A4.rcmpeqi
    hexagon_A4_rcmpneq,                        // llvm.hexagon.A4.rcmpneq
    hexagon_A4_rcmpneqi,                       // llvm.hexagon.A4.rcmpneqi
    hexagon_A4_round_ri,                       // llvm.hexagon.A4.round.ri
    hexagon_A4_round_ri_sat,                   // llvm.hexagon.A4.round.ri.sat
    hexagon_A4_round_rr,                       // llvm.hexagon.A4.round.rr
    hexagon_A4_round_rr_sat,                   // llvm.hexagon.A4.round.rr.sat
    hexagon_A4_tlbmatch,                       // llvm.hexagon.A4.tlbmatch
    hexagon_A4_vcmpbeq_any,                    // llvm.hexagon.A4.vcmpbeq.any
    hexagon_A4_vcmpbeqi,                       // llvm.hexagon.A4.vcmpbeqi
    hexagon_A4_vcmpbgt,                        // llvm.hexagon.A4.vcmpbgt
    hexagon_A4_vcmpbgti,                       // llvm.hexagon.A4.vcmpbgti
    hexagon_A4_vcmpbgtui,                      // llvm.hexagon.A4.vcmpbgtui
    hexagon_A4_vcmpheqi,                       // llvm.hexagon.A4.vcmpheqi
    hexagon_A4_vcmphgti,                       // llvm.hexagon.A4.vcmphgti
    hexagon_A4_vcmphgtui,                      // llvm.hexagon.A4.vcmphgtui
    hexagon_A4_vcmpweqi,                       // llvm.hexagon.A4.vcmpweqi
    hexagon_A4_vcmpwgti,                       // llvm.hexagon.A4.vcmpwgti
    hexagon_A4_vcmpwgtui,                      // llvm.hexagon.A4.vcmpwgtui
    hexagon_A4_vrmaxh,                         // llvm.hexagon.A4.vrmaxh
    hexagon_A4_vrmaxuh,                        // llvm.hexagon.A4.vrmaxuh
    hexagon_A4_vrmaxuw,                        // llvm.hexagon.A4.vrmaxuw
    hexagon_A4_vrmaxw,                         // llvm.hexagon.A4.vrmaxw
    hexagon_A4_vrminh,                         // llvm.hexagon.A4.vrminh
    hexagon_A4_vrminuh,                        // llvm.hexagon.A4.vrminuh
    hexagon_A4_vrminuw,                        // llvm.hexagon.A4.vrminuw
    hexagon_A4_vrminw,                         // llvm.hexagon.A4.vrminw
    hexagon_A5_vaddhubs,                       // llvm.hexagon.A5.vaddhubs
    hexagon_A6_vcmpbeq_notany,                 // llvm.hexagon.A6.vcmpbeq.notany
    hexagon_A7_clip,                           // llvm.hexagon.A7.clip
    hexagon_A7_croundd_ri,                     // llvm.hexagon.A7.croundd.ri
    hexagon_A7_croundd_rr,                     // llvm.hexagon.A7.croundd.rr
    hexagon_A7_vclip,                          // llvm.hexagon.A7.vclip
    hexagon_C2_all8,                           // llvm.hexagon.C2.all8
    hexagon_C2_and,                            // llvm.hexagon.C2.and
    hexagon_C2_andn,                           // llvm.hexagon.C2.andn
    hexagon_C2_any8,                           // llvm.hexagon.C2.any8
    hexagon_C2_bitsclr,                        // llvm.hexagon.C2.bitsclr
    hexagon_C2_bitsclri,                       // llvm.hexagon.C2.bitsclri
    hexagon_C2_bitsset,                        // llvm.hexagon.C2.bitsset
    hexagon_C2_cmpeq,                          // llvm.hexagon.C2.cmpeq
    hexagon_C2_cmpeqi,                         // llvm.hexagon.C2.cmpeqi
    hexagon_C2_cmpeqp,                         // llvm.hexagon.C2.cmpeqp
    hexagon_C2_cmpgei,                         // llvm.hexagon.C2.cmpgei
    hexagon_C2_cmpgeui,                        // llvm.hexagon.C2.cmpgeui
    hexagon_C2_cmpgt,                          // llvm.hexagon.C2.cmpgt
    hexagon_C2_cmpgti,                         // llvm.hexagon.C2.cmpgti
    hexagon_C2_cmpgtp,                         // llvm.hexagon.C2.cmpgtp
    hexagon_C2_cmpgtu,                         // llvm.hexagon.C2.cmpgtu
    hexagon_C2_cmpgtui,                        // llvm.hexagon.C2.cmpgtui
    hexagon_C2_cmpgtup,                        // llvm.hexagon.C2.cmpgtup
    hexagon_C2_cmplt,                          // llvm.hexagon.C2.cmplt
    hexagon_C2_cmpltu,                         // llvm.hexagon.C2.cmpltu
    hexagon_C2_mask,                           // llvm.hexagon.C2.mask
    hexagon_C2_mux,                            // llvm.hexagon.C2.mux
    hexagon_C2_muxii,                          // llvm.hexagon.C2.muxii
    hexagon_C2_muxir,                          // llvm.hexagon.C2.muxir
    hexagon_C2_muxri,                          // llvm.hexagon.C2.muxri
    hexagon_C2_not,                            // llvm.hexagon.C2.not
    hexagon_C2_or,                             // llvm.hexagon.C2.or
    hexagon_C2_orn,                            // llvm.hexagon.C2.orn
    hexagon_C2_pxfer_map,                      // llvm.hexagon.C2.pxfer.map
    hexagon_C2_tfrpr,                          // llvm.hexagon.C2.tfrpr
    hexagon_C2_tfrrp,                          // llvm.hexagon.C2.tfrrp
    hexagon_C2_vitpack,                        // llvm.hexagon.C2.vitpack
    hexagon_C2_vmux,                           // llvm.hexagon.C2.vmux
    hexagon_C2_xor,                            // llvm.hexagon.C2.xor
    hexagon_C4_and_and,                        // llvm.hexagon.C4.and.and
    hexagon_C4_and_andn,                       // llvm.hexagon.C4.and.andn
    hexagon_C4_and_or,                         // llvm.hexagon.C4.and.or
    hexagon_C4_and_orn,                        // llvm.hexagon.C4.and.orn
    hexagon_C4_cmplte,                         // llvm.hexagon.C4.cmplte
    hexagon_C4_cmpltei,                        // llvm.hexagon.C4.cmpltei
    hexagon_C4_cmplteu,                        // llvm.hexagon.C4.cmplteu
    hexagon_C4_cmplteui,                       // llvm.hexagon.C4.cmplteui
    hexagon_C4_cmpneq,                         // llvm.hexagon.C4.cmpneq
    hexagon_C4_cmpneqi,                        // llvm.hexagon.C4.cmpneqi
    hexagon_C4_fastcorner9,                    // llvm.hexagon.C4.fastcorner9
    hexagon_C4_fastcorner9_not,                // llvm.hexagon.C4.fastcorner9.not
    hexagon_C4_nbitsclr,                       // llvm.hexagon.C4.nbitsclr
    hexagon_C4_nbitsclri,                      // llvm.hexagon.C4.nbitsclri
    hexagon_C4_nbitsset,                       // llvm.hexagon.C4.nbitsset
    hexagon_C4_or_and,                         // llvm.hexagon.C4.or.and
    hexagon_C4_or_andn,                        // llvm.hexagon.C4.or.andn
    hexagon_C4_or_or,                          // llvm.hexagon.C4.or.or
    hexagon_C4_or_orn,                         // llvm.hexagon.C4.or.orn
    hexagon_F2_conv_d2df,                      // llvm.hexagon.F2.conv.d2df
    hexagon_F2_conv_d2sf,                      // llvm.hexagon.F2.conv.d2sf
    hexagon_F2_conv_df2d,                      // llvm.hexagon.F2.conv.df2d
    hexagon_F2_conv_df2d_chop,                 // llvm.hexagon.F2.conv.df2d.chop
    hexagon_F2_conv_df2sf,                     // llvm.hexagon.F2.conv.df2sf
    hexagon_F2_conv_df2ud,                     // llvm.hexagon.F2.conv.df2ud
    hexagon_F2_conv_df2ud_chop,                // llvm.hexagon.F2.conv.df2ud.chop
    hexagon_F2_conv_df2uw,                     // llvm.hexagon.F2.conv.df2uw
    hexagon_F2_conv_df2uw_chop,                // llvm.hexagon.F2.conv.df2uw.chop
    hexagon_F2_conv_df2w,                      // llvm.hexagon.F2.conv.df2w
    hexagon_F2_conv_df2w_chop,                 // llvm.hexagon.F2.conv.df2w.chop
    hexagon_F2_conv_sf2d,                      // llvm.hexagon.F2.conv.sf2d
    hexagon_F2_conv_sf2d_chop,                 // llvm.hexagon.F2.conv.sf2d.chop
    hexagon_F2_conv_sf2df,                     // llvm.hexagon.F2.conv.sf2df
    hexagon_F2_conv_sf2ud,                     // llvm.hexagon.F2.conv.sf2ud
    hexagon_F2_conv_sf2ud_chop,                // llvm.hexagon.F2.conv.sf2ud.chop
    hexagon_F2_conv_sf2uw,                     // llvm.hexagon.F2.conv.sf2uw
    hexagon_F2_conv_sf2uw_chop,                // llvm.hexagon.F2.conv.sf2uw.chop
    hexagon_F2_conv_sf2w,                      // llvm.hexagon.F2.conv.sf2w
    hexagon_F2_conv_sf2w_chop,                 // llvm.hexagon.F2.conv.sf2w.chop
    hexagon_F2_conv_ud2df,                     // llvm.hexagon.F2.conv.ud2df
    hexagon_F2_conv_ud2sf,                     // llvm.hexagon.F2.conv.ud2sf
    hexagon_F2_conv_uw2df,                     // llvm.hexagon.F2.conv.uw2df
    hexagon_F2_conv_uw2sf,                     // llvm.hexagon.F2.conv.uw2sf
    hexagon_F2_conv_w2df,                      // llvm.hexagon.F2.conv.w2df
    hexagon_F2_conv_w2sf,                      // llvm.hexagon.F2.conv.w2sf
    hexagon_F2_dfadd,                          // llvm.hexagon.F2.dfadd
    hexagon_F2_dfclass,                        // llvm.hexagon.F2.dfclass
    hexagon_F2_dfcmpeq,                        // llvm.hexagon.F2.dfcmpeq
    hexagon_F2_dfcmpge,                        // llvm.hexagon.F2.dfcmpge
    hexagon_F2_dfcmpgt,                        // llvm.hexagon.F2.dfcmpgt
    hexagon_F2_dfcmpuo,                        // llvm.hexagon.F2.dfcmpuo
    hexagon_F2_dfimm_n,                        // llvm.hexagon.F2.dfimm.n
    hexagon_F2_dfimm_p,                        // llvm.hexagon.F2.dfimm.p
    hexagon_F2_dfmax,                          // llvm.hexagon.F2.dfmax
    hexagon_F2_dfmin,                          // llvm.hexagon.F2.dfmin
    hexagon_F2_dfmpyfix,                       // llvm.hexagon.F2.dfmpyfix
    hexagon_F2_dfmpyhh,                        // llvm.hexagon.F2.dfmpyhh
    hexagon_F2_dfmpylh,                        // llvm.hexagon.F2.dfmpylh
    hexagon_F2_dfmpyll,                        // llvm.hexagon.F2.dfmpyll
    hexagon_F2_dfsub,                          // llvm.hexagon.F2.dfsub
    hexagon_F2_sfadd,                          // llvm.hexagon.F2.sfadd
    hexagon_F2_sfclass,                        // llvm.hexagon.F2.sfclass
    hexagon_F2_sfcmpeq,                        // llvm.hexagon.F2.sfcmpeq
    hexagon_F2_sfcmpge,                        // llvm.hexagon.F2.sfcmpge
    hexagon_F2_sfcmpgt,                        // llvm.hexagon.F2.sfcmpgt
    hexagon_F2_sfcmpuo,                        // llvm.hexagon.F2.sfcmpuo
    hexagon_F2_sffixupd,                       // llvm.hexagon.F2.sffixupd
    hexagon_F2_sffixupn,                       // llvm.hexagon.F2.sffixupn
    hexagon_F2_sffixupr,                       // llvm.hexagon.F2.sffixupr
    hexagon_F2_sffma,                          // llvm.hexagon.F2.sffma
    hexagon_F2_sffma_lib,                      // llvm.hexagon.F2.sffma.lib
    hexagon_F2_sffma_sc,                       // llvm.hexagon.F2.sffma.sc
    hexagon_F2_sffms,                          // llvm.hexagon.F2.sffms
    hexagon_F2_sffms_lib,                      // llvm.hexagon.F2.sffms.lib
    hexagon_F2_sfimm_n,                        // llvm.hexagon.F2.sfimm.n
    hexagon_F2_sfimm_p,                        // llvm.hexagon.F2.sfimm.p
    hexagon_F2_sfmax,                          // llvm.hexagon.F2.sfmax
    hexagon_F2_sfmin,                          // llvm.hexagon.F2.sfmin
    hexagon_F2_sfmpy,                          // llvm.hexagon.F2.sfmpy
    hexagon_F2_sfsub,                          // llvm.hexagon.F2.sfsub
    hexagon_L2_loadrb_pbr,                     // llvm.hexagon.L2.loadrb.pbr
    hexagon_L2_loadrb_pci,                     // llvm.hexagon.L2.loadrb.pci
    hexagon_L2_loadrb_pcr,                     // llvm.hexagon.L2.loadrb.pcr
    hexagon_L2_loadrd_pbr,                     // llvm.hexagon.L2.loadrd.pbr
    hexagon_L2_loadrd_pci,                     // llvm.hexagon.L2.loadrd.pci
    hexagon_L2_loadrd_pcr,                     // llvm.hexagon.L2.loadrd.pcr
    hexagon_L2_loadrh_pbr,                     // llvm.hexagon.L2.loadrh.pbr
    hexagon_L2_loadrh_pci,                     // llvm.hexagon.L2.loadrh.pci
    hexagon_L2_loadrh_pcr,                     // llvm.hexagon.L2.loadrh.pcr
    hexagon_L2_loadri_pbr,                     // llvm.hexagon.L2.loadri.pbr
    hexagon_L2_loadri_pci,                     // llvm.hexagon.L2.loadri.pci
    hexagon_L2_loadri_pcr,                     // llvm.hexagon.L2.loadri.pcr
    hexagon_L2_loadrub_pbr,                    // llvm.hexagon.L2.loadrub.pbr
    hexagon_L2_loadrub_pci,                    // llvm.hexagon.L2.loadrub.pci
    hexagon_L2_loadrub_pcr,                    // llvm.hexagon.L2.loadrub.pcr
    hexagon_L2_loadruh_pbr,                    // llvm.hexagon.L2.loadruh.pbr
    hexagon_L2_loadruh_pci,                    // llvm.hexagon.L2.loadruh.pci
    hexagon_L2_loadruh_pcr,                    // llvm.hexagon.L2.loadruh.pcr
    hexagon_L2_loadw_locked,                   // llvm.hexagon.L2.loadw.locked
    hexagon_L4_loadd_locked,                   // llvm.hexagon.L4.loadd.locked
    hexagon_M2_acci,                           // llvm.hexagon.M2.acci
    hexagon_M2_accii,                          // llvm.hexagon.M2.accii
    hexagon_M2_cmaci_s0,                       // llvm.hexagon.M2.cmaci.s0
    hexagon_M2_cmacr_s0,                       // llvm.hexagon.M2.cmacr.s0
    hexagon_M2_cmacs_s0,                       // llvm.hexagon.M2.cmacs.s0
    hexagon_M2_cmacs_s1,                       // llvm.hexagon.M2.cmacs.s1
    hexagon_M2_cmacsc_s0,                      // llvm.hexagon.M2.cmacsc.s0
    hexagon_M2_cmacsc_s1,                      // llvm.hexagon.M2.cmacsc.s1
    hexagon_M2_cmpyi_s0,                       // llvm.hexagon.M2.cmpyi.s0
    hexagon_M2_cmpyr_s0,                       // llvm.hexagon.M2.cmpyr.s0
    hexagon_M2_cmpyrs_s0,                      // llvm.hexagon.M2.cmpyrs.s0
    hexagon_M2_cmpyrs_s1,                      // llvm.hexagon.M2.cmpyrs.s1
    hexagon_M2_cmpyrsc_s0,                     // llvm.hexagon.M2.cmpyrsc.s0
    hexagon_M2_cmpyrsc_s1,                     // llvm.hexagon.M2.cmpyrsc.s1
    hexagon_M2_cmpys_s0,                       // llvm.hexagon.M2.cmpys.s0
    hexagon_M2_cmpys_s1,                       // llvm.hexagon.M2.cmpys.s1
    hexagon_M2_cmpysc_s0,                      // llvm.hexagon.M2.cmpysc.s0
    hexagon_M2_cmpysc_s1,                      // llvm.hexagon.M2.cmpysc.s1
    hexagon_M2_cnacs_s0,                       // llvm.hexagon.M2.cnacs.s0
    hexagon_M2_cnacs_s1,                       // llvm.hexagon.M2.cnacs.s1
    hexagon_M2_cnacsc_s0,                      // llvm.hexagon.M2.cnacsc.s0
    hexagon_M2_cnacsc_s1,                      // llvm.hexagon.M2.cnacsc.s1
    hexagon_M2_dpmpyss_acc_s0,                 // llvm.hexagon.M2.dpmpyss.acc.s0
    hexagon_M2_dpmpyss_nac_s0,                 // llvm.hexagon.M2.dpmpyss.nac.s0
    hexagon_M2_dpmpyss_rnd_s0,                 // llvm.hexagon.M2.dpmpyss.rnd.s0
    hexagon_M2_dpmpyss_s0,                     // llvm.hexagon.M2.dpmpyss.s0
    hexagon_M2_dpmpyuu_acc_s0,                 // llvm.hexagon.M2.dpmpyuu.acc.s0
    hexagon_M2_dpmpyuu_nac_s0,                 // llvm.hexagon.M2.dpmpyuu.nac.s0
    hexagon_M2_dpmpyuu_s0,                     // llvm.hexagon.M2.dpmpyuu.s0
    hexagon_M2_hmmpyh_rs1,                     // llvm.hexagon.M2.hmmpyh.rs1
    hexagon_M2_hmmpyh_s1,                      // llvm.hexagon.M2.hmmpyh.s1
    hexagon_M2_hmmpyl_rs1,                     // llvm.hexagon.M2.hmmpyl.rs1
    hexagon_M2_hmmpyl_s1,                      // llvm.hexagon.M2.hmmpyl.s1
    hexagon_M2_maci,                           // llvm.hexagon.M2.maci
    hexagon_M2_macsin,                         // llvm.hexagon.M2.macsin
    hexagon_M2_macsip,                         // llvm.hexagon.M2.macsip
    hexagon_M2_mmachs_rs0,                     // llvm.hexagon.M2.mmachs.rs0
    hexagon_M2_mmachs_rs1,                     // llvm.hexagon.M2.mmachs.rs1
    hexagon_M2_mmachs_s0,                      // llvm.hexagon.M2.mmachs.s0
    hexagon_M2_mmachs_s1,                      // llvm.hexagon.M2.mmachs.s1
    hexagon_M2_mmacls_rs0,                     // llvm.hexagon.M2.mmacls.rs0
    hexagon_M2_mmacls_rs1,                     // llvm.hexagon.M2.mmacls.rs1
    hexagon_M2_mmacls_s0,                      // llvm.hexagon.M2.mmacls.s0
    hexagon_M2_mmacls_s1,                      // llvm.hexagon.M2.mmacls.s1
    hexagon_M2_mmacuhs_rs0,                    // llvm.hexagon.M2.mmacuhs.rs0
    hexagon_M2_mmacuhs_rs1,                    // llvm.hexagon.M2.mmacuhs.rs1
    hexagon_M2_mmacuhs_s0,                     // llvm.hexagon.M2.mmacuhs.s0
    hexagon_M2_mmacuhs_s1,                     // llvm.hexagon.M2.mmacuhs.s1
    hexagon_M2_mmaculs_rs0,                    // llvm.hexagon.M2.mmaculs.rs0
    hexagon_M2_mmaculs_rs1,                    // llvm.hexagon.M2.mmaculs.rs1
    hexagon_M2_mmaculs_s0,                     // llvm.hexagon.M2.mmaculs.s0
    hexagon_M2_mmaculs_s1,                     // llvm.hexagon.M2.mmaculs.s1
    hexagon_M2_mmpyh_rs0,                      // llvm.hexagon.M2.mmpyh.rs0
    hexagon_M2_mmpyh_rs1,                      // llvm.hexagon.M2.mmpyh.rs1
    hexagon_M2_mmpyh_s0,                       // llvm.hexagon.M2.mmpyh.s0
    hexagon_M2_mmpyh_s1,                       // llvm.hexagon.M2.mmpyh.s1
    hexagon_M2_mmpyl_rs0,                      // llvm.hexagon.M2.mmpyl.rs0
    hexagon_M2_mmpyl_rs1,                      // llvm.hexagon.M2.mmpyl.rs1
    hexagon_M2_mmpyl_s0,                       // llvm.hexagon.M2.mmpyl.s0
    hexagon_M2_mmpyl_s1,                       // llvm.hexagon.M2.mmpyl.s1
    hexagon_M2_mmpyuh_rs0,                     // llvm.hexagon.M2.mmpyuh.rs0
    hexagon_M2_mmpyuh_rs1,                     // llvm.hexagon.M2.mmpyuh.rs1
    hexagon_M2_mmpyuh_s0,                      // llvm.hexagon.M2.mmpyuh.s0
    hexagon_M2_mmpyuh_s1,                      // llvm.hexagon.M2.mmpyuh.s1
    hexagon_M2_mmpyul_rs0,                     // llvm.hexagon.M2.mmpyul.rs0
    hexagon_M2_mmpyul_rs1,                     // llvm.hexagon.M2.mmpyul.rs1
    hexagon_M2_mmpyul_s0,                      // llvm.hexagon.M2.mmpyul.s0
    hexagon_M2_mmpyul_s1,                      // llvm.hexagon.M2.mmpyul.s1
    hexagon_M2_mnaci,                          // llvm.hexagon.M2.mnaci
    hexagon_M2_mpy_acc_hh_s0,                  // llvm.hexagon.M2.mpy.acc.hh.s0
    hexagon_M2_mpy_acc_hh_s1,                  // llvm.hexagon.M2.mpy.acc.hh.s1
    hexagon_M2_mpy_acc_hl_s0,                  // llvm.hexagon.M2.mpy.acc.hl.s0
    hexagon_M2_mpy_acc_hl_s1,                  // llvm.hexagon.M2.mpy.acc.hl.s1
    hexagon_M2_mpy_acc_lh_s0,                  // llvm.hexagon.M2.mpy.acc.lh.s0
    hexagon_M2_mpy_acc_lh_s1,                  // llvm.hexagon.M2.mpy.acc.lh.s1
    hexagon_M2_mpy_acc_ll_s0,                  // llvm.hexagon.M2.mpy.acc.ll.s0
    hexagon_M2_mpy_acc_ll_s1,                  // llvm.hexagon.M2.mpy.acc.ll.s1
    hexagon_M2_mpy_acc_sat_hh_s0,              // llvm.hexagon.M2.mpy.acc.sat.hh.s0
    hexagon_M2_mpy_acc_sat_hh_s1,              // llvm.hexagon.M2.mpy.acc.sat.hh.s1
    hexagon_M2_mpy_acc_sat_hl_s0,              // llvm.hexagon.M2.mpy.acc.sat.hl.s0
    hexagon_M2_mpy_acc_sat_hl_s1,              // llvm.hexagon.M2.mpy.acc.sat.hl.s1
    hexagon_M2_mpy_acc_sat_lh_s0,              // llvm.hexagon.M2.mpy.acc.sat.lh.s0
    hexagon_M2_mpy_acc_sat_lh_s1,              // llvm.hexagon.M2.mpy.acc.sat.lh.s1
    hexagon_M2_mpy_acc_sat_ll_s0,              // llvm.hexagon.M2.mpy.acc.sat.ll.s0
    hexagon_M2_mpy_acc_sat_ll_s1,              // llvm.hexagon.M2.mpy.acc.sat.ll.s1
    hexagon_M2_mpy_hh_s0,                      // llvm.hexagon.M2.mpy.hh.s0
    hexagon_M2_mpy_hh_s1,                      // llvm.hexagon.M2.mpy.hh.s1
    hexagon_M2_mpy_hl_s0,                      // llvm.hexagon.M2.mpy.hl.s0
    hexagon_M2_mpy_hl_s1,                      // llvm.hexagon.M2.mpy.hl.s1
    hexagon_M2_mpy_lh_s0,                      // llvm.hexagon.M2.mpy.lh.s0
    hexagon_M2_mpy_lh_s1,                      // llvm.hexagon.M2.mpy.lh.s1
    hexagon_M2_mpy_ll_s0,                      // llvm.hexagon.M2.mpy.ll.s0
    hexagon_M2_mpy_ll_s1,                      // llvm.hexagon.M2.mpy.ll.s1
    hexagon_M2_mpy_nac_hh_s0,                  // llvm.hexagon.M2.mpy.nac.hh.s0
    hexagon_M2_mpy_nac_hh_s1,                  // llvm.hexagon.M2.mpy.nac.hh.s1
    hexagon_M2_mpy_nac_hl_s0,                  // llvm.hexagon.M2.mpy.nac.hl.s0
    hexagon_M2_mpy_nac_hl_s1,                  // llvm.hexagon.M2.mpy.nac.hl.s1
    hexagon_M2_mpy_nac_lh_s0,                  // llvm.hexagon.M2.mpy.nac.lh.s0
    hexagon_M2_mpy_nac_lh_s1,                  // llvm.hexagon.M2.mpy.nac.lh.s1
    hexagon_M2_mpy_nac_ll_s0,                  // llvm.hexagon.M2.mpy.nac.ll.s0
    hexagon_M2_mpy_nac_ll_s1,                  // llvm.hexagon.M2.mpy.nac.ll.s1
    hexagon_M2_mpy_nac_sat_hh_s0,              // llvm.hexagon.M2.mpy.nac.sat.hh.s0
    hexagon_M2_mpy_nac_sat_hh_s1,              // llvm.hexagon.M2.mpy.nac.sat.hh.s1
    hexagon_M2_mpy_nac_sat_hl_s0,              // llvm.hexagon.M2.mpy.nac.sat.hl.s0
    hexagon_M2_mpy_nac_sat_hl_s1,              // llvm.hexagon.M2.mpy.nac.sat.hl.s1
    hexagon_M2_mpy_nac_sat_lh_s0,              // llvm.hexagon.M2.mpy.nac.sat.lh.s0
    hexagon_M2_mpy_nac_sat_lh_s1,              // llvm.hexagon.M2.mpy.nac.sat.lh.s1
    hexagon_M2_mpy_nac_sat_ll_s0,              // llvm.hexagon.M2.mpy.nac.sat.ll.s0
    hexagon_M2_mpy_nac_sat_ll_s1,              // llvm.hexagon.M2.mpy.nac.sat.ll.s1
    hexagon_M2_mpy_rnd_hh_s0,                  // llvm.hexagon.M2.mpy.rnd.hh.s0
    hexagon_M2_mpy_rnd_hh_s1,                  // llvm.hexagon.M2.mpy.rnd.hh.s1
    hexagon_M2_mpy_rnd_hl_s0,                  // llvm.hexagon.M2.mpy.rnd.hl.s0
    hexagon_M2_mpy_rnd_hl_s1,                  // llvm.hexagon.M2.mpy.rnd.hl.s1
    hexagon_M2_mpy_rnd_lh_s0,                  // llvm.hexagon.M2.mpy.rnd.lh.s0
    hexagon_M2_mpy_rnd_lh_s1,                  // llvm.hexagon.M2.mpy.rnd.lh.s1
    hexagon_M2_mpy_rnd_ll_s0,                  // llvm.hexagon.M2.mpy.rnd.ll.s0
    hexagon_M2_mpy_rnd_ll_s1,                  // llvm.hexagon.M2.mpy.rnd.ll.s1
    hexagon_M2_mpy_sat_hh_s0,                  // llvm.hexagon.M2.mpy.sat.hh.s0
    hexagon_M2_mpy_sat_hh_s1,                  // llvm.hexagon.M2.mpy.sat.hh.s1
    hexagon_M2_mpy_sat_hl_s0,                  // llvm.hexagon.M2.mpy.sat.hl.s0
    hexagon_M2_mpy_sat_hl_s1,                  // llvm.hexagon.M2.mpy.sat.hl.s1
    hexagon_M2_mpy_sat_lh_s0,                  // llvm.hexagon.M2.mpy.sat.lh.s0
    hexagon_M2_mpy_sat_lh_s1,                  // llvm.hexagon.M2.mpy.sat.lh.s1
    hexagon_M2_mpy_sat_ll_s0,                  // llvm.hexagon.M2.mpy.sat.ll.s0
    hexagon_M2_mpy_sat_ll_s1,                  // llvm.hexagon.M2.mpy.sat.ll.s1
    hexagon_M2_mpy_sat_rnd_hh_s0,              // llvm.hexagon.M2.mpy.sat.rnd.hh.s0
    hexagon_M2_mpy_sat_rnd_hh_s1,              // llvm.hexagon.M2.mpy.sat.rnd.hh.s1
    hexagon_M2_mpy_sat_rnd_hl_s0,              // llvm.hexagon.M2.mpy.sat.rnd.hl.s0
    hexagon_M2_mpy_sat_rnd_hl_s1,              // llvm.hexagon.M2.mpy.sat.rnd.hl.s1
    hexagon_M2_mpy_sat_rnd_lh_s0,              // llvm.hexagon.M2.mpy.sat.rnd.lh.s0
    hexagon_M2_mpy_sat_rnd_lh_s1,              // llvm.hexagon.M2.mpy.sat.rnd.lh.s1
    hexagon_M2_mpy_sat_rnd_ll_s0,              // llvm.hexagon.M2.mpy.sat.rnd.ll.s0
    hexagon_M2_mpy_sat_rnd_ll_s1,              // llvm.hexagon.M2.mpy.sat.rnd.ll.s1
    hexagon_M2_mpy_up,                         // llvm.hexagon.M2.mpy.up
    hexagon_M2_mpy_up_s1,                      // llvm.hexagon.M2.mpy.up.s1
    hexagon_M2_mpy_up_s1_sat,                  // llvm.hexagon.M2.mpy.up.s1.sat
    hexagon_M2_mpyd_acc_hh_s0,                 // llvm.hexagon.M2.mpyd.acc.hh.s0
    hexagon_M2_mpyd_acc_hh_s1,                 // llvm.hexagon.M2.mpyd.acc.hh.s1
    hexagon_M2_mpyd_acc_hl_s0,                 // llvm.hexagon.M2.mpyd.acc.hl.s0
    hexagon_M2_mpyd_acc_hl_s1,                 // llvm.hexagon.M2.mpyd.acc.hl.s1
    hexagon_M2_mpyd_acc_lh_s0,                 // llvm.hexagon.M2.mpyd.acc.lh.s0
    hexagon_M2_mpyd_acc_lh_s1,                 // llvm.hexagon.M2.mpyd.acc.lh.s1
    hexagon_M2_mpyd_acc_ll_s0,                 // llvm.hexagon.M2.mpyd.acc.ll.s0
    hexagon_M2_mpyd_acc_ll_s1,                 // llvm.hexagon.M2.mpyd.acc.ll.s1
    hexagon_M2_mpyd_hh_s0,                     // llvm.hexagon.M2.mpyd.hh.s0
    hexagon_M2_mpyd_hh_s1,                     // llvm.hexagon.M2.mpyd.hh.s1
    hexagon_M2_mpyd_hl_s0,                     // llvm.hexagon.M2.mpyd.hl.s0
    hexagon_M2_mpyd_hl_s1,                     // llvm.hexagon.M2.mpyd.hl.s1
    hexagon_M2_mpyd_lh_s0,                     // llvm.hexagon.M2.mpyd.lh.s0
    hexagon_M2_mpyd_lh_s1,                     // llvm.hexagon.M2.mpyd.lh.s1
    hexagon_M2_mpyd_ll_s0,                     // llvm.hexagon.M2.mpyd.ll.s0
    hexagon_M2_mpyd_ll_s1,                     // llvm.hexagon.M2.mpyd.ll.s1
    hexagon_M2_mpyd_nac_hh_s0,                 // llvm.hexagon.M2.mpyd.nac.hh.s0
    hexagon_M2_mpyd_nac_hh_s1,                 // llvm.hexagon.M2.mpyd.nac.hh.s1
    hexagon_M2_mpyd_nac_hl_s0,                 // llvm.hexagon.M2.mpyd.nac.hl.s0
    hexagon_M2_mpyd_nac_hl_s1,                 // llvm.hexagon.M2.mpyd.nac.hl.s1
    hexagon_M2_mpyd_nac_lh_s0,                 // llvm.hexagon.M2.mpyd.nac.lh.s0
    hexagon_M2_mpyd_nac_lh_s1,                 // llvm.hexagon.M2.mpyd.nac.lh.s1
    hexagon_M2_mpyd_nac_ll_s0,                 // llvm.hexagon.M2.mpyd.nac.ll.s0
    hexagon_M2_mpyd_nac_ll_s1,                 // llvm.hexagon.M2.mpyd.nac.ll.s1
    hexagon_M2_mpyd_rnd_hh_s0,                 // llvm.hexagon.M2.mpyd.rnd.hh.s0
    hexagon_M2_mpyd_rnd_hh_s1,                 // llvm.hexagon.M2.mpyd.rnd.hh.s1
    hexagon_M2_mpyd_rnd_hl_s0,                 // llvm.hexagon.M2.mpyd.rnd.hl.s0
    hexagon_M2_mpyd_rnd_hl_s1,                 // llvm.hexagon.M2.mpyd.rnd.hl.s1
    hexagon_M2_mpyd_rnd_lh_s0,                 // llvm.hexagon.M2.mpyd.rnd.lh.s0
    hexagon_M2_mpyd_rnd_lh_s1,                 // llvm.hexagon.M2.mpyd.rnd.lh.s1
    hexagon_M2_mpyd_rnd_ll_s0,                 // llvm.hexagon.M2.mpyd.rnd.ll.s0
    hexagon_M2_mpyd_rnd_ll_s1,                 // llvm.hexagon.M2.mpyd.rnd.ll.s1
    hexagon_M2_mpyi,                           // llvm.hexagon.M2.mpyi
    hexagon_M2_mpysmi,                         // llvm.hexagon.M2.mpysmi
    hexagon_M2_mpysu_up,                       // llvm.hexagon.M2.mpysu.up
    hexagon_M2_mpyu_acc_hh_s0,                 // llvm.hexagon.M2.mpyu.acc.hh.s0
    hexagon_M2_mpyu_acc_hh_s1,                 // llvm.hexagon.M2.mpyu.acc.hh.s1
    hexagon_M2_mpyu_acc_hl_s0,                 // llvm.hexagon.M2.mpyu.acc.hl.s0
    hexagon_M2_mpyu_acc_hl_s1,                 // llvm.hexagon.M2.mpyu.acc.hl.s1
    hexagon_M2_mpyu_acc_lh_s0,                 // llvm.hexagon.M2.mpyu.acc.lh.s0
    hexagon_M2_mpyu_acc_lh_s1,                 // llvm.hexagon.M2.mpyu.acc.lh.s1
    hexagon_M2_mpyu_acc_ll_s0,                 // llvm.hexagon.M2.mpyu.acc.ll.s0
    hexagon_M2_mpyu_acc_ll_s1,                 // llvm.hexagon.M2.mpyu.acc.ll.s1
    hexagon_M2_mpyu_hh_s0,                     // llvm.hexagon.M2.mpyu.hh.s0
    hexagon_M2_mpyu_hh_s1,                     // llvm.hexagon.M2.mpyu.hh.s1
    hexagon_M2_mpyu_hl_s0,                     // llvm.hexagon.M2.mpyu.hl.s0
    hexagon_M2_mpyu_hl_s1,                     // llvm.hexagon.M2.mpyu.hl.s1
    hexagon_M2_mpyu_lh_s0,                     // llvm.hexagon.M2.mpyu.lh.s0
    hexagon_M2_mpyu_lh_s1,                     // llvm.hexagon.M2.mpyu.lh.s1
    hexagon_M2_mpyu_ll_s0,                     // llvm.hexagon.M2.mpyu.ll.s0
    hexagon_M2_mpyu_ll_s1,                     // llvm.hexagon.M2.mpyu.ll.s1
    hexagon_M2_mpyu_nac_hh_s0,                 // llvm.hexagon.M2.mpyu.nac.hh.s0
    hexagon_M2_mpyu_nac_hh_s1,                 // llvm.hexagon.M2.mpyu.nac.hh.s1
    hexagon_M2_mpyu_nac_hl_s0,                 // llvm.hexagon.M2.mpyu.nac.hl.s0
    hexagon_M2_mpyu_nac_hl_s1,                 // llvm.hexagon.M2.mpyu.nac.hl.s1
    hexagon_M2_mpyu_nac_lh_s0,                 // llvm.hexagon.M2.mpyu.nac.lh.s0
    hexagon_M2_mpyu_nac_lh_s1,                 // llvm.hexagon.M2.mpyu.nac.lh.s1
    hexagon_M2_mpyu_nac_ll_s0,                 // llvm.hexagon.M2.mpyu.nac.ll.s0
    hexagon_M2_mpyu_nac_ll_s1,                 // llvm.hexagon.M2.mpyu.nac.ll.s1
    hexagon_M2_mpyu_up,                        // llvm.hexagon.M2.mpyu.up
    hexagon_M2_mpyud_acc_hh_s0,                // llvm.hexagon.M2.mpyud.acc.hh.s0
    hexagon_M2_mpyud_acc_hh_s1,                // llvm.hexagon.M2.mpyud.acc.hh.s1
    hexagon_M2_mpyud_acc_hl_s0,                // llvm.hexagon.M2.mpyud.acc.hl.s0
    hexagon_M2_mpyud_acc_hl_s1,                // llvm.hexagon.M2.mpyud.acc.hl.s1
    hexagon_M2_mpyud_acc_lh_s0,                // llvm.hexagon.M2.mpyud.acc.lh.s0
    hexagon_M2_mpyud_acc_lh_s1,                // llvm.hexagon.M2.mpyud.acc.lh.s1
    hexagon_M2_mpyud_acc_ll_s0,                // llvm.hexagon.M2.mpyud.acc.ll.s0
    hexagon_M2_mpyud_acc_ll_s1,                // llvm.hexagon.M2.mpyud.acc.ll.s1
    hexagon_M2_mpyud_hh_s0,                    // llvm.hexagon.M2.mpyud.hh.s0
    hexagon_M2_mpyud_hh_s1,                    // llvm.hexagon.M2.mpyud.hh.s1
    hexagon_M2_mpyud_hl_s0,                    // llvm.hexagon.M2.mpyud.hl.s0
    hexagon_M2_mpyud_hl_s1,                    // llvm.hexagon.M2.mpyud.hl.s1
    hexagon_M2_mpyud_lh_s0,                    // llvm.hexagon.M2.mpyud.lh.s0
    hexagon_M2_mpyud_lh_s1,                    // llvm.hexagon.M2.mpyud.lh.s1
    hexagon_M2_mpyud_ll_s0,                    // llvm.hexagon.M2.mpyud.ll.s0
    hexagon_M2_mpyud_ll_s1,                    // llvm.hexagon.M2.mpyud.ll.s1
    hexagon_M2_mpyud_nac_hh_s0,                // llvm.hexagon.M2.mpyud.nac.hh.s0
    hexagon_M2_mpyud_nac_hh_s1,                // llvm.hexagon.M2.mpyud.nac.hh.s1
    hexagon_M2_mpyud_nac_hl_s0,                // llvm.hexagon.M2.mpyud.nac.hl.s0
    hexagon_M2_mpyud_nac_hl_s1,                // llvm.hexagon.M2.mpyud.nac.hl.s1
    hexagon_M2_mpyud_nac_lh_s0,                // llvm.hexagon.M2.mpyud.nac.lh.s0
    hexagon_M2_mpyud_nac_lh_s1,                // llvm.hexagon.M2.mpyud.nac.lh.s1
    hexagon_M2_mpyud_nac_ll_s0,                // llvm.hexagon.M2.mpyud.nac.ll.s0
    hexagon_M2_mpyud_nac_ll_s1,                // llvm.hexagon.M2.mpyud.nac.ll.s1
    hexagon_M2_mpyui,                          // llvm.hexagon.M2.mpyui
    hexagon_M2_nacci,                          // llvm.hexagon.M2.nacci
    hexagon_M2_naccii,                         // llvm.hexagon.M2.naccii
    hexagon_M2_subacc,                         // llvm.hexagon.M2.subacc
    hexagon_M2_vabsdiffh,                      // llvm.hexagon.M2.vabsdiffh
    hexagon_M2_vabsdiffw,                      // llvm.hexagon.M2.vabsdiffw
    hexagon_M2_vcmac_s0_sat_i,                 // llvm.hexagon.M2.vcmac.s0.sat.i
    hexagon_M2_vcmac_s0_sat_r,                 // llvm.hexagon.M2.vcmac.s0.sat.r
    hexagon_M2_vcmpy_s0_sat_i,                 // llvm.hexagon.M2.vcmpy.s0.sat.i
    hexagon_M2_vcmpy_s0_sat_r,                 // llvm.hexagon.M2.vcmpy.s0.sat.r
    hexagon_M2_vcmpy_s1_sat_i,                 // llvm.hexagon.M2.vcmpy.s1.sat.i
    hexagon_M2_vcmpy_s1_sat_r,                 // llvm.hexagon.M2.vcmpy.s1.sat.r
    hexagon_M2_vdmacs_s0,                      // llvm.hexagon.M2.vdmacs.s0
    hexagon_M2_vdmacs_s1,                      // llvm.hexagon.M2.vdmacs.s1
    hexagon_M2_vdmpyrs_s0,                     // llvm.hexagon.M2.vdmpyrs.s0
    hexagon_M2_vdmpyrs_s1,                     // llvm.hexagon.M2.vdmpyrs.s1
    hexagon_M2_vdmpys_s0,                      // llvm.hexagon.M2.vdmpys.s0
    hexagon_M2_vdmpys_s1,                      // llvm.hexagon.M2.vdmpys.s1
    hexagon_M2_vmac2,                          // llvm.hexagon.M2.vmac2
    hexagon_M2_vmac2es,                        // llvm.hexagon.M2.vmac2es
    hexagon_M2_vmac2es_s0,                     // llvm.hexagon.M2.vmac2es.s0
    hexagon_M2_vmac2es_s1,                     // llvm.hexagon.M2.vmac2es.s1
    hexagon_M2_vmac2s_s0,                      // llvm.hexagon.M2.vmac2s.s0
    hexagon_M2_vmac2s_s1,                      // llvm.hexagon.M2.vmac2s.s1
    hexagon_M2_vmac2su_s0,                     // llvm.hexagon.M2.vmac2su.s0
    hexagon_M2_vmac2su_s1,                     // llvm.hexagon.M2.vmac2su.s1
    hexagon_M2_vmpy2es_s0,                     // llvm.hexagon.M2.vmpy2es.s0
    hexagon_M2_vmpy2es_s1,                     // llvm.hexagon.M2.vmpy2es.s1
    hexagon_M2_vmpy2s_s0,                      // llvm.hexagon.M2.vmpy2s.s0
    hexagon_M2_vmpy2s_s0pack,                  // llvm.hexagon.M2.vmpy2s.s0pack
    hexagon_M2_vmpy2s_s1,                      // llvm.hexagon.M2.vmpy2s.s1
    hexagon_M2_vmpy2s_s1pack,                  // llvm.hexagon.M2.vmpy2s.s1pack
    hexagon_M2_vmpy2su_s0,                     // llvm.hexagon.M2.vmpy2su.s0
    hexagon_M2_vmpy2su_s1,                     // llvm.hexagon.M2.vmpy2su.s1
    hexagon_M2_vraddh,                         // llvm.hexagon.M2.vraddh
    hexagon_M2_vradduh,                        // llvm.hexagon.M2.vradduh
    hexagon_M2_vrcmaci_s0,                     // llvm.hexagon.M2.vrcmaci.s0
    hexagon_M2_vrcmaci_s0c,                    // llvm.hexagon.M2.vrcmaci.s0c
    hexagon_M2_vrcmacr_s0,                     // llvm.hexagon.M2.vrcmacr.s0
    hexagon_M2_vrcmacr_s0c,                    // llvm.hexagon.M2.vrcmacr.s0c
    hexagon_M2_vrcmpyi_s0,                     // llvm.hexagon.M2.vrcmpyi.s0
    hexagon_M2_vrcmpyi_s0c,                    // llvm.hexagon.M2.vrcmpyi.s0c
    hexagon_M2_vrcmpyr_s0,                     // llvm.hexagon.M2.vrcmpyr.s0
    hexagon_M2_vrcmpyr_s0c,                    // llvm.hexagon.M2.vrcmpyr.s0c
    hexagon_M2_vrcmpys_acc_s1,                 // llvm.hexagon.M2.vrcmpys.acc.s1
    hexagon_M2_vrcmpys_s1,                     // llvm.hexagon.M2.vrcmpys.s1
    hexagon_M2_vrcmpys_s1rp,                   // llvm.hexagon.M2.vrcmpys.s1rp
    hexagon_M2_vrmac_s0,                       // llvm.hexagon.M2.vrmac.s0
    hexagon_M2_vrmpy_s0,                       // llvm.hexagon.M2.vrmpy.s0
    hexagon_M2_xor_xacc,                       // llvm.hexagon.M2.xor.xacc
    hexagon_M4_and_and,                        // llvm.hexagon.M4.and.and
    hexagon_M4_and_andn,                       // llvm.hexagon.M4.and.andn
    hexagon_M4_and_or,                         // llvm.hexagon.M4.and.or
    hexagon_M4_and_xor,                        // llvm.hexagon.M4.and.xor
    hexagon_M4_cmpyi_wh,                       // llvm.hexagon.M4.cmpyi.wh
    hexagon_M4_cmpyi_whc,                      // llvm.hexagon.M4.cmpyi.whc
    hexagon_M4_cmpyr_wh,                       // llvm.hexagon.M4.cmpyr.wh
    hexagon_M4_cmpyr_whc,                      // llvm.hexagon.M4.cmpyr.whc
    hexagon_M4_mac_up_s1_sat,                  // llvm.hexagon.M4.mac.up.s1.sat
    hexagon_M4_mpyri_addi,                     // llvm.hexagon.M4.mpyri.addi
    hexagon_M4_mpyri_addr,                     // llvm.hexagon.M4.mpyri.addr
    hexagon_M4_mpyri_addr_u2,                  // llvm.hexagon.M4.mpyri.addr.u2
    hexagon_M4_mpyrr_addi,                     // llvm.hexagon.M4.mpyrr.addi
    hexagon_M4_mpyrr_addr,                     // llvm.hexagon.M4.mpyrr.addr
    hexagon_M4_nac_up_s1_sat,                  // llvm.hexagon.M4.nac.up.s1.sat
    hexagon_M4_or_and,                         // llvm.hexagon.M4.or.and
    hexagon_M4_or_andn,                        // llvm.hexagon.M4.or.andn
    hexagon_M4_or_or,                          // llvm.hexagon.M4.or.or
    hexagon_M4_or_xor,                         // llvm.hexagon.M4.or.xor
    hexagon_M4_pmpyw,                          // llvm.hexagon.M4.pmpyw
    hexagon_M4_pmpyw_acc,                      // llvm.hexagon.M4.pmpyw.acc
    hexagon_M4_vpmpyh,                         // llvm.hexagon.M4.vpmpyh
    hexagon_M4_vpmpyh_acc,                     // llvm.hexagon.M4.vpmpyh.acc
    hexagon_M4_vrmpyeh_acc_s0,                 // llvm.hexagon.M4.vrmpyeh.acc.s0
    hexagon_M4_vrmpyeh_acc_s1,                 // llvm.hexagon.M4.vrmpyeh.acc.s1
    hexagon_M4_vrmpyeh_s0,                     // llvm.hexagon.M4.vrmpyeh.s0
    hexagon_M4_vrmpyeh_s1,                     // llvm.hexagon.M4.vrmpyeh.s1
    hexagon_M4_vrmpyoh_acc_s0,                 // llvm.hexagon.M4.vrmpyoh.acc.s0
    hexagon_M4_vrmpyoh_acc_s1,                 // llvm.hexagon.M4.vrmpyoh.acc.s1
    hexagon_M4_vrmpyoh_s0,                     // llvm.hexagon.M4.vrmpyoh.s0
    hexagon_M4_vrmpyoh_s1,                     // llvm.hexagon.M4.vrmpyoh.s1
    hexagon_M4_xor_and,                        // llvm.hexagon.M4.xor.and
    hexagon_M4_xor_andn,                       // llvm.hexagon.M4.xor.andn
    hexagon_M4_xor_or,                         // llvm.hexagon.M4.xor.or
    hexagon_M4_xor_xacc,                       // llvm.hexagon.M4.xor.xacc
    hexagon_M5_vdmacbsu,                       // llvm.hexagon.M5.vdmacbsu
    hexagon_M5_vdmpybsu,                       // llvm.hexagon.M5.vdmpybsu
    hexagon_M5_vmacbsu,                        // llvm.hexagon.M5.vmacbsu
    hexagon_M5_vmacbuu,                        // llvm.hexagon.M5.vmacbuu
    hexagon_M5_vmpybsu,                        // llvm.hexagon.M5.vmpybsu
    hexagon_M5_vmpybuu,                        // llvm.hexagon.M5.vmpybuu
    hexagon_M5_vrmacbsu,                       // llvm.hexagon.M5.vrmacbsu
    hexagon_M5_vrmacbuu,                       // llvm.hexagon.M5.vrmacbuu
    hexagon_M5_vrmpybsu,                       // llvm.hexagon.M5.vrmpybsu
    hexagon_M5_vrmpybuu,                       // llvm.hexagon.M5.vrmpybuu
    hexagon_M6_vabsdiffb,                      // llvm.hexagon.M6.vabsdiffb
    hexagon_M6_vabsdiffub,                     // llvm.hexagon.M6.vabsdiffub
    hexagon_M7_dcmpyiw,                        // llvm.hexagon.M7.dcmpyiw
    hexagon_M7_dcmpyiw_acc,                    // llvm.hexagon.M7.dcmpyiw.acc
    hexagon_M7_dcmpyiwc,                       // llvm.hexagon.M7.dcmpyiwc
    hexagon_M7_dcmpyiwc_acc,                   // llvm.hexagon.M7.dcmpyiwc.acc
    hexagon_M7_dcmpyrw,                        // llvm.hexagon.M7.dcmpyrw
    hexagon_M7_dcmpyrw_acc,                    // llvm.hexagon.M7.dcmpyrw.acc
    hexagon_M7_dcmpyrwc,                       // llvm.hexagon.M7.dcmpyrwc
    hexagon_M7_dcmpyrwc_acc,                   // llvm.hexagon.M7.dcmpyrwc.acc
    hexagon_M7_vdmpy,                          // llvm.hexagon.M7.vdmpy
    hexagon_M7_vdmpy_acc,                      // llvm.hexagon.M7.vdmpy.acc
    hexagon_M7_wcmpyiw,                        // llvm.hexagon.M7.wcmpyiw
    hexagon_M7_wcmpyiw_rnd,                    // llvm.hexagon.M7.wcmpyiw.rnd
    hexagon_M7_wcmpyiwc,                       // llvm.hexagon.M7.wcmpyiwc
    hexagon_M7_wcmpyiwc_rnd,                   // llvm.hexagon.M7.wcmpyiwc.rnd
    hexagon_M7_wcmpyrw,                        // llvm.hexagon.M7.wcmpyrw
    hexagon_M7_wcmpyrw_rnd,                    // llvm.hexagon.M7.wcmpyrw.rnd
    hexagon_M7_wcmpyrwc,                       // llvm.hexagon.M7.wcmpyrwc
    hexagon_M7_wcmpyrwc_rnd,                   // llvm.hexagon.M7.wcmpyrwc.rnd
    hexagon_S2_addasl_rrri,                    // llvm.hexagon.S2.addasl.rrri
    hexagon_S2_asl_i_p,                        // llvm.hexagon.S2.asl.i.p
    hexagon_S2_asl_i_p_acc,                    // llvm.hexagon.S2.asl.i.p.acc
    hexagon_S2_asl_i_p_and,                    // llvm.hexagon.S2.asl.i.p.and
    hexagon_S2_asl_i_p_nac,                    // llvm.hexagon.S2.asl.i.p.nac
    hexagon_S2_asl_i_p_or,                     // llvm.hexagon.S2.asl.i.p.or
    hexagon_S2_asl_i_p_xacc,                   // llvm.hexagon.S2.asl.i.p.xacc
    hexagon_S2_asl_i_r,                        // llvm.hexagon.S2.asl.i.r
    hexagon_S2_asl_i_r_acc,                    // llvm.hexagon.S2.asl.i.r.acc
    hexagon_S2_asl_i_r_and,                    // llvm.hexagon.S2.asl.i.r.and
    hexagon_S2_asl_i_r_nac,                    // llvm.hexagon.S2.asl.i.r.nac
    hexagon_S2_asl_i_r_or,                     // llvm.hexagon.S2.asl.i.r.or
    hexagon_S2_asl_i_r_sat,                    // llvm.hexagon.S2.asl.i.r.sat
    hexagon_S2_asl_i_r_xacc,                   // llvm.hexagon.S2.asl.i.r.xacc
    hexagon_S2_asl_i_vh,                       // llvm.hexagon.S2.asl.i.vh
    hexagon_S2_asl_i_vw,                       // llvm.hexagon.S2.asl.i.vw
    hexagon_S2_asl_r_p,                        // llvm.hexagon.S2.asl.r.p
    hexagon_S2_asl_r_p_acc,                    // llvm.hexagon.S2.asl.r.p.acc
    hexagon_S2_asl_r_p_and,                    // llvm.hexagon.S2.asl.r.p.and
    hexagon_S2_asl_r_p_nac,                    // llvm.hexagon.S2.asl.r.p.nac
    hexagon_S2_asl_r_p_or,                     // llvm.hexagon.S2.asl.r.p.or
    hexagon_S2_asl_r_p_xor,                    // llvm.hexagon.S2.asl.r.p.xor
    hexagon_S2_asl_r_r,                        // llvm.hexagon.S2.asl.r.r
    hexagon_S2_asl_r_r_acc,                    // llvm.hexagon.S2.asl.r.r.acc
    hexagon_S2_asl_r_r_and,                    // llvm.hexagon.S2.asl.r.r.and
    hexagon_S2_asl_r_r_nac,                    // llvm.hexagon.S2.asl.r.r.nac
    hexagon_S2_asl_r_r_or,                     // llvm.hexagon.S2.asl.r.r.or
    hexagon_S2_asl_r_r_sat,                    // llvm.hexagon.S2.asl.r.r.sat
    hexagon_S2_asl_r_vh,                       // llvm.hexagon.S2.asl.r.vh
    hexagon_S2_asl_r_vw,                       // llvm.hexagon.S2.asl.r.vw
    hexagon_S2_asr_i_p,                        // llvm.hexagon.S2.asr.i.p
    hexagon_S2_asr_i_p_acc,                    // llvm.hexagon.S2.asr.i.p.acc
    hexagon_S2_asr_i_p_and,                    // llvm.hexagon.S2.asr.i.p.and
    hexagon_S2_asr_i_p_nac,                    // llvm.hexagon.S2.asr.i.p.nac
    hexagon_S2_asr_i_p_or,                     // llvm.hexagon.S2.asr.i.p.or
    hexagon_S2_asr_i_p_rnd,                    // llvm.hexagon.S2.asr.i.p.rnd
    hexagon_S2_asr_i_p_rnd_goodsyntax,         // llvm.hexagon.S2.asr.i.p.rnd.goodsyntax
    hexagon_S2_asr_i_r,                        // llvm.hexagon.S2.asr.i.r
    hexagon_S2_asr_i_r_acc,                    // llvm.hexagon.S2.asr.i.r.acc
    hexagon_S2_asr_i_r_and,                    // llvm.hexagon.S2.asr.i.r.and
    hexagon_S2_asr_i_r_nac,                    // llvm.hexagon.S2.asr.i.r.nac
    hexagon_S2_asr_i_r_or,                     // llvm.hexagon.S2.asr.i.r.or
    hexagon_S2_asr_i_r_rnd,                    // llvm.hexagon.S2.asr.i.r.rnd
    hexagon_S2_asr_i_r_rnd_goodsyntax,         // llvm.hexagon.S2.asr.i.r.rnd.goodsyntax
    hexagon_S2_asr_i_svw_trun,                 // llvm.hexagon.S2.asr.i.svw.trun
    hexagon_S2_asr_i_vh,                       // llvm.hexagon.S2.asr.i.vh
    hexagon_S2_asr_i_vw,                       // llvm.hexagon.S2.asr.i.vw
    hexagon_S2_asr_r_p,                        // llvm.hexagon.S2.asr.r.p
    hexagon_S2_asr_r_p_acc,                    // llvm.hexagon.S2.asr.r.p.acc
    hexagon_S2_asr_r_p_and,                    // llvm.hexagon.S2.asr.r.p.and
    hexagon_S2_asr_r_p_nac,                    // llvm.hexagon.S2.asr.r.p.nac
    hexagon_S2_asr_r_p_or,                     // llvm.hexagon.S2.asr.r.p.or
    hexagon_S2_asr_r_p_xor,                    // llvm.hexagon.S2.asr.r.p.xor
    hexagon_S2_asr_r_r,                        // llvm.hexagon.S2.asr.r.r
    hexagon_S2_asr_r_r_acc,                    // llvm.hexagon.S2.asr.r.r.acc
    hexagon_S2_asr_r_r_and,                    // llvm.hexagon.S2.asr.r.r.and
    hexagon_S2_asr_r_r_nac,                    // llvm.hexagon.S2.asr.r.r.nac
    hexagon_S2_asr_r_r_or,                     // llvm.hexagon.S2.asr.r.r.or
    hexagon_S2_asr_r_r_sat,                    // llvm.hexagon.S2.asr.r.r.sat
    hexagon_S2_asr_r_svw_trun,                 // llvm.hexagon.S2.asr.r.svw.trun
    hexagon_S2_asr_r_vh,                       // llvm.hexagon.S2.asr.r.vh
    hexagon_S2_asr_r_vw,                       // llvm.hexagon.S2.asr.r.vw
    hexagon_S2_brev,                           // llvm.hexagon.S2.brev
    hexagon_S2_brevp,                          // llvm.hexagon.S2.brevp
    hexagon_S2_cl0,                            // llvm.hexagon.S2.cl0
    hexagon_S2_cl0p,                           // llvm.hexagon.S2.cl0p
    hexagon_S2_cl1,                            // llvm.hexagon.S2.cl1
    hexagon_S2_cl1p,                           // llvm.hexagon.S2.cl1p
    hexagon_S2_clb,                            // llvm.hexagon.S2.clb
    hexagon_S2_clbnorm,                        // llvm.hexagon.S2.clbnorm
    hexagon_S2_clbp,                           // llvm.hexagon.S2.clbp
    hexagon_S2_clrbit_i,                       // llvm.hexagon.S2.clrbit.i
    hexagon_S2_clrbit_r,                       // llvm.hexagon.S2.clrbit.r
    hexagon_S2_ct0,                            // llvm.hexagon.S2.ct0
    hexagon_S2_ct0p,                           // llvm.hexagon.S2.ct0p
    hexagon_S2_ct1,                            // llvm.hexagon.S2.ct1
    hexagon_S2_ct1p,                           // llvm.hexagon.S2.ct1p
    hexagon_S2_deinterleave,                   // llvm.hexagon.S2.deinterleave
    hexagon_S2_extractu,                       // llvm.hexagon.S2.extractu
    hexagon_S2_extractu_rp,                    // llvm.hexagon.S2.extractu.rp
    hexagon_S2_extractup,                      // llvm.hexagon.S2.extractup
    hexagon_S2_extractup_rp,                   // llvm.hexagon.S2.extractup.rp
    hexagon_S2_insert,                         // llvm.hexagon.S2.insert
    hexagon_S2_insert_rp,                      // llvm.hexagon.S2.insert.rp
    hexagon_S2_insertp,                        // llvm.hexagon.S2.insertp
    hexagon_S2_insertp_rp,                     // llvm.hexagon.S2.insertp.rp
    hexagon_S2_interleave,                     // llvm.hexagon.S2.interleave
    hexagon_S2_lfsp,                           // llvm.hexagon.S2.lfsp
    hexagon_S2_lsl_r_p,                        // llvm.hexagon.S2.lsl.r.p
    hexagon_S2_lsl_r_p_acc,                    // llvm.hexagon.S2.lsl.r.p.acc
    hexagon_S2_lsl_r_p_and,                    // llvm.hexagon.S2.lsl.r.p.and
    hexagon_S2_lsl_r_p_nac,                    // llvm.hexagon.S2.lsl.r.p.nac
    hexagon_S2_lsl_r_p_or,                     // llvm.hexagon.S2.lsl.r.p.or
    hexagon_S2_lsl_r_p_xor,                    // llvm.hexagon.S2.lsl.r.p.xor
    hexagon_S2_lsl_r_r,                        // llvm.hexagon.S2.lsl.r.r
    hexagon_S2_lsl_r_r_acc,                    // llvm.hexagon.S2.lsl.r.r.acc
    hexagon_S2_lsl_r_r_and,                    // llvm.hexagon.S2.lsl.r.r.and
    hexagon_S2_lsl_r_r_nac,                    // llvm.hexagon.S2.lsl.r.r.nac
    hexagon_S2_lsl_r_r_or,                     // llvm.hexagon.S2.lsl.r.r.or
    hexagon_S2_lsl_r_vh,                       // llvm.hexagon.S2.lsl.r.vh
    hexagon_S2_lsl_r_vw,                       // llvm.hexagon.S2.lsl.r.vw
    hexagon_S2_lsr_i_p,                        // llvm.hexagon.S2.lsr.i.p
    hexagon_S2_lsr_i_p_acc,                    // llvm.hexagon.S2.lsr.i.p.acc
    hexagon_S2_lsr_i_p_and,                    // llvm.hexagon.S2.lsr.i.p.and
    hexagon_S2_lsr_i_p_nac,                    // llvm.hexagon.S2.lsr.i.p.nac
    hexagon_S2_lsr_i_p_or,                     // llvm.hexagon.S2.lsr.i.p.or
    hexagon_S2_lsr_i_p_xacc,                   // llvm.hexagon.S2.lsr.i.p.xacc
    hexagon_S2_lsr_i_r,                        // llvm.hexagon.S2.lsr.i.r
    hexagon_S2_lsr_i_r_acc,                    // llvm.hexagon.S2.lsr.i.r.acc
    hexagon_S2_lsr_i_r_and,                    // llvm.hexagon.S2.lsr.i.r.and
    hexagon_S2_lsr_i_r_nac,                    // llvm.hexagon.S2.lsr.i.r.nac
    hexagon_S2_lsr_i_r_or,                     // llvm.hexagon.S2.lsr.i.r.or
    hexagon_S2_lsr_i_r_xacc,                   // llvm.hexagon.S2.lsr.i.r.xacc
    hexagon_S2_lsr_i_vh,                       // llvm.hexagon.S2.lsr.i.vh
    hexagon_S2_lsr_i_vw,                       // llvm.hexagon.S2.lsr.i.vw
    hexagon_S2_lsr_r_p,                        // llvm.hexagon.S2.lsr.r.p
    hexagon_S2_lsr_r_p_acc,                    // llvm.hexagon.S2.lsr.r.p.acc
    hexagon_S2_lsr_r_p_and,                    // llvm.hexagon.S2.lsr.r.p.and
    hexagon_S2_lsr_r_p_nac,                    // llvm.hexagon.S2.lsr.r.p.nac
    hexagon_S2_lsr_r_p_or,                     // llvm.hexagon.S2.lsr.r.p.or
    hexagon_S2_lsr_r_p_xor,                    // llvm.hexagon.S2.lsr.r.p.xor
    hexagon_S2_lsr_r_r,                        // llvm.hexagon.S2.lsr.r.r
    hexagon_S2_lsr_r_r_acc,                    // llvm.hexagon.S2.lsr.r.r.acc
    hexagon_S2_lsr_r_r_and,                    // llvm.hexagon.S2.lsr.r.r.and
    hexagon_S2_lsr_r_r_nac,                    // llvm.hexagon.S2.lsr.r.r.nac
    hexagon_S2_lsr_r_r_or,                     // llvm.hexagon.S2.lsr.r.r.or
    hexagon_S2_lsr_r_vh,                       // llvm.hexagon.S2.lsr.r.vh
    hexagon_S2_lsr_r_vw,                       // llvm.hexagon.S2.lsr.r.vw
    hexagon_S2_mask,                           // llvm.hexagon.S2.mask
    hexagon_S2_packhl,                         // llvm.hexagon.S2.packhl
    hexagon_S2_parityp,                        // llvm.hexagon.S2.parityp
    hexagon_S2_setbit_i,                       // llvm.hexagon.S2.setbit.i
    hexagon_S2_setbit_r,                       // llvm.hexagon.S2.setbit.r
    hexagon_S2_shuffeb,                        // llvm.hexagon.S2.shuffeb
    hexagon_S2_shuffeh,                        // llvm.hexagon.S2.shuffeh
    hexagon_S2_shuffob,                        // llvm.hexagon.S2.shuffob
    hexagon_S2_shuffoh,                        // llvm.hexagon.S2.shuffoh
    hexagon_S2_storerb_pbr,                    // llvm.hexagon.S2.storerb.pbr
    hexagon_S2_storerb_pci,                    // llvm.hexagon.S2.storerb.pci
    hexagon_S2_storerb_pcr,                    // llvm.hexagon.S2.storerb.pcr
    hexagon_S2_storerd_pbr,                    // llvm.hexagon.S2.storerd.pbr
    hexagon_S2_storerd_pci,                    // llvm.hexagon.S2.storerd.pci
    hexagon_S2_storerd_pcr,                    // llvm.hexagon.S2.storerd.pcr
    hexagon_S2_storerf_pbr,                    // llvm.hexagon.S2.storerf.pbr
    hexagon_S2_storerf_pci,                    // llvm.hexagon.S2.storerf.pci
    hexagon_S2_storerf_pcr,                    // llvm.hexagon.S2.storerf.pcr
    hexagon_S2_storerh_pbr,                    // llvm.hexagon.S2.storerh.pbr
    hexagon_S2_storerh_pci,                    // llvm.hexagon.S2.storerh.pci
    hexagon_S2_storerh_pcr,                    // llvm.hexagon.S2.storerh.pcr
    hexagon_S2_storeri_pbr,                    // llvm.hexagon.S2.storeri.pbr
    hexagon_S2_storeri_pci,                    // llvm.hexagon.S2.storeri.pci
    hexagon_S2_storeri_pcr,                    // llvm.hexagon.S2.storeri.pcr
    hexagon_S2_storew_locked,                  // llvm.hexagon.S2.storew.locked
    hexagon_S2_svsathb,                        // llvm.hexagon.S2.svsathb
    hexagon_S2_svsathub,                       // llvm.hexagon.S2.svsathub
    hexagon_S2_tableidxb_goodsyntax,           // llvm.hexagon.S2.tableidxb.goodsyntax
    hexagon_S2_tableidxd_goodsyntax,           // llvm.hexagon.S2.tableidxd.goodsyntax
    hexagon_S2_tableidxh_goodsyntax,           // llvm.hexagon.S2.tableidxh.goodsyntax
    hexagon_S2_tableidxw_goodsyntax,           // llvm.hexagon.S2.tableidxw.goodsyntax
    hexagon_S2_togglebit_i,                    // llvm.hexagon.S2.togglebit.i
    hexagon_S2_togglebit_r,                    // llvm.hexagon.S2.togglebit.r
    hexagon_S2_tstbit_i,                       // llvm.hexagon.S2.tstbit.i
    hexagon_S2_tstbit_r,                       // llvm.hexagon.S2.tstbit.r
    hexagon_S2_valignib,                       // llvm.hexagon.S2.valignib
    hexagon_S2_valignrb,                       // llvm.hexagon.S2.valignrb
    hexagon_S2_vcnegh,                         // llvm.hexagon.S2.vcnegh
    hexagon_S2_vcrotate,                       // llvm.hexagon.S2.vcrotate
    hexagon_S2_vrcnegh,                        // llvm.hexagon.S2.vrcnegh
    hexagon_S2_vrndpackwh,                     // llvm.hexagon.S2.vrndpackwh
    hexagon_S2_vrndpackwhs,                    // llvm.hexagon.S2.vrndpackwhs
    hexagon_S2_vsathb,                         // llvm.hexagon.S2.vsathb
    hexagon_S2_vsathb_nopack,                  // llvm.hexagon.S2.vsathb.nopack
    hexagon_S2_vsathub,                        // llvm.hexagon.S2.vsathub
    hexagon_S2_vsathub_nopack,                 // llvm.hexagon.S2.vsathub.nopack
    hexagon_S2_vsatwh,                         // llvm.hexagon.S2.vsatwh
    hexagon_S2_vsatwh_nopack,                  // llvm.hexagon.S2.vsatwh.nopack
    hexagon_S2_vsatwuh,                        // llvm.hexagon.S2.vsatwuh
    hexagon_S2_vsatwuh_nopack,                 // llvm.hexagon.S2.vsatwuh.nopack
    hexagon_S2_vsplatrb,                       // llvm.hexagon.S2.vsplatrb
    hexagon_S2_vsplatrh,                       // llvm.hexagon.S2.vsplatrh
    hexagon_S2_vspliceib,                      // llvm.hexagon.S2.vspliceib
    hexagon_S2_vsplicerb,                      // llvm.hexagon.S2.vsplicerb
    hexagon_S2_vsxtbh,                         // llvm.hexagon.S2.vsxtbh
    hexagon_S2_vsxthw,                         // llvm.hexagon.S2.vsxthw
    hexagon_S2_vtrunehb,                       // llvm.hexagon.S2.vtrunehb
    hexagon_S2_vtrunewh,                       // llvm.hexagon.S2.vtrunewh
    hexagon_S2_vtrunohb,                       // llvm.hexagon.S2.vtrunohb
    hexagon_S2_vtrunowh,                       // llvm.hexagon.S2.vtrunowh
    hexagon_S2_vzxtbh,                         // llvm.hexagon.S2.vzxtbh
    hexagon_S2_vzxthw,                         // llvm.hexagon.S2.vzxthw
    hexagon_S4_addaddi,                        // llvm.hexagon.S4.addaddi
    hexagon_S4_addi_asl_ri,                    // llvm.hexagon.S4.addi.asl.ri
    hexagon_S4_addi_lsr_ri,                    // llvm.hexagon.S4.addi.lsr.ri
    hexagon_S4_andi_asl_ri,                    // llvm.hexagon.S4.andi.asl.ri
    hexagon_S4_andi_lsr_ri,                    // llvm.hexagon.S4.andi.lsr.ri
    hexagon_S4_clbaddi,                        // llvm.hexagon.S4.clbaddi
    hexagon_S4_clbpaddi,                       // llvm.hexagon.S4.clbpaddi
    hexagon_S4_clbpnorm,                       // llvm.hexagon.S4.clbpnorm
    hexagon_S4_extract,                        // llvm.hexagon.S4.extract
    hexagon_S4_extract_rp,                     // llvm.hexagon.S4.extract.rp
    hexagon_S4_extractp,                       // llvm.hexagon.S4.extractp
    hexagon_S4_extractp_rp,                    // llvm.hexagon.S4.extractp.rp
    hexagon_S4_lsli,                           // llvm.hexagon.S4.lsli
    hexagon_S4_ntstbit_i,                      // llvm.hexagon.S4.ntstbit.i
    hexagon_S4_ntstbit_r,                      // llvm.hexagon.S4.ntstbit.r
    hexagon_S4_or_andi,                        // llvm.hexagon.S4.or.andi
    hexagon_S4_or_andix,                       // llvm.hexagon.S4.or.andix
    hexagon_S4_or_ori,                         // llvm.hexagon.S4.or.ori
    hexagon_S4_ori_asl_ri,                     // llvm.hexagon.S4.ori.asl.ri
    hexagon_S4_ori_lsr_ri,                     // llvm.hexagon.S4.ori.lsr.ri
    hexagon_S4_parity,                         // llvm.hexagon.S4.parity
    hexagon_S4_stored_locked,                  // llvm.hexagon.S4.stored.locked
    hexagon_S4_subaddi,                        // llvm.hexagon.S4.subaddi
    hexagon_S4_subi_asl_ri,                    // llvm.hexagon.S4.subi.asl.ri
    hexagon_S4_subi_lsr_ri,                    // llvm.hexagon.S4.subi.lsr.ri
    hexagon_S4_vrcrotate,                      // llvm.hexagon.S4.vrcrotate
    hexagon_S4_vrcrotate_acc,                  // llvm.hexagon.S4.vrcrotate.acc
    hexagon_S4_vxaddsubh,                      // llvm.hexagon.S4.vxaddsubh
    hexagon_S4_vxaddsubhr,                     // llvm.hexagon.S4.vxaddsubhr
    hexagon_S4_vxaddsubw,                      // llvm.hexagon.S4.vxaddsubw
    hexagon_S4_vxsubaddh,                      // llvm.hexagon.S4.vxsubaddh
    hexagon_S4_vxsubaddhr,                     // llvm.hexagon.S4.vxsubaddhr
    hexagon_S4_vxsubaddw,                      // llvm.hexagon.S4.vxsubaddw
    hexagon_S5_asrhub_rnd_sat_goodsyntax,      // llvm.hexagon.S5.asrhub.rnd.sat.goodsyntax
    hexagon_S5_asrhub_sat,                     // llvm.hexagon.S5.asrhub.sat
    hexagon_S5_popcountp,                      // llvm.hexagon.S5.popcountp
    hexagon_S5_vasrhrnd_goodsyntax,            // llvm.hexagon.S5.vasrhrnd.goodsyntax
    hexagon_S6_rol_i_p,                        // llvm.hexagon.S6.rol.i.p
    hexagon_S6_rol_i_p_acc,                    // llvm.hexagon.S6.rol.i.p.acc
    hexagon_S6_rol_i_p_and,                    // llvm.hexagon.S6.rol.i.p.and
    hexagon_S6_rol_i_p_nac,                    // llvm.hexagon.S6.rol.i.p.nac
    hexagon_S6_rol_i_p_or,                     // llvm.hexagon.S6.rol.i.p.or
    hexagon_S6_rol_i_p_xacc,                   // llvm.hexagon.S6.rol.i.p.xacc
    hexagon_S6_rol_i_r,                        // llvm.hexagon.S6.rol.i.r
    hexagon_S6_rol_i_r_acc,                    // llvm.hexagon.S6.rol.i.r.acc
    hexagon_S6_rol_i_r_and,                    // llvm.hexagon.S6.rol.i.r.and
    hexagon_S6_rol_i_r_nac,                    // llvm.hexagon.S6.rol.i.r.nac
    hexagon_S6_rol_i_r_or,                     // llvm.hexagon.S6.rol.i.r.or
    hexagon_S6_rol_i_r_xacc,                   // llvm.hexagon.S6.rol.i.r.xacc
    hexagon_S6_vsplatrbp,                      // llvm.hexagon.S6.vsplatrbp
    hexagon_S6_vtrunehb_ppp,                   // llvm.hexagon.S6.vtrunehb.ppp
    hexagon_S6_vtrunohb_ppp,                   // llvm.hexagon.S6.vtrunohb.ppp
    hexagon_V6_extractw,                       // llvm.hexagon.V6.extractw
    hexagon_V6_extractw_128B,                  // llvm.hexagon.V6.extractw.128B
    hexagon_V6_get_qfext,                      // llvm.hexagon.V6.get.qfext
    hexagon_V6_get_qfext_128B,                 // llvm.hexagon.V6.get.qfext.128B
    hexagon_V6_get_qfext_oracc,                // llvm.hexagon.V6.get.qfext.oracc
    hexagon_V6_get_qfext_oracc_128B,           // llvm.hexagon.V6.get.qfext.oracc.128B
    hexagon_V6_hi,                             // llvm.hexagon.V6.hi
    hexagon_V6_hi_128B,                        // llvm.hexagon.V6.hi.128B
    hexagon_V6_lo,                             // llvm.hexagon.V6.lo
    hexagon_V6_lo_128B,                        // llvm.hexagon.V6.lo.128B
    hexagon_V6_lvsplatb,                       // llvm.hexagon.V6.lvsplatb
    hexagon_V6_lvsplatb_128B,                  // llvm.hexagon.V6.lvsplatb.128B
    hexagon_V6_lvsplath,                       // llvm.hexagon.V6.lvsplath
    hexagon_V6_lvsplath_128B,                  // llvm.hexagon.V6.lvsplath.128B
    hexagon_V6_lvsplatw,                       // llvm.hexagon.V6.lvsplatw
    hexagon_V6_lvsplatw_128B,                  // llvm.hexagon.V6.lvsplatw.128B
    hexagon_V6_pred_and,                       // llvm.hexagon.V6.pred.and
    hexagon_V6_pred_and_128B,                  // llvm.hexagon.V6.pred.and.128B
    hexagon_V6_pred_and_n,                     // llvm.hexagon.V6.pred.and.n
    hexagon_V6_pred_and_n_128B,                // llvm.hexagon.V6.pred.and.n.128B
    hexagon_V6_pred_not,                       // llvm.hexagon.V6.pred.not
    hexagon_V6_pred_not_128B,                  // llvm.hexagon.V6.pred.not.128B
    hexagon_V6_pred_or,                        // llvm.hexagon.V6.pred.or
    hexagon_V6_pred_or_128B,                   // llvm.hexagon.V6.pred.or.128B
    hexagon_V6_pred_or_n,                      // llvm.hexagon.V6.pred.or.n
    hexagon_V6_pred_or_n_128B,                 // llvm.hexagon.V6.pred.or.n.128B
    hexagon_V6_pred_scalar2,                   // llvm.hexagon.V6.pred.scalar2
    hexagon_V6_pred_scalar2_128B,              // llvm.hexagon.V6.pred.scalar2.128B
    hexagon_V6_pred_scalar2v2,                 // llvm.hexagon.V6.pred.scalar2v2
    hexagon_V6_pred_scalar2v2_128B,            // llvm.hexagon.V6.pred.scalar2v2.128B
    hexagon_V6_pred_typecast,                  // llvm.hexagon.V6.pred.typecast
    hexagon_V6_pred_typecast_128B,             // llvm.hexagon.V6.pred.typecast.128B
    hexagon_V6_pred_xor,                       // llvm.hexagon.V6.pred.xor
    hexagon_V6_pred_xor_128B,                  // llvm.hexagon.V6.pred.xor.128B
    hexagon_V6_set_qfext,                      // llvm.hexagon.V6.set.qfext
    hexagon_V6_set_qfext_128B,                 // llvm.hexagon.V6.set.qfext.128B
    hexagon_V6_shuffeqh,                       // llvm.hexagon.V6.shuffeqh
    hexagon_V6_shuffeqh_128B,                  // llvm.hexagon.V6.shuffeqh.128B
    hexagon_V6_shuffeqw,                       // llvm.hexagon.V6.shuffeqw
    hexagon_V6_shuffeqw_128B,                  // llvm.hexagon.V6.shuffeqw.128B
    hexagon_V6_v6mpyhubs10,                    // llvm.hexagon.V6.v6mpyhubs10
    hexagon_V6_v6mpyhubs10_128B,               // llvm.hexagon.V6.v6mpyhubs10.128B
    hexagon_V6_v6mpyhubs10_vxx,                // llvm.hexagon.V6.v6mpyhubs10.vxx
    hexagon_V6_v6mpyhubs10_vxx_128B,           // llvm.hexagon.V6.v6mpyhubs10.vxx.128B
    hexagon_V6_v6mpyvubs10,                    // llvm.hexagon.V6.v6mpyvubs10
    hexagon_V6_v6mpyvubs10_128B,               // llvm.hexagon.V6.v6mpyvubs10.128B
    hexagon_V6_v6mpyvubs10_vxx,                // llvm.hexagon.V6.v6mpyvubs10.vxx
    hexagon_V6_v6mpyvubs10_vxx_128B,           // llvm.hexagon.V6.v6mpyvubs10.vxx.128B
    hexagon_V6_vL32b_npred_ai,                 // llvm.hexagon.V6.vL32b.npred.ai
    hexagon_V6_vL32b_npred_ai_128B,            // llvm.hexagon.V6.vL32b.npred.ai.128B
    hexagon_V6_vL32b_npred_pi,                 // llvm.hexagon.V6.vL32b.npred.pi
    hexagon_V6_vL32b_npred_pi_128B,            // llvm.hexagon.V6.vL32b.npred.pi.128B
    hexagon_V6_vL32b_npred_ppu,                // llvm.hexagon.V6.vL32b.npred.ppu
    hexagon_V6_vL32b_npred_ppu_128B,           // llvm.hexagon.V6.vL32b.npred.ppu.128B
    hexagon_V6_vL32b_nt_npred_ai,              // llvm.hexagon.V6.vL32b.nt.npred.ai
    hexagon_V6_vL32b_nt_npred_ai_128B,         // llvm.hexagon.V6.vL32b.nt.npred.ai.128B
    hexagon_V6_vL32b_nt_npred_pi,              // llvm.hexagon.V6.vL32b.nt.npred.pi
    hexagon_V6_vL32b_nt_npred_pi_128B,         // llvm.hexagon.V6.vL32b.nt.npred.pi.128B
    hexagon_V6_vL32b_nt_npred_ppu,             // llvm.hexagon.V6.vL32b.nt.npred.ppu
    hexagon_V6_vL32b_nt_npred_ppu_128B,        // llvm.hexagon.V6.vL32b.nt.npred.ppu.128B
    hexagon_V6_vL32b_nt_pred_ai,               // llvm.hexagon.V6.vL32b.nt.pred.ai
    hexagon_V6_vL32b_nt_pred_ai_128B,          // llvm.hexagon.V6.vL32b.nt.pred.ai.128B
    hexagon_V6_vL32b_nt_pred_pi,               // llvm.hexagon.V6.vL32b.nt.pred.pi
    hexagon_V6_vL32b_nt_pred_pi_128B,          // llvm.hexagon.V6.vL32b.nt.pred.pi.128B
    hexagon_V6_vL32b_nt_pred_ppu,              // llvm.hexagon.V6.vL32b.nt.pred.ppu
    hexagon_V6_vL32b_nt_pred_ppu_128B,         // llvm.hexagon.V6.vL32b.nt.pred.ppu.128B
    hexagon_V6_vL32b_pred_ai,                  // llvm.hexagon.V6.vL32b.pred.ai
    hexagon_V6_vL32b_pred_ai_128B,             // llvm.hexagon.V6.vL32b.pred.ai.128B
    hexagon_V6_vL32b_pred_pi,                  // llvm.hexagon.V6.vL32b.pred.pi
    hexagon_V6_vL32b_pred_pi_128B,             // llvm.hexagon.V6.vL32b.pred.pi.128B
    hexagon_V6_vL32b_pred_ppu,                 // llvm.hexagon.V6.vL32b.pred.ppu
    hexagon_V6_vL32b_pred_ppu_128B,            // llvm.hexagon.V6.vL32b.pred.ppu.128B
    hexagon_V6_vS32Ub_npred_ai,                // llvm.hexagon.V6.vS32Ub.npred.ai
    hexagon_V6_vS32Ub_npred_ai_128B,           // llvm.hexagon.V6.vS32Ub.npred.ai.128B
    hexagon_V6_vS32Ub_npred_pi,                // llvm.hexagon.V6.vS32Ub.npred.pi
    hexagon_V6_vS32Ub_npred_pi_128B,           // llvm.hexagon.V6.vS32Ub.npred.pi.128B
    hexagon_V6_vS32Ub_npred_ppu,               // llvm.hexagon.V6.vS32Ub.npred.ppu
    hexagon_V6_vS32Ub_npred_ppu_128B,          // llvm.hexagon.V6.vS32Ub.npred.ppu.128B
    hexagon_V6_vS32Ub_pred_ai,                 // llvm.hexagon.V6.vS32Ub.pred.ai
    hexagon_V6_vS32Ub_pred_ai_128B,            // llvm.hexagon.V6.vS32Ub.pred.ai.128B
    hexagon_V6_vS32Ub_pred_pi,                 // llvm.hexagon.V6.vS32Ub.pred.pi
    hexagon_V6_vS32Ub_pred_pi_128B,            // llvm.hexagon.V6.vS32Ub.pred.pi.128B
    hexagon_V6_vS32Ub_pred_ppu,                // llvm.hexagon.V6.vS32Ub.pred.ppu
    hexagon_V6_vS32Ub_pred_ppu_128B,           // llvm.hexagon.V6.vS32Ub.pred.ppu.128B
    hexagon_V6_vS32b_npred_ai,                 // llvm.hexagon.V6.vS32b.npred.ai
    hexagon_V6_vS32b_npred_ai_128B,            // llvm.hexagon.V6.vS32b.npred.ai.128B
    hexagon_V6_vS32b_npred_pi,                 // llvm.hexagon.V6.vS32b.npred.pi
    hexagon_V6_vS32b_npred_pi_128B,            // llvm.hexagon.V6.vS32b.npred.pi.128B
    hexagon_V6_vS32b_npred_ppu,                // llvm.hexagon.V6.vS32b.npred.ppu
    hexagon_V6_vS32b_npred_ppu_128B,           // llvm.hexagon.V6.vS32b.npred.ppu.128B
    hexagon_V6_vS32b_nqpred_ai,                // llvm.hexagon.V6.vS32b.nqpred.ai
    hexagon_V6_vS32b_nqpred_ai_128B,           // llvm.hexagon.V6.vS32b.nqpred.ai.128B
    hexagon_V6_vS32b_nt_npred_ai,              // llvm.hexagon.V6.vS32b.nt.npred.ai
    hexagon_V6_vS32b_nt_npred_ai_128B,         // llvm.hexagon.V6.vS32b.nt.npred.ai.128B
    hexagon_V6_vS32b_nt_npred_pi,              // llvm.hexagon.V6.vS32b.nt.npred.pi
    hexagon_V6_vS32b_nt_npred_pi_128B,         // llvm.hexagon.V6.vS32b.nt.npred.pi.128B
    hexagon_V6_vS32b_nt_npred_ppu,             // llvm.hexagon.V6.vS32b.nt.npred.ppu
    hexagon_V6_vS32b_nt_npred_ppu_128B,        // llvm.hexagon.V6.vS32b.nt.npred.ppu.128B
    hexagon_V6_vS32b_nt_nqpred_ai,             // llvm.hexagon.V6.vS32b.nt.nqpred.ai
    hexagon_V6_vS32b_nt_nqpred_ai_128B,        // llvm.hexagon.V6.vS32b.nt.nqpred.ai.128B
    hexagon_V6_vS32b_nt_pred_ai,               // llvm.hexagon.V6.vS32b.nt.pred.ai
    hexagon_V6_vS32b_nt_pred_ai_128B,          // llvm.hexagon.V6.vS32b.nt.pred.ai.128B
    hexagon_V6_vS32b_nt_pred_pi,               // llvm.hexagon.V6.vS32b.nt.pred.pi
    hexagon_V6_vS32b_nt_pred_pi_128B,          // llvm.hexagon.V6.vS32b.nt.pred.pi.128B
    hexagon_V6_vS32b_nt_pred_ppu,              // llvm.hexagon.V6.vS32b.nt.pred.ppu
    hexagon_V6_vS32b_nt_pred_ppu_128B,         // llvm.hexagon.V6.vS32b.nt.pred.ppu.128B
    hexagon_V6_vS32b_nt_qpred_ai,              // llvm.hexagon.V6.vS32b.nt.qpred.ai
    hexagon_V6_vS32b_nt_qpred_ai_128B,         // llvm.hexagon.V6.vS32b.nt.qpred.ai.128B
    hexagon_V6_vS32b_pred_ai,                  // llvm.hexagon.V6.vS32b.pred.ai
    hexagon_V6_vS32b_pred_ai_128B,             // llvm.hexagon.V6.vS32b.pred.ai.128B
    hexagon_V6_vS32b_pred_pi,                  // llvm.hexagon.V6.vS32b.pred.pi
    hexagon_V6_vS32b_pred_pi_128B,             // llvm.hexagon.V6.vS32b.pred.pi.128B
    hexagon_V6_vS32b_pred_ppu,                 // llvm.hexagon.V6.vS32b.pred.ppu
    hexagon_V6_vS32b_pred_ppu_128B,            // llvm.hexagon.V6.vS32b.pred.ppu.128B
    hexagon_V6_vS32b_qpred_ai,                 // llvm.hexagon.V6.vS32b.qpred.ai
    hexagon_V6_vS32b_qpred_ai_128B,            // llvm.hexagon.V6.vS32b.qpred.ai.128B
    hexagon_V6_vabs_f8,                        // llvm.hexagon.V6.vabs.f8
    hexagon_V6_vabs_f8_128B,                   // llvm.hexagon.V6.vabs.f8.128B
    hexagon_V6_vabs_hf,                        // llvm.hexagon.V6.vabs.hf
    hexagon_V6_vabs_hf_128B,                   // llvm.hexagon.V6.vabs.hf.128B
    hexagon_V6_vabs_sf,                        // llvm.hexagon.V6.vabs.sf
    hexagon_V6_vabs_sf_128B,                   // llvm.hexagon.V6.vabs.sf.128B
    hexagon_V6_vabsb,                          // llvm.hexagon.V6.vabsb
    hexagon_V6_vabsb_128B,                     // llvm.hexagon.V6.vabsb.128B
    hexagon_V6_vabsb_sat,                      // llvm.hexagon.V6.vabsb.sat
    hexagon_V6_vabsb_sat_128B,                 // llvm.hexagon.V6.vabsb.sat.128B
    hexagon_V6_vabsdiffh,                      // llvm.hexagon.V6.vabsdiffh
    hexagon_V6_vabsdiffh_128B,                 // llvm.hexagon.V6.vabsdiffh.128B
    hexagon_V6_vabsdiffub,                     // llvm.hexagon.V6.vabsdiffub
    hexagon_V6_vabsdiffub_128B,                // llvm.hexagon.V6.vabsdiffub.128B
    hexagon_V6_vabsdiffuh,                     // llvm.hexagon.V6.vabsdiffuh
    hexagon_V6_vabsdiffuh_128B,                // llvm.hexagon.V6.vabsdiffuh.128B
    hexagon_V6_vabsdiffw,                      // llvm.hexagon.V6.vabsdiffw
    hexagon_V6_vabsdiffw_128B,                 // llvm.hexagon.V6.vabsdiffw.128B
    hexagon_V6_vabsh,                          // llvm.hexagon.V6.vabsh
    hexagon_V6_vabsh_128B,                     // llvm.hexagon.V6.vabsh.128B
    hexagon_V6_vabsh_sat,                      // llvm.hexagon.V6.vabsh.sat
    hexagon_V6_vabsh_sat_128B,                 // llvm.hexagon.V6.vabsh.sat.128B
    hexagon_V6_vabsw,                          // llvm.hexagon.V6.vabsw
    hexagon_V6_vabsw_128B,                     // llvm.hexagon.V6.vabsw.128B
    hexagon_V6_vabsw_sat,                      // llvm.hexagon.V6.vabsw.sat
    hexagon_V6_vabsw_sat_128B,                 // llvm.hexagon.V6.vabsw.sat.128B
    hexagon_V6_vadd_hf,                        // llvm.hexagon.V6.vadd.hf
    hexagon_V6_vadd_hf_128B,                   // llvm.hexagon.V6.vadd.hf.128B
    hexagon_V6_vadd_hf_f8,                     // llvm.hexagon.V6.vadd.hf.f8
    hexagon_V6_vadd_hf_f8_128B,                // llvm.hexagon.V6.vadd.hf.f8.128B
    hexagon_V6_vadd_hf_hf,                     // llvm.hexagon.V6.vadd.hf.hf
    hexagon_V6_vadd_hf_hf_128B,                // llvm.hexagon.V6.vadd.hf.hf.128B
    hexagon_V6_vadd_qf16,                      // llvm.hexagon.V6.vadd.qf16
    hexagon_V6_vadd_qf16_128B,                 // llvm.hexagon.V6.vadd.qf16.128B
    hexagon_V6_vadd_qf16_mix,                  // llvm.hexagon.V6.vadd.qf16.mix
    hexagon_V6_vadd_qf16_mix_128B,             // llvm.hexagon.V6.vadd.qf16.mix.128B
    hexagon_V6_vadd_qf32,                      // llvm.hexagon.V6.vadd.qf32
    hexagon_V6_vadd_qf32_128B,                 // llvm.hexagon.V6.vadd.qf32.128B
    hexagon_V6_vadd_qf32_mix,                  // llvm.hexagon.V6.vadd.qf32.mix
    hexagon_V6_vadd_qf32_mix_128B,             // llvm.hexagon.V6.vadd.qf32.mix.128B
    hexagon_V6_vadd_sf,                        // llvm.hexagon.V6.vadd.sf
    hexagon_V6_vadd_sf_128B,                   // llvm.hexagon.V6.vadd.sf.128B
    hexagon_V6_vadd_sf_bf,                     // llvm.hexagon.V6.vadd.sf.bf
    hexagon_V6_vadd_sf_bf_128B,                // llvm.hexagon.V6.vadd.sf.bf.128B
    hexagon_V6_vadd_sf_hf,                     // llvm.hexagon.V6.vadd.sf.hf
    hexagon_V6_vadd_sf_hf_128B,                // llvm.hexagon.V6.vadd.sf.hf.128B
    hexagon_V6_vadd_sf_sf,                     // llvm.hexagon.V6.vadd.sf.sf
    hexagon_V6_vadd_sf_sf_128B,                // llvm.hexagon.V6.vadd.sf.sf.128B
    hexagon_V6_vaddb,                          // llvm.hexagon.V6.vaddb
    hexagon_V6_vaddb_128B,                     // llvm.hexagon.V6.vaddb.128B
    hexagon_V6_vaddb_dv,                       // llvm.hexagon.V6.vaddb.dv
    hexagon_V6_vaddb_dv_128B,                  // llvm.hexagon.V6.vaddb.dv.128B
    hexagon_V6_vaddbnq,                        // llvm.hexagon.V6.vaddbnq
    hexagon_V6_vaddbnq_128B,                   // llvm.hexagon.V6.vaddbnq.128B
    hexagon_V6_vaddbq,                         // llvm.hexagon.V6.vaddbq
    hexagon_V6_vaddbq_128B,                    // llvm.hexagon.V6.vaddbq.128B
    hexagon_V6_vaddbsat,                       // llvm.hexagon.V6.vaddbsat
    hexagon_V6_vaddbsat_128B,                  // llvm.hexagon.V6.vaddbsat.128B
    hexagon_V6_vaddbsat_dv,                    // llvm.hexagon.V6.vaddbsat.dv
    hexagon_V6_vaddbsat_dv_128B,               // llvm.hexagon.V6.vaddbsat.dv.128B
    hexagon_V6_vaddcarry,                      // llvm.hexagon.V6.vaddcarry
    hexagon_V6_vaddcarry_128B,                 // llvm.hexagon.V6.vaddcarry.128B
    hexagon_V6_vaddcarryo,                     // llvm.hexagon.V6.vaddcarryo
    hexagon_V6_vaddcarryo_128B,                // llvm.hexagon.V6.vaddcarryo.128B
    hexagon_V6_vaddcarrysat,                   // llvm.hexagon.V6.vaddcarrysat
    hexagon_V6_vaddcarrysat_128B,              // llvm.hexagon.V6.vaddcarrysat.128B
    hexagon_V6_vaddclbh,                       // llvm.hexagon.V6.vaddclbh
    hexagon_V6_vaddclbh_128B,                  // llvm.hexagon.V6.vaddclbh.128B
    hexagon_V6_vaddclbw,                       // llvm.hexagon.V6.vaddclbw
    hexagon_V6_vaddclbw_128B,                  // llvm.hexagon.V6.vaddclbw.128B
    hexagon_V6_vaddh,                          // llvm.hexagon.V6.vaddh
    hexagon_V6_vaddh_128B,                     // llvm.hexagon.V6.vaddh.128B
    hexagon_V6_vaddh_dv,                       // llvm.hexagon.V6.vaddh.dv
    hexagon_V6_vaddh_dv_128B,                  // llvm.hexagon.V6.vaddh.dv.128B
    hexagon_V6_vaddhnq,                        // llvm.hexagon.V6.vaddhnq
    hexagon_V6_vaddhnq_128B,                   // llvm.hexagon.V6.vaddhnq.128B
    hexagon_V6_vaddhq,                         // llvm.hexagon.V6.vaddhq
    hexagon_V6_vaddhq_128B,                    // llvm.hexagon.V6.vaddhq.128B
    hexagon_V6_vaddhsat,                       // llvm.hexagon.V6.vaddhsat
    hexagon_V6_vaddhsat_128B,                  // llvm.hexagon.V6.vaddhsat.128B
    hexagon_V6_vaddhsat_dv,                    // llvm.hexagon.V6.vaddhsat.dv
    hexagon_V6_vaddhsat_dv_128B,               // llvm.hexagon.V6.vaddhsat.dv.128B
    hexagon_V6_vaddhw,                         // llvm.hexagon.V6.vaddhw
    hexagon_V6_vaddhw_128B,                    // llvm.hexagon.V6.vaddhw.128B
    hexagon_V6_vaddhw_acc,                     // llvm.hexagon.V6.vaddhw.acc
    hexagon_V6_vaddhw_acc_128B,                // llvm.hexagon.V6.vaddhw.acc.128B
    hexagon_V6_vaddubh,                        // llvm.hexagon.V6.vaddubh
    hexagon_V6_vaddubh_128B,                   // llvm.hexagon.V6.vaddubh.128B
    hexagon_V6_vaddubh_acc,                    // llvm.hexagon.V6.vaddubh.acc
    hexagon_V6_vaddubh_acc_128B,               // llvm.hexagon.V6.vaddubh.acc.128B
    hexagon_V6_vaddubsat,                      // llvm.hexagon.V6.vaddubsat
    hexagon_V6_vaddubsat_128B,                 // llvm.hexagon.V6.vaddubsat.128B
    hexagon_V6_vaddubsat_dv,                   // llvm.hexagon.V6.vaddubsat.dv
    hexagon_V6_vaddubsat_dv_128B,              // llvm.hexagon.V6.vaddubsat.dv.128B
    hexagon_V6_vaddububb_sat,                  // llvm.hexagon.V6.vaddububb.sat
    hexagon_V6_vaddububb_sat_128B,             // llvm.hexagon.V6.vaddububb.sat.128B
    hexagon_V6_vadduhsat,                      // llvm.hexagon.V6.vadduhsat
    hexagon_V6_vadduhsat_128B,                 // llvm.hexagon.V6.vadduhsat.128B
    hexagon_V6_vadduhsat_dv,                   // llvm.hexagon.V6.vadduhsat.dv
    hexagon_V6_vadduhsat_dv_128B,              // llvm.hexagon.V6.vadduhsat.dv.128B
    hexagon_V6_vadduhw,                        // llvm.hexagon.V6.vadduhw
    hexagon_V6_vadduhw_128B,                   // llvm.hexagon.V6.vadduhw.128B
    hexagon_V6_vadduhw_acc,                    // llvm.hexagon.V6.vadduhw.acc
    hexagon_V6_vadduhw_acc_128B,               // llvm.hexagon.V6.vadduhw.acc.128B
    hexagon_V6_vadduwsat,                      // llvm.hexagon.V6.vadduwsat
    hexagon_V6_vadduwsat_128B,                 // llvm.hexagon.V6.vadduwsat.128B
    hexagon_V6_vadduwsat_dv,                   // llvm.hexagon.V6.vadduwsat.dv
    hexagon_V6_vadduwsat_dv_128B,              // llvm.hexagon.V6.vadduwsat.dv.128B
    hexagon_V6_vaddw,                          // llvm.hexagon.V6.vaddw
    hexagon_V6_vaddw_128B,                     // llvm.hexagon.V6.vaddw.128B
    hexagon_V6_vaddw_dv,                       // llvm.hexagon.V6.vaddw.dv
    hexagon_V6_vaddw_dv_128B,                  // llvm.hexagon.V6.vaddw.dv.128B
    hexagon_V6_vaddwnq,                        // llvm.hexagon.V6.vaddwnq
    hexagon_V6_vaddwnq_128B,                   // llvm.hexagon.V6.vaddwnq.128B
    hexagon_V6_vaddwq,                         // llvm.hexagon.V6.vaddwq
    hexagon_V6_vaddwq_128B,                    // llvm.hexagon.V6.vaddwq.128B
    hexagon_V6_vaddwsat,                       // llvm.hexagon.V6.vaddwsat
    hexagon_V6_vaddwsat_128B,                  // llvm.hexagon.V6.vaddwsat.128B
    hexagon_V6_vaddwsat_dv,                    // llvm.hexagon.V6.vaddwsat.dv
    hexagon_V6_vaddwsat_dv_128B,               // llvm.hexagon.V6.vaddwsat.dv.128B
    hexagon_V6_valignb,                        // llvm.hexagon.V6.valignb
    hexagon_V6_valignb_128B,                   // llvm.hexagon.V6.valignb.128B
    hexagon_V6_valignbi,                       // llvm.hexagon.V6.valignbi
    hexagon_V6_valignbi_128B,                  // llvm.hexagon.V6.valignbi.128B
    hexagon_V6_vand,                           // llvm.hexagon.V6.vand
    hexagon_V6_vand_128B,                      // llvm.hexagon.V6.vand.128B
    hexagon_V6_vandnqrt,                       // llvm.hexagon.V6.vandnqrt
    hexagon_V6_vandnqrt_128B,                  // llvm.hexagon.V6.vandnqrt.128B
    hexagon_V6_vandnqrt_acc,                   // llvm.hexagon.V6.vandnqrt.acc
    hexagon_V6_vandnqrt_acc_128B,              // llvm.hexagon.V6.vandnqrt.acc.128B
    hexagon_V6_vandqrt,                        // llvm.hexagon.V6.vandqrt
    hexagon_V6_vandqrt_128B,                   // llvm.hexagon.V6.vandqrt.128B
    hexagon_V6_vandqrt_acc,                    // llvm.hexagon.V6.vandqrt.acc
    hexagon_V6_vandqrt_acc_128B,               // llvm.hexagon.V6.vandqrt.acc.128B
    hexagon_V6_vandvnqv,                       // llvm.hexagon.V6.vandvnqv
    hexagon_V6_vandvnqv_128B,                  // llvm.hexagon.V6.vandvnqv.128B
    hexagon_V6_vandvqv,                        // llvm.hexagon.V6.vandvqv
    hexagon_V6_vandvqv_128B,                   // llvm.hexagon.V6.vandvqv.128B
    hexagon_V6_vandvrt,                        // llvm.hexagon.V6.vandvrt
    hexagon_V6_vandvrt_128B,                   // llvm.hexagon.V6.vandvrt.128B
    hexagon_V6_vandvrt_acc,                    // llvm.hexagon.V6.vandvrt.acc
    hexagon_V6_vandvrt_acc_128B,               // llvm.hexagon.V6.vandvrt.acc.128B
    hexagon_V6_vaslh,                          // llvm.hexagon.V6.vaslh
    hexagon_V6_vaslh_128B,                     // llvm.hexagon.V6.vaslh.128B
    hexagon_V6_vaslh_acc,                      // llvm.hexagon.V6.vaslh.acc
    hexagon_V6_vaslh_acc_128B,                 // llvm.hexagon.V6.vaslh.acc.128B
    hexagon_V6_vaslhv,                         // llvm.hexagon.V6.vaslhv
    hexagon_V6_vaslhv_128B,                    // llvm.hexagon.V6.vaslhv.128B
    hexagon_V6_vaslw,                          // llvm.hexagon.V6.vaslw
    hexagon_V6_vaslw_128B,                     // llvm.hexagon.V6.vaslw.128B
    hexagon_V6_vaslw_acc,                      // llvm.hexagon.V6.vaslw.acc
    hexagon_V6_vaslw_acc_128B,                 // llvm.hexagon.V6.vaslw.acc.128B
    hexagon_V6_vaslwv,                         // llvm.hexagon.V6.vaslwv
    hexagon_V6_vaslwv_128B,                    // llvm.hexagon.V6.vaslwv.128B
    hexagon_V6_vasr_into,                      // llvm.hexagon.V6.vasr.into
    hexagon_V6_vasr_into_128B,                 // llvm.hexagon.V6.vasr.into.128B
    hexagon_V6_vasrh,                          // llvm.hexagon.V6.vasrh
    hexagon_V6_vasrh_128B,                     // llvm.hexagon.V6.vasrh.128B
    hexagon_V6_vasrh_acc,                      // llvm.hexagon.V6.vasrh.acc
    hexagon_V6_vasrh_acc_128B,                 // llvm.hexagon.V6.vasrh.acc.128B
    hexagon_V6_vasrhbrndsat,                   // llvm.hexagon.V6.vasrhbrndsat
    hexagon_V6_vasrhbrndsat_128B,              // llvm.hexagon.V6.vasrhbrndsat.128B
    hexagon_V6_vasrhbsat,                      // llvm.hexagon.V6.vasrhbsat
    hexagon_V6_vasrhbsat_128B,                 // llvm.hexagon.V6.vasrhbsat.128B
    hexagon_V6_vasrhubrndsat,                  // llvm.hexagon.V6.vasrhubrndsat
    hexagon_V6_vasrhubrndsat_128B,             // llvm.hexagon.V6.vasrhubrndsat.128B
    hexagon_V6_vasrhubsat,                     // llvm.hexagon.V6.vasrhubsat
    hexagon_V6_vasrhubsat_128B,                // llvm.hexagon.V6.vasrhubsat.128B
    hexagon_V6_vasrhv,                         // llvm.hexagon.V6.vasrhv
    hexagon_V6_vasrhv_128B,                    // llvm.hexagon.V6.vasrhv.128B
    hexagon_V6_vasruhubrndsat,                 // llvm.hexagon.V6.vasruhubrndsat
    hexagon_V6_vasruhubrndsat_128B,            // llvm.hexagon.V6.vasruhubrndsat.128B
    hexagon_V6_vasruhubsat,                    // llvm.hexagon.V6.vasruhubsat
    hexagon_V6_vasruhubsat_128B,               // llvm.hexagon.V6.vasruhubsat.128B
    hexagon_V6_vasruwuhrndsat,                 // llvm.hexagon.V6.vasruwuhrndsat
    hexagon_V6_vasruwuhrndsat_128B,            // llvm.hexagon.V6.vasruwuhrndsat.128B
    hexagon_V6_vasruwuhsat,                    // llvm.hexagon.V6.vasruwuhsat
    hexagon_V6_vasruwuhsat_128B,               // llvm.hexagon.V6.vasruwuhsat.128B
    hexagon_V6_vasrvuhubrndsat,                // llvm.hexagon.V6.vasrvuhubrndsat
    hexagon_V6_vasrvuhubrndsat_128B,           // llvm.hexagon.V6.vasrvuhubrndsat.128B
    hexagon_V6_vasrvuhubsat,                   // llvm.hexagon.V6.vasrvuhubsat
    hexagon_V6_vasrvuhubsat_128B,              // llvm.hexagon.V6.vasrvuhubsat.128B
    hexagon_V6_vasrvwuhrndsat,                 // llvm.hexagon.V6.vasrvwuhrndsat
    hexagon_V6_vasrvwuhrndsat_128B,            // llvm.hexagon.V6.vasrvwuhrndsat.128B
    hexagon_V6_vasrvwuhsat,                    // llvm.hexagon.V6.vasrvwuhsat
    hexagon_V6_vasrvwuhsat_128B,               // llvm.hexagon.V6.vasrvwuhsat.128B
    hexagon_V6_vasrw,                          // llvm.hexagon.V6.vasrw
    hexagon_V6_vasrw_128B,                     // llvm.hexagon.V6.vasrw.128B
    hexagon_V6_vasrw_acc,                      // llvm.hexagon.V6.vasrw.acc
    hexagon_V6_vasrw_acc_128B,                 // llvm.hexagon.V6.vasrw.acc.128B
    hexagon_V6_vasrwh,                         // llvm.hexagon.V6.vasrwh
    hexagon_V6_vasrwh_128B,                    // llvm.hexagon.V6.vasrwh.128B
    hexagon_V6_vasrwhrndsat,                   // llvm.hexagon.V6.vasrwhrndsat
    hexagon_V6_vasrwhrndsat_128B,              // llvm.hexagon.V6.vasrwhrndsat.128B
    hexagon_V6_vasrwhsat,                      // llvm.hexagon.V6.vasrwhsat
    hexagon_V6_vasrwhsat_128B,                 // llvm.hexagon.V6.vasrwhsat.128B
    hexagon_V6_vasrwuhrndsat,                  // llvm.hexagon.V6.vasrwuhrndsat
    hexagon_V6_vasrwuhrndsat_128B,             // llvm.hexagon.V6.vasrwuhrndsat.128B
    hexagon_V6_vasrwuhsat,                     // llvm.hexagon.V6.vasrwuhsat
    hexagon_V6_vasrwuhsat_128B,                // llvm.hexagon.V6.vasrwuhsat.128B
    hexagon_V6_vasrwv,                         // llvm.hexagon.V6.vasrwv
    hexagon_V6_vasrwv_128B,                    // llvm.hexagon.V6.vasrwv.128B
    hexagon_V6_vassign,                        // llvm.hexagon.V6.vassign
    hexagon_V6_vassign_128B,                   // llvm.hexagon.V6.vassign.128B
    hexagon_V6_vassign_fp,                     // llvm.hexagon.V6.vassign.fp
    hexagon_V6_vassign_fp_128B,                // llvm.hexagon.V6.vassign.fp.128B
    hexagon_V6_vassignp,                       // llvm.hexagon.V6.vassignp
    hexagon_V6_vassignp_128B,                  // llvm.hexagon.V6.vassignp.128B
    hexagon_V6_vavgb,                          // llvm.hexagon.V6.vavgb
    hexagon_V6_vavgb_128B,                     // llvm.hexagon.V6.vavgb.128B
    hexagon_V6_vavgbrnd,                       // llvm.hexagon.V6.vavgbrnd
    hexagon_V6_vavgbrnd_128B,                  // llvm.hexagon.V6.vavgbrnd.128B
    hexagon_V6_vavgh,                          // llvm.hexagon.V6.vavgh
    hexagon_V6_vavgh_128B,                     // llvm.hexagon.V6.vavgh.128B
    hexagon_V6_vavghrnd,                       // llvm.hexagon.V6.vavghrnd
    hexagon_V6_vavghrnd_128B,                  // llvm.hexagon.V6.vavghrnd.128B
    hexagon_V6_vavgub,                         // llvm.hexagon.V6.vavgub
    hexagon_V6_vavgub_128B,                    // llvm.hexagon.V6.vavgub.128B
    hexagon_V6_vavgubrnd,                      // llvm.hexagon.V6.vavgubrnd
    hexagon_V6_vavgubrnd_128B,                 // llvm.hexagon.V6.vavgubrnd.128B
    hexagon_V6_vavguh,                         // llvm.hexagon.V6.vavguh
    hexagon_V6_vavguh_128B,                    // llvm.hexagon.V6.vavguh.128B
    hexagon_V6_vavguhrnd,                      // llvm.hexagon.V6.vavguhrnd
    hexagon_V6_vavguhrnd_128B,                 // llvm.hexagon.V6.vavguhrnd.128B
    hexagon_V6_vavguw,                         // llvm.hexagon.V6.vavguw
    hexagon_V6_vavguw_128B,                    // llvm.hexagon.V6.vavguw.128B
    hexagon_V6_vavguwrnd,                      // llvm.hexagon.V6.vavguwrnd
    hexagon_V6_vavguwrnd_128B,                 // llvm.hexagon.V6.vavguwrnd.128B
    hexagon_V6_vavgw,                          // llvm.hexagon.V6.vavgw
    hexagon_V6_vavgw_128B,                     // llvm.hexagon.V6.vavgw.128B
    hexagon_V6_vavgwrnd,                       // llvm.hexagon.V6.vavgwrnd
    hexagon_V6_vavgwrnd_128B,                  // llvm.hexagon.V6.vavgwrnd.128B
    hexagon_V6_vcl0h,                          // llvm.hexagon.V6.vcl0h
    hexagon_V6_vcl0h_128B,                     // llvm.hexagon.V6.vcl0h.128B
    hexagon_V6_vcl0w,                          // llvm.hexagon.V6.vcl0w
    hexagon_V6_vcl0w_128B,                     // llvm.hexagon.V6.vcl0w.128B
    hexagon_V6_vcombine,                       // llvm.hexagon.V6.vcombine
    hexagon_V6_vcombine_128B,                  // llvm.hexagon.V6.vcombine.128B
    hexagon_V6_vconv_h_hf,                     // llvm.hexagon.V6.vconv.h.hf
    hexagon_V6_vconv_h_hf_128B,                // llvm.hexagon.V6.vconv.h.hf.128B
    hexagon_V6_vconv_hf_h,                     // llvm.hexagon.V6.vconv.hf.h
    hexagon_V6_vconv_hf_h_128B,                // llvm.hexagon.V6.vconv.hf.h.128B
    hexagon_V6_vconv_hf_qf16,                  // llvm.hexagon.V6.vconv.hf.qf16
    hexagon_V6_vconv_hf_qf16_128B,             // llvm.hexagon.V6.vconv.hf.qf16.128B
    hexagon_V6_vconv_hf_qf32,                  // llvm.hexagon.V6.vconv.hf.qf32
    hexagon_V6_vconv_hf_qf32_128B,             // llvm.hexagon.V6.vconv.hf.qf32.128B
    hexagon_V6_vconv_sf_qf32,                  // llvm.hexagon.V6.vconv.sf.qf32
    hexagon_V6_vconv_sf_qf32_128B,             // llvm.hexagon.V6.vconv.sf.qf32.128B
    hexagon_V6_vconv_sf_w,                     // llvm.hexagon.V6.vconv.sf.w
    hexagon_V6_vconv_sf_w_128B,                // llvm.hexagon.V6.vconv.sf.w.128B
    hexagon_V6_vconv_w_sf,                     // llvm.hexagon.V6.vconv.w.sf
    hexagon_V6_vconv_w_sf_128B,                // llvm.hexagon.V6.vconv.w.sf.128B
    hexagon_V6_vcvt_b_hf,                      // llvm.hexagon.V6.vcvt.b.hf
    hexagon_V6_vcvt_b_hf_128B,                 // llvm.hexagon.V6.vcvt.b.hf.128B
    hexagon_V6_vcvt_bf_sf,                     // llvm.hexagon.V6.vcvt.bf.sf
    hexagon_V6_vcvt_bf_sf_128B,                // llvm.hexagon.V6.vcvt.bf.sf.128B
    hexagon_V6_vcvt_f8_hf,                     // llvm.hexagon.V6.vcvt.f8.hf
    hexagon_V6_vcvt_f8_hf_128B,                // llvm.hexagon.V6.vcvt.f8.hf.128B
    hexagon_V6_vcvt_h_hf,                      // llvm.hexagon.V6.vcvt.h.hf
    hexagon_V6_vcvt_h_hf_128B,                 // llvm.hexagon.V6.vcvt.h.hf.128B
    hexagon_V6_vcvt_hf_b,                      // llvm.hexagon.V6.vcvt.hf.b
    hexagon_V6_vcvt_hf_b_128B,                 // llvm.hexagon.V6.vcvt.hf.b.128B
    hexagon_V6_vcvt_hf_f8,                     // llvm.hexagon.V6.vcvt.hf.f8
    hexagon_V6_vcvt_hf_f8_128B,                // llvm.hexagon.V6.vcvt.hf.f8.128B
    hexagon_V6_vcvt_hf_h,                      // llvm.hexagon.V6.vcvt.hf.h
    hexagon_V6_vcvt_hf_h_128B,                 // llvm.hexagon.V6.vcvt.hf.h.128B
    hexagon_V6_vcvt_hf_sf,                     // llvm.hexagon.V6.vcvt.hf.sf
    hexagon_V6_vcvt_hf_sf_128B,                // llvm.hexagon.V6.vcvt.hf.sf.128B
    hexagon_V6_vcvt_hf_ub,                     // llvm.hexagon.V6.vcvt.hf.ub
    hexagon_V6_vcvt_hf_ub_128B,                // llvm.hexagon.V6.vcvt.hf.ub.128B
    hexagon_V6_vcvt_hf_uh,                     // llvm.hexagon.V6.vcvt.hf.uh
    hexagon_V6_vcvt_hf_uh_128B,                // llvm.hexagon.V6.vcvt.hf.uh.128B
    hexagon_V6_vcvt_sf_hf,                     // llvm.hexagon.V6.vcvt.sf.hf
    hexagon_V6_vcvt_sf_hf_128B,                // llvm.hexagon.V6.vcvt.sf.hf.128B
    hexagon_V6_vcvt_ub_hf,                     // llvm.hexagon.V6.vcvt.ub.hf
    hexagon_V6_vcvt_ub_hf_128B,                // llvm.hexagon.V6.vcvt.ub.hf.128B
    hexagon_V6_vcvt_uh_hf,                     // llvm.hexagon.V6.vcvt.uh.hf
    hexagon_V6_vcvt_uh_hf_128B,                // llvm.hexagon.V6.vcvt.uh.hf.128B
    hexagon_V6_vcvt2_b_hf,                     // llvm.hexagon.V6.vcvt2.b.hf
    hexagon_V6_vcvt2_b_hf_128B,                // llvm.hexagon.V6.vcvt2.b.hf.128B
    hexagon_V6_vcvt2_hf_b,                     // llvm.hexagon.V6.vcvt2.hf.b
    hexagon_V6_vcvt2_hf_b_128B,                // llvm.hexagon.V6.vcvt2.hf.b.128B
    hexagon_V6_vcvt2_hf_ub,                    // llvm.hexagon.V6.vcvt2.hf.ub
    hexagon_V6_vcvt2_hf_ub_128B,               // llvm.hexagon.V6.vcvt2.hf.ub.128B
    hexagon_V6_vcvt2_ub_hf,                    // llvm.hexagon.V6.vcvt2.ub.hf
    hexagon_V6_vcvt2_ub_hf_128B,               // llvm.hexagon.V6.vcvt2.ub.hf.128B
    hexagon_V6_vd0,                            // llvm.hexagon.V6.vd0
    hexagon_V6_vd0_128B,                       // llvm.hexagon.V6.vd0.128B
    hexagon_V6_vdd0,                           // llvm.hexagon.V6.vdd0
    hexagon_V6_vdd0_128B,                      // llvm.hexagon.V6.vdd0.128B
    hexagon_V6_vdealb,                         // llvm.hexagon.V6.vdealb
    hexagon_V6_vdealb_128B,                    // llvm.hexagon.V6.vdealb.128B
    hexagon_V6_vdealb4w,                       // llvm.hexagon.V6.vdealb4w
    hexagon_V6_vdealb4w_128B,                  // llvm.hexagon.V6.vdealb4w.128B
    hexagon_V6_vdealh,                         // llvm.hexagon.V6.vdealh
    hexagon_V6_vdealh_128B,                    // llvm.hexagon.V6.vdealh.128B
    hexagon_V6_vdealvdd,                       // llvm.hexagon.V6.vdealvdd
    hexagon_V6_vdealvdd_128B,                  // llvm.hexagon.V6.vdealvdd.128B
    hexagon_V6_vdelta,                         // llvm.hexagon.V6.vdelta
    hexagon_V6_vdelta_128B,                    // llvm.hexagon.V6.vdelta.128B
    hexagon_V6_vdmpy_sf_hf,                    // llvm.hexagon.V6.vdmpy.sf.hf
    hexagon_V6_vdmpy_sf_hf_128B,               // llvm.hexagon.V6.vdmpy.sf.hf.128B
    hexagon_V6_vdmpy_sf_hf_acc,                // llvm.hexagon.V6.vdmpy.sf.hf.acc
    hexagon_V6_vdmpy_sf_hf_acc_128B,           // llvm.hexagon.V6.vdmpy.sf.hf.acc.128B
    hexagon_V6_vdmpybus,                       // llvm.hexagon.V6.vdmpybus
    hexagon_V6_vdmpybus_128B,                  // llvm.hexagon.V6.vdmpybus.128B
    hexagon_V6_vdmpybus_acc,                   // llvm.hexagon.V6.vdmpybus.acc
    hexagon_V6_vdmpybus_acc_128B,              // llvm.hexagon.V6.vdmpybus.acc.128B
    hexagon_V6_vdmpybus_dv,                    // llvm.hexagon.V6.vdmpybus.dv
    hexagon_V6_vdmpybus_dv_128B,               // llvm.hexagon.V6.vdmpybus.dv.128B
    hexagon_V6_vdmpybus_dv_acc,                // llvm.hexagon.V6.vdmpybus.dv.acc
    hexagon_V6_vdmpybus_dv_acc_128B,           // llvm.hexagon.V6.vdmpybus.dv.acc.128B
    hexagon_V6_vdmpyhb,                        // llvm.hexagon.V6.vdmpyhb
    hexagon_V6_vdmpyhb_128B,                   // llvm.hexagon.V6.vdmpyhb.128B
    hexagon_V6_vdmpyhb_acc,                    // llvm.hexagon.V6.vdmpyhb.acc
    hexagon_V6_vdmpyhb_acc_128B,               // llvm.hexagon.V6.vdmpyhb.acc.128B
    hexagon_V6_vdmpyhb_dv,                     // llvm.hexagon.V6.vdmpyhb.dv
    hexagon_V6_vdmpyhb_dv_128B,                // llvm.hexagon.V6.vdmpyhb.dv.128B
    hexagon_V6_vdmpyhb_dv_acc,                 // llvm.hexagon.V6.vdmpyhb.dv.acc
    hexagon_V6_vdmpyhb_dv_acc_128B,            // llvm.hexagon.V6.vdmpyhb.dv.acc.128B
    hexagon_V6_vdmpyhisat,                     // llvm.hexagon.V6.vdmpyhisat
    hexagon_V6_vdmpyhisat_128B,                // llvm.hexagon.V6.vdmpyhisat.128B
    hexagon_V6_vdmpyhisat_acc,                 // llvm.hexagon.V6.vdmpyhisat.acc
    hexagon_V6_vdmpyhisat_acc_128B,            // llvm.hexagon.V6.vdmpyhisat.acc.128B
    hexagon_V6_vdmpyhsat,                      // llvm.hexagon.V6.vdmpyhsat
    hexagon_V6_vdmpyhsat_128B,                 // llvm.hexagon.V6.vdmpyhsat.128B
    hexagon_V6_vdmpyhsat_acc,                  // llvm.hexagon.V6.vdmpyhsat.acc
    hexagon_V6_vdmpyhsat_acc_128B,             // llvm.hexagon.V6.vdmpyhsat.acc.128B
    hexagon_V6_vdmpyhsuisat,                   // llvm.hexagon.V6.vdmpyhsuisat
    hexagon_V6_vdmpyhsuisat_128B,              // llvm.hexagon.V6.vdmpyhsuisat.128B
    hexagon_V6_vdmpyhsuisat_acc,               // llvm.hexagon.V6.vdmpyhsuisat.acc
    hexagon_V6_vdmpyhsuisat_acc_128B,          // llvm.hexagon.V6.vdmpyhsuisat.acc.128B
    hexagon_V6_vdmpyhsusat,                    // llvm.hexagon.V6.vdmpyhsusat
    hexagon_V6_vdmpyhsusat_128B,               // llvm.hexagon.V6.vdmpyhsusat.128B
    hexagon_V6_vdmpyhsusat_acc,                // llvm.hexagon.V6.vdmpyhsusat.acc
    hexagon_V6_vdmpyhsusat_acc_128B,           // llvm.hexagon.V6.vdmpyhsusat.acc.128B
    hexagon_V6_vdmpyhvsat,                     // llvm.hexagon.V6.vdmpyhvsat
    hexagon_V6_vdmpyhvsat_128B,                // llvm.hexagon.V6.vdmpyhvsat.128B
    hexagon_V6_vdmpyhvsat_acc,                 // llvm.hexagon.V6.vdmpyhvsat.acc
    hexagon_V6_vdmpyhvsat_acc_128B,            // llvm.hexagon.V6.vdmpyhvsat.acc.128B
    hexagon_V6_vdsaduh,                        // llvm.hexagon.V6.vdsaduh
    hexagon_V6_vdsaduh_128B,                   // llvm.hexagon.V6.vdsaduh.128B
    hexagon_V6_vdsaduh_acc,                    // llvm.hexagon.V6.vdsaduh.acc
    hexagon_V6_vdsaduh_acc_128B,               // llvm.hexagon.V6.vdsaduh.acc.128B
    hexagon_V6_veqb,                           // llvm.hexagon.V6.veqb
    hexagon_V6_veqb_128B,                      // llvm.hexagon.V6.veqb.128B
    hexagon_V6_veqb_and,                       // llvm.hexagon.V6.veqb.and
    hexagon_V6_veqb_and_128B,                  // llvm.hexagon.V6.veqb.and.128B
    hexagon_V6_veqb_or,                        // llvm.hexagon.V6.veqb.or
    hexagon_V6_veqb_or_128B,                   // llvm.hexagon.V6.veqb.or.128B
    hexagon_V6_veqb_xor,                       // llvm.hexagon.V6.veqb.xor
    hexagon_V6_veqb_xor_128B,                  // llvm.hexagon.V6.veqb.xor.128B
    hexagon_V6_veqh,                           // llvm.hexagon.V6.veqh
    hexagon_V6_veqh_128B,                      // llvm.hexagon.V6.veqh.128B
    hexagon_V6_veqh_and,                       // llvm.hexagon.V6.veqh.and
    hexagon_V6_veqh_and_128B,                  // llvm.hexagon.V6.veqh.and.128B
    hexagon_V6_veqh_or,                        // llvm.hexagon.V6.veqh.or
    hexagon_V6_veqh_or_128B,                   // llvm.hexagon.V6.veqh.or.128B
    hexagon_V6_veqh_xor,                       // llvm.hexagon.V6.veqh.xor
    hexagon_V6_veqh_xor_128B,                  // llvm.hexagon.V6.veqh.xor.128B
    hexagon_V6_veqw,                           // llvm.hexagon.V6.veqw
    hexagon_V6_veqw_128B,                      // llvm.hexagon.V6.veqw.128B
    hexagon_V6_veqw_and,                       // llvm.hexagon.V6.veqw.and
    hexagon_V6_veqw_and_128B,                  // llvm.hexagon.V6.veqw.and.128B
    hexagon_V6_veqw_or,                        // llvm.hexagon.V6.veqw.or
    hexagon_V6_veqw_or_128B,                   // llvm.hexagon.V6.veqw.or.128B
    hexagon_V6_veqw_xor,                       // llvm.hexagon.V6.veqw.xor
    hexagon_V6_veqw_xor_128B,                  // llvm.hexagon.V6.veqw.xor.128B
    hexagon_V6_vfmax_f8,                       // llvm.hexagon.V6.vfmax.f8
    hexagon_V6_vfmax_f8_128B,                  // llvm.hexagon.V6.vfmax.f8.128B
    hexagon_V6_vfmax_hf,                       // llvm.hexagon.V6.vfmax.hf
    hexagon_V6_vfmax_hf_128B,                  // llvm.hexagon.V6.vfmax.hf.128B
    hexagon_V6_vfmax_sf,                       // llvm.hexagon.V6.vfmax.sf
    hexagon_V6_vfmax_sf_128B,                  // llvm.hexagon.V6.vfmax.sf.128B
    hexagon_V6_vfmin_f8,                       // llvm.hexagon.V6.vfmin.f8
    hexagon_V6_vfmin_f8_128B,                  // llvm.hexagon.V6.vfmin.f8.128B
    hexagon_V6_vfmin_hf,                       // llvm.hexagon.V6.vfmin.hf
    hexagon_V6_vfmin_hf_128B,                  // llvm.hexagon.V6.vfmin.hf.128B
    hexagon_V6_vfmin_sf,                       // llvm.hexagon.V6.vfmin.sf
    hexagon_V6_vfmin_sf_128B,                  // llvm.hexagon.V6.vfmin.sf.128B
    hexagon_V6_vfneg_f8,                       // llvm.hexagon.V6.vfneg.f8
    hexagon_V6_vfneg_f8_128B,                  // llvm.hexagon.V6.vfneg.f8.128B
    hexagon_V6_vfneg_hf,                       // llvm.hexagon.V6.vfneg.hf
    hexagon_V6_vfneg_hf_128B,                  // llvm.hexagon.V6.vfneg.hf.128B
    hexagon_V6_vfneg_sf,                       // llvm.hexagon.V6.vfneg.sf
    hexagon_V6_vfneg_sf_128B,                  // llvm.hexagon.V6.vfneg.sf.128B
    hexagon_V6_vgathermh,                      // llvm.hexagon.V6.vgathermh
    hexagon_V6_vgathermh_128B,                 // llvm.hexagon.V6.vgathermh.128B
    hexagon_V6_vgathermhq,                     // llvm.hexagon.V6.vgathermhq
    hexagon_V6_vgathermhq_128B,                // llvm.hexagon.V6.vgathermhq.128B
    hexagon_V6_vgathermhw,                     // llvm.hexagon.V6.vgathermhw
    hexagon_V6_vgathermhw_128B,                // llvm.hexagon.V6.vgathermhw.128B
    hexagon_V6_vgathermhwq,                    // llvm.hexagon.V6.vgathermhwq
    hexagon_V6_vgathermhwq_128B,               // llvm.hexagon.V6.vgathermhwq.128B
    hexagon_V6_vgathermw,                      // llvm.hexagon.V6.vgathermw
    hexagon_V6_vgathermw_128B,                 // llvm.hexagon.V6.vgathermw.128B
    hexagon_V6_vgathermwq,                     // llvm.hexagon.V6.vgathermwq
    hexagon_V6_vgathermwq_128B,                // llvm.hexagon.V6.vgathermwq.128B
    hexagon_V6_vgtb,                           // llvm.hexagon.V6.vgtb
    hexagon_V6_vgtb_128B,                      // llvm.hexagon.V6.vgtb.128B
    hexagon_V6_vgtb_and,                       // llvm.hexagon.V6.vgtb.and
    hexagon_V6_vgtb_and_128B,                  // llvm.hexagon.V6.vgtb.and.128B
    hexagon_V6_vgtb_or,                        // llvm.hexagon.V6.vgtb.or
    hexagon_V6_vgtb_or_128B,                   // llvm.hexagon.V6.vgtb.or.128B
    hexagon_V6_vgtb_xor,                       // llvm.hexagon.V6.vgtb.xor
    hexagon_V6_vgtb_xor_128B,                  // llvm.hexagon.V6.vgtb.xor.128B
    hexagon_V6_vgtbf,                          // llvm.hexagon.V6.vgtbf
    hexagon_V6_vgtbf_128B,                     // llvm.hexagon.V6.vgtbf.128B
    hexagon_V6_vgtbf_and,                      // llvm.hexagon.V6.vgtbf.and
    hexagon_V6_vgtbf_and_128B,                 // llvm.hexagon.V6.vgtbf.and.128B
    hexagon_V6_vgtbf_or,                       // llvm.hexagon.V6.vgtbf.or
    hexagon_V6_vgtbf_or_128B,                  // llvm.hexagon.V6.vgtbf.or.128B
    hexagon_V6_vgtbf_xor,                      // llvm.hexagon.V6.vgtbf.xor
    hexagon_V6_vgtbf_xor_128B,                 // llvm.hexagon.V6.vgtbf.xor.128B
    hexagon_V6_vgth,                           // llvm.hexagon.V6.vgth
    hexagon_V6_vgth_128B,                      // llvm.hexagon.V6.vgth.128B
    hexagon_V6_vgth_and,                       // llvm.hexagon.V6.vgth.and
    hexagon_V6_vgth_and_128B,                  // llvm.hexagon.V6.vgth.and.128B
    hexagon_V6_vgth_or,                        // llvm.hexagon.V6.vgth.or
    hexagon_V6_vgth_or_128B,                   // llvm.hexagon.V6.vgth.or.128B
    hexagon_V6_vgth_xor,                       // llvm.hexagon.V6.vgth.xor
    hexagon_V6_vgth_xor_128B,                  // llvm.hexagon.V6.vgth.xor.128B
    hexagon_V6_vgthf,                          // llvm.hexagon.V6.vgthf
    hexagon_V6_vgthf_128B,                     // llvm.hexagon.V6.vgthf.128B
    hexagon_V6_vgthf_and,                      // llvm.hexagon.V6.vgthf.and
    hexagon_V6_vgthf_and_128B,                 // llvm.hexagon.V6.vgthf.and.128B
    hexagon_V6_vgthf_or,                       // llvm.hexagon.V6.vgthf.or
    hexagon_V6_vgthf_or_128B,                  // llvm.hexagon.V6.vgthf.or.128B
    hexagon_V6_vgthf_xor,                      // llvm.hexagon.V6.vgthf.xor
    hexagon_V6_vgthf_xor_128B,                 // llvm.hexagon.V6.vgthf.xor.128B
    hexagon_V6_vgtsf,                          // llvm.hexagon.V6.vgtsf
    hexagon_V6_vgtsf_128B,                     // llvm.hexagon.V6.vgtsf.128B
    hexagon_V6_vgtsf_and,                      // llvm.hexagon.V6.vgtsf.and
    hexagon_V6_vgtsf_and_128B,                 // llvm.hexagon.V6.vgtsf.and.128B
    hexagon_V6_vgtsf_or,                       // llvm.hexagon.V6.vgtsf.or
    hexagon_V6_vgtsf_or_128B,                  // llvm.hexagon.V6.vgtsf.or.128B
    hexagon_V6_vgtsf_xor,                      // llvm.hexagon.V6.vgtsf.xor
    hexagon_V6_vgtsf_xor_128B,                 // llvm.hexagon.V6.vgtsf.xor.128B
    hexagon_V6_vgtub,                          // llvm.hexagon.V6.vgtub
    hexagon_V6_vgtub_128B,                     // llvm.hexagon.V6.vgtub.128B
    hexagon_V6_vgtub_and,                      // llvm.hexagon.V6.vgtub.and
    hexagon_V6_vgtub_and_128B,                 // llvm.hexagon.V6.vgtub.and.128B
    hexagon_V6_vgtub_or,                       // llvm.hexagon.V6.vgtub.or
    hexagon_V6_vgtub_or_128B,                  // llvm.hexagon.V6.vgtub.or.128B
    hexagon_V6_vgtub_xor,                      // llvm.hexagon.V6.vgtub.xor
    hexagon_V6_vgtub_xor_128B,                 // llvm.hexagon.V6.vgtub.xor.128B
    hexagon_V6_vgtuh,                          // llvm.hexagon.V6.vgtuh
    hexagon_V6_vgtuh_128B,                     // llvm.hexagon.V6.vgtuh.128B
    hexagon_V6_vgtuh_and,                      // llvm.hexagon.V6.vgtuh.and
    hexagon_V6_vgtuh_and_128B,                 // llvm.hexagon.V6.vgtuh.and.128B
    hexagon_V6_vgtuh_or,                       // llvm.hexagon.V6.vgtuh.or
    hexagon_V6_vgtuh_or_128B,                  // llvm.hexagon.V6.vgtuh.or.128B
    hexagon_V6_vgtuh_xor,                      // llvm.hexagon.V6.vgtuh.xor
    hexagon_V6_vgtuh_xor_128B,                 // llvm.hexagon.V6.vgtuh.xor.128B
    hexagon_V6_vgtuw,                          // llvm.hexagon.V6.vgtuw
    hexagon_V6_vgtuw_128B,                     // llvm.hexagon.V6.vgtuw.128B
    hexagon_V6_vgtuw_and,                      // llvm.hexagon.V6.vgtuw.and
    hexagon_V6_vgtuw_and_128B,                 // llvm.hexagon.V6.vgtuw.and.128B
    hexagon_V6_vgtuw_or,                       // llvm.hexagon.V6.vgtuw.or
    hexagon_V6_vgtuw_or_128B,                  // llvm.hexagon.V6.vgtuw.or.128B
    hexagon_V6_vgtuw_xor,                      // llvm.hexagon.V6.vgtuw.xor
    hexagon_V6_vgtuw_xor_128B,                 // llvm.hexagon.V6.vgtuw.xor.128B
    hexagon_V6_vgtw,                           // llvm.hexagon.V6.vgtw
    hexagon_V6_vgtw_128B,                      // llvm.hexagon.V6.vgtw.128B
    hexagon_V6_vgtw_and,                       // llvm.hexagon.V6.vgtw.and
    hexagon_V6_vgtw_and_128B,                  // llvm.hexagon.V6.vgtw.and.128B
    hexagon_V6_vgtw_or,                        // llvm.hexagon.V6.vgtw.or
    hexagon_V6_vgtw_or_128B,                   // llvm.hexagon.V6.vgtw.or.128B
    hexagon_V6_vgtw_xor,                       // llvm.hexagon.V6.vgtw.xor
    hexagon_V6_vgtw_xor_128B,                  // llvm.hexagon.V6.vgtw.xor.128B
    hexagon_V6_vinsertwr,                      // llvm.hexagon.V6.vinsertwr
    hexagon_V6_vinsertwr_128B,                 // llvm.hexagon.V6.vinsertwr.128B
    hexagon_V6_vlalignb,                       // llvm.hexagon.V6.vlalignb
    hexagon_V6_vlalignb_128B,                  // llvm.hexagon.V6.vlalignb.128B
    hexagon_V6_vlalignbi,                      // llvm.hexagon.V6.vlalignbi
    hexagon_V6_vlalignbi_128B,                 // llvm.hexagon.V6.vlalignbi.128B
    hexagon_V6_vlsrb,                          // llvm.hexagon.V6.vlsrb
    hexagon_V6_vlsrb_128B,                     // llvm.hexagon.V6.vlsrb.128B
    hexagon_V6_vlsrh,                          // llvm.hexagon.V6.vlsrh
    hexagon_V6_vlsrh_128B,                     // llvm.hexagon.V6.vlsrh.128B
    hexagon_V6_vlsrhv,                         // llvm.hexagon.V6.vlsrhv
    hexagon_V6_vlsrhv_128B,                    // llvm.hexagon.V6.vlsrhv.128B
    hexagon_V6_vlsrw,                          // llvm.hexagon.V6.vlsrw
    hexagon_V6_vlsrw_128B,                     // llvm.hexagon.V6.vlsrw.128B
    hexagon_V6_vlsrwv,                         // llvm.hexagon.V6.vlsrwv
    hexagon_V6_vlsrwv_128B,                    // llvm.hexagon.V6.vlsrwv.128B
    hexagon_V6_vlut4,                          // llvm.hexagon.V6.vlut4
    hexagon_V6_vlut4_128B,                     // llvm.hexagon.V6.vlut4.128B
    hexagon_V6_vlutvvb,                        // llvm.hexagon.V6.vlutvvb
    hexagon_V6_vlutvvb_128B,                   // llvm.hexagon.V6.vlutvvb.128B
    hexagon_V6_vlutvvb_nm,                     // llvm.hexagon.V6.vlutvvb.nm
    hexagon_V6_vlutvvb_nm_128B,                // llvm.hexagon.V6.vlutvvb.nm.128B
    hexagon_V6_vlutvvb_oracc,                  // llvm.hexagon.V6.vlutvvb.oracc
    hexagon_V6_vlutvvb_oracc_128B,             // llvm.hexagon.V6.vlutvvb.oracc.128B
    hexagon_V6_vlutvvb_oracci,                 // llvm.hexagon.V6.vlutvvb.oracci
    hexagon_V6_vlutvvb_oracci_128B,            // llvm.hexagon.V6.vlutvvb.oracci.128B
    hexagon_V6_vlutvvbi,                       // llvm.hexagon.V6.vlutvvbi
    hexagon_V6_vlutvvbi_128B,                  // llvm.hexagon.V6.vlutvvbi.128B
    hexagon_V6_vlutvwh,                        // llvm.hexagon.V6.vlutvwh
    hexagon_V6_vlutvwh_128B,                   // llvm.hexagon.V6.vlutvwh.128B
    hexagon_V6_vlutvwh_nm,                     // llvm.hexagon.V6.vlutvwh.nm
    hexagon_V6_vlutvwh_nm_128B,                // llvm.hexagon.V6.vlutvwh.nm.128B
    hexagon_V6_vlutvwh_oracc,                  // llvm.hexagon.V6.vlutvwh.oracc
    hexagon_V6_vlutvwh_oracc_128B,             // llvm.hexagon.V6.vlutvwh.oracc.128B
    hexagon_V6_vlutvwh_oracci,                 // llvm.hexagon.V6.vlutvwh.oracci
    hexagon_V6_vlutvwh_oracci_128B,            // llvm.hexagon.V6.vlutvwh.oracci.128B
    hexagon_V6_vlutvwhi,                       // llvm.hexagon.V6.vlutvwhi
    hexagon_V6_vlutvwhi_128B,                  // llvm.hexagon.V6.vlutvwhi.128B
    hexagon_V6_vmaskedstorenq,                 // llvm.hexagon.V6.vmaskedstorenq
    hexagon_V6_vmaskedstorenq_128B,            // llvm.hexagon.V6.vmaskedstorenq.128B
    hexagon_V6_vmaskedstorentnq,               // llvm.hexagon.V6.vmaskedstorentnq
    hexagon_V6_vmaskedstorentnq_128B,          // llvm.hexagon.V6.vmaskedstorentnq.128B
    hexagon_V6_vmaskedstorentq,                // llvm.hexagon.V6.vmaskedstorentq
    hexagon_V6_vmaskedstorentq_128B,           // llvm.hexagon.V6.vmaskedstorentq.128B
    hexagon_V6_vmaskedstoreq,                  // llvm.hexagon.V6.vmaskedstoreq
    hexagon_V6_vmaskedstoreq_128B,             // llvm.hexagon.V6.vmaskedstoreq.128B
    hexagon_V6_vmax_bf,                        // llvm.hexagon.V6.vmax.bf
    hexagon_V6_vmax_bf_128B,                   // llvm.hexagon.V6.vmax.bf.128B
    hexagon_V6_vmax_hf,                        // llvm.hexagon.V6.vmax.hf
    hexagon_V6_vmax_hf_128B,                   // llvm.hexagon.V6.vmax.hf.128B
    hexagon_V6_vmax_sf,                        // llvm.hexagon.V6.vmax.sf
    hexagon_V6_vmax_sf_128B,                   // llvm.hexagon.V6.vmax.sf.128B
    hexagon_V6_vmaxb,                          // llvm.hexagon.V6.vmaxb
    hexagon_V6_vmaxb_128B,                     // llvm.hexagon.V6.vmaxb.128B
    hexagon_V6_vmaxh,                          // llvm.hexagon.V6.vmaxh
    hexagon_V6_vmaxh_128B,                     // llvm.hexagon.V6.vmaxh.128B
    hexagon_V6_vmaxub,                         // llvm.hexagon.V6.vmaxub
    hexagon_V6_vmaxub_128B,                    // llvm.hexagon.V6.vmaxub.128B
    hexagon_V6_vmaxuh,                         // llvm.hexagon.V6.vmaxuh
    hexagon_V6_vmaxuh_128B,                    // llvm.hexagon.V6.vmaxuh.128B
    hexagon_V6_vmaxw,                          // llvm.hexagon.V6.vmaxw
    hexagon_V6_vmaxw_128B,                     // llvm.hexagon.V6.vmaxw.128B
    hexagon_V6_vmerge_qf,                      // llvm.hexagon.V6.vmerge.qf
    hexagon_V6_vmerge_qf_128B,                 // llvm.hexagon.V6.vmerge.qf.128B
    hexagon_V6_vmin_bf,                        // llvm.hexagon.V6.vmin.bf
    hexagon_V6_vmin_bf_128B,                   // llvm.hexagon.V6.vmin.bf.128B
    hexagon_V6_vmin_hf,                        // llvm.hexagon.V6.vmin.hf
    hexagon_V6_vmin_hf_128B,                   // llvm.hexagon.V6.vmin.hf.128B
    hexagon_V6_vmin_sf,                        // llvm.hexagon.V6.vmin.sf
    hexagon_V6_vmin_sf_128B,                   // llvm.hexagon.V6.vmin.sf.128B
    hexagon_V6_vminb,                          // llvm.hexagon.V6.vminb
    hexagon_V6_vminb_128B,                     // llvm.hexagon.V6.vminb.128B
    hexagon_V6_vminh,                          // llvm.hexagon.V6.vminh
    hexagon_V6_vminh_128B,                     // llvm.hexagon.V6.vminh.128B
    hexagon_V6_vminub,                         // llvm.hexagon.V6.vminub
    hexagon_V6_vminub_128B,                    // llvm.hexagon.V6.vminub.128B
    hexagon_V6_vminuh,                         // llvm.hexagon.V6.vminuh
    hexagon_V6_vminuh_128B,                    // llvm.hexagon.V6.vminuh.128B
    hexagon_V6_vminw,                          // llvm.hexagon.V6.vminw
    hexagon_V6_vminw_128B,                     // llvm.hexagon.V6.vminw.128B
    hexagon_V6_vmpabus,                        // llvm.hexagon.V6.vmpabus
    hexagon_V6_vmpabus_128B,                   // llvm.hexagon.V6.vmpabus.128B
    hexagon_V6_vmpabus_acc,                    // llvm.hexagon.V6.vmpabus.acc
    hexagon_V6_vmpabus_acc_128B,               // llvm.hexagon.V6.vmpabus.acc.128B
    hexagon_V6_vmpabusv,                       // llvm.hexagon.V6.vmpabusv
    hexagon_V6_vmpabusv_128B,                  // llvm.hexagon.V6.vmpabusv.128B
    hexagon_V6_vmpabuu,                        // llvm.hexagon.V6.vmpabuu
    hexagon_V6_vmpabuu_128B,                   // llvm.hexagon.V6.vmpabuu.128B
    hexagon_V6_vmpabuu_acc,                    // llvm.hexagon.V6.vmpabuu.acc
    hexagon_V6_vmpabuu_acc_128B,               // llvm.hexagon.V6.vmpabuu.acc.128B
    hexagon_V6_vmpabuuv,                       // llvm.hexagon.V6.vmpabuuv
    hexagon_V6_vmpabuuv_128B,                  // llvm.hexagon.V6.vmpabuuv.128B
    hexagon_V6_vmpahb,                         // llvm.hexagon.V6.vmpahb
    hexagon_V6_vmpahb_128B,                    // llvm.hexagon.V6.vmpahb.128B
    hexagon_V6_vmpahb_acc,                     // llvm.hexagon.V6.vmpahb.acc
    hexagon_V6_vmpahb_acc_128B,                // llvm.hexagon.V6.vmpahb.acc.128B
    hexagon_V6_vmpahhsat,                      // llvm.hexagon.V6.vmpahhsat
    hexagon_V6_vmpahhsat_128B,                 // llvm.hexagon.V6.vmpahhsat.128B
    hexagon_V6_vmpauhb,                        // llvm.hexagon.V6.vmpauhb
    hexagon_V6_vmpauhb_128B,                   // llvm.hexagon.V6.vmpauhb.128B
    hexagon_V6_vmpauhb_acc,                    // llvm.hexagon.V6.vmpauhb.acc
    hexagon_V6_vmpauhb_acc_128B,               // llvm.hexagon.V6.vmpauhb.acc.128B
    hexagon_V6_vmpauhuhsat,                    // llvm.hexagon.V6.vmpauhuhsat
    hexagon_V6_vmpauhuhsat_128B,               // llvm.hexagon.V6.vmpauhuhsat.128B
    hexagon_V6_vmpsuhuhsat,                    // llvm.hexagon.V6.vmpsuhuhsat
    hexagon_V6_vmpsuhuhsat_128B,               // llvm.hexagon.V6.vmpsuhuhsat.128B
    hexagon_V6_vmpy_hf_f8,                     // llvm.hexagon.V6.vmpy.hf.f8
    hexagon_V6_vmpy_hf_f8_128B,                // llvm.hexagon.V6.vmpy.hf.f8.128B
    hexagon_V6_vmpy_hf_f8_acc,                 // llvm.hexagon.V6.vmpy.hf.f8.acc
    hexagon_V6_vmpy_hf_f8_acc_128B,            // llvm.hexagon.V6.vmpy.hf.f8.acc.128B
    hexagon_V6_vmpy_hf_hf,                     // llvm.hexagon.V6.vmpy.hf.hf
    hexagon_V6_vmpy_hf_hf_128B,                // llvm.hexagon.V6.vmpy.hf.hf.128B
    hexagon_V6_vmpy_hf_hf_acc,                 // llvm.hexagon.V6.vmpy.hf.hf.acc
    hexagon_V6_vmpy_hf_hf_acc_128B,            // llvm.hexagon.V6.vmpy.hf.hf.acc.128B
    hexagon_V6_vmpy_qf16,                      // llvm.hexagon.V6.vmpy.qf16
    hexagon_V6_vmpy_qf16_128B,                 // llvm.hexagon.V6.vmpy.qf16.128B
    hexagon_V6_vmpy_qf16_hf,                   // llvm.hexagon.V6.vmpy.qf16.hf
    hexagon_V6_vmpy_qf16_hf_128B,              // llvm.hexagon.V6.vmpy.qf16.hf.128B
    hexagon_V6_vmpy_qf16_mix_hf,               // llvm.hexagon.V6.vmpy.qf16.mix.hf
    hexagon_V6_vmpy_qf16_mix_hf_128B,          // llvm.hexagon.V6.vmpy.qf16.mix.hf.128B
    hexagon_V6_vmpy_qf32,                      // llvm.hexagon.V6.vmpy.qf32
    hexagon_V6_vmpy_qf32_128B,                 // llvm.hexagon.V6.vmpy.qf32.128B
    hexagon_V6_vmpy_qf32_hf,                   // llvm.hexagon.V6.vmpy.qf32.hf
    hexagon_V6_vmpy_qf32_hf_128B,              // llvm.hexagon.V6.vmpy.qf32.hf.128B
    hexagon_V6_vmpy_qf32_mix_hf,               // llvm.hexagon.V6.vmpy.qf32.mix.hf
    hexagon_V6_vmpy_qf32_mix_hf_128B,          // llvm.hexagon.V6.vmpy.qf32.mix.hf.128B
    hexagon_V6_vmpy_qf32_qf16,                 // llvm.hexagon.V6.vmpy.qf32.qf16
    hexagon_V6_vmpy_qf32_qf16_128B,            // llvm.hexagon.V6.vmpy.qf32.qf16.128B
    hexagon_V6_vmpy_qf32_sf,                   // llvm.hexagon.V6.vmpy.qf32.sf
    hexagon_V6_vmpy_qf32_sf_128B,              // llvm.hexagon.V6.vmpy.qf32.sf.128B
    hexagon_V6_vmpy_rt_hf,                     // llvm.hexagon.V6.vmpy.rt.hf
    hexagon_V6_vmpy_rt_hf_128B,                // llvm.hexagon.V6.vmpy.rt.hf.128B
    hexagon_V6_vmpy_rt_qf16,                   // llvm.hexagon.V6.vmpy.rt.qf16
    hexagon_V6_vmpy_rt_qf16_128B,              // llvm.hexagon.V6.vmpy.rt.qf16.128B
    hexagon_V6_vmpy_rt_sf,                     // llvm.hexagon.V6.vmpy.rt.sf
    hexagon_V6_vmpy_rt_sf_128B,                // llvm.hexagon.V6.vmpy.rt.sf.128B
    hexagon_V6_vmpy_sf_bf,                     // llvm.hexagon.V6.vmpy.sf.bf
    hexagon_V6_vmpy_sf_bf_128B,                // llvm.hexagon.V6.vmpy.sf.bf.128B
    hexagon_V6_vmpy_sf_bf_acc,                 // llvm.hexagon.V6.vmpy.sf.bf.acc
    hexagon_V6_vmpy_sf_bf_acc_128B,            // llvm.hexagon.V6.vmpy.sf.bf.acc.128B
    hexagon_V6_vmpy_sf_hf,                     // llvm.hexagon.V6.vmpy.sf.hf
    hexagon_V6_vmpy_sf_hf_128B,                // llvm.hexagon.V6.vmpy.sf.hf.128B
    hexagon_V6_vmpy_sf_hf_acc,                 // llvm.hexagon.V6.vmpy.sf.hf.acc
    hexagon_V6_vmpy_sf_hf_acc_128B,            // llvm.hexagon.V6.vmpy.sf.hf.acc.128B
    hexagon_V6_vmpy_sf_sf,                     // llvm.hexagon.V6.vmpy.sf.sf
    hexagon_V6_vmpy_sf_sf_128B,                // llvm.hexagon.V6.vmpy.sf.sf.128B
    hexagon_V6_vmpybus,                        // llvm.hexagon.V6.vmpybus
    hexagon_V6_vmpybus_128B,                   // llvm.hexagon.V6.vmpybus.128B
    hexagon_V6_vmpybus_acc,                    // llvm.hexagon.V6.vmpybus.acc
    hexagon_V6_vmpybus_acc_128B,               // llvm.hexagon.V6.vmpybus.acc.128B
    hexagon_V6_vmpybusv,                       // llvm.hexagon.V6.vmpybusv
    hexagon_V6_vmpybusv_128B,                  // llvm.hexagon.V6.vmpybusv.128B
    hexagon_V6_vmpybusv_acc,                   // llvm.hexagon.V6.vmpybusv.acc
    hexagon_V6_vmpybusv_acc_128B,              // llvm.hexagon.V6.vmpybusv.acc.128B
    hexagon_V6_vmpybv,                         // llvm.hexagon.V6.vmpybv
    hexagon_V6_vmpybv_128B,                    // llvm.hexagon.V6.vmpybv.128B
    hexagon_V6_vmpybv_acc,                     // llvm.hexagon.V6.vmpybv.acc
    hexagon_V6_vmpybv_acc_128B,                // llvm.hexagon.V6.vmpybv.acc.128B
    hexagon_V6_vmpyewuh,                       // llvm.hexagon.V6.vmpyewuh
    hexagon_V6_vmpyewuh_128B,                  // llvm.hexagon.V6.vmpyewuh.128B
    hexagon_V6_vmpyewuh_64,                    // llvm.hexagon.V6.vmpyewuh.64
    hexagon_V6_vmpyewuh_64_128B,               // llvm.hexagon.V6.vmpyewuh.64.128B
    hexagon_V6_vmpyh,                          // llvm.hexagon.V6.vmpyh
    hexagon_V6_vmpyh_128B,                     // llvm.hexagon.V6.vmpyh.128B
    hexagon_V6_vmpyh_acc,                      // llvm.hexagon.V6.vmpyh.acc
    hexagon_V6_vmpyh_acc_128B,                 // llvm.hexagon.V6.vmpyh.acc.128B
    hexagon_V6_vmpyhsat_acc,                   // llvm.hexagon.V6.vmpyhsat.acc
    hexagon_V6_vmpyhsat_acc_128B,              // llvm.hexagon.V6.vmpyhsat.acc.128B
    hexagon_V6_vmpyhsrs,                       // llvm.hexagon.V6.vmpyhsrs
    hexagon_V6_vmpyhsrs_128B,                  // llvm.hexagon.V6.vmpyhsrs.128B
    hexagon_V6_vmpyhss,                        // llvm.hexagon.V6.vmpyhss
    hexagon_V6_vmpyhss_128B,                   // llvm.hexagon.V6.vmpyhss.128B
    hexagon_V6_vmpyhus,                        // llvm.hexagon.V6.vmpyhus
    hexagon_V6_vmpyhus_128B,                   // llvm.hexagon.V6.vmpyhus.128B
    hexagon_V6_vmpyhus_acc,                    // llvm.hexagon.V6.vmpyhus.acc
    hexagon_V6_vmpyhus_acc_128B,               // llvm.hexagon.V6.vmpyhus.acc.128B
    hexagon_V6_vmpyhv,                         // llvm.hexagon.V6.vmpyhv
    hexagon_V6_vmpyhv_128B,                    // llvm.hexagon.V6.vmpyhv.128B
    hexagon_V6_vmpyhv_acc,                     // llvm.hexagon.V6.vmpyhv.acc
    hexagon_V6_vmpyhv_acc_128B,                // llvm.hexagon.V6.vmpyhv.acc.128B
    hexagon_V6_vmpyhvsrs,                      // llvm.hexagon.V6.vmpyhvsrs
    hexagon_V6_vmpyhvsrs_128B,                 // llvm.hexagon.V6.vmpyhvsrs.128B
    hexagon_V6_vmpyieoh,                       // llvm.hexagon.V6.vmpyieoh
    hexagon_V6_vmpyieoh_128B,                  // llvm.hexagon.V6.vmpyieoh.128B
    hexagon_V6_vmpyiewh_acc,                   // llvm.hexagon.V6.vmpyiewh.acc
    hexagon_V6_vmpyiewh_acc_128B,              // llvm.hexagon.V6.vmpyiewh.acc.128B
    hexagon_V6_vmpyiewuh,                      // llvm.hexagon.V6.vmpyiewuh
    hexagon_V6_vmpyiewuh_128B,                 // llvm.hexagon.V6.vmpyiewuh.128B
    hexagon_V6_vmpyiewuh_acc,                  // llvm.hexagon.V6.vmpyiewuh.acc
    hexagon_V6_vmpyiewuh_acc_128B,             // llvm.hexagon.V6.vmpyiewuh.acc.128B
    hexagon_V6_vmpyih,                         // llvm.hexagon.V6.vmpyih
    hexagon_V6_vmpyih_128B,                    // llvm.hexagon.V6.vmpyih.128B
    hexagon_V6_vmpyih_acc,                     // llvm.hexagon.V6.vmpyih.acc
    hexagon_V6_vmpyih_acc_128B,                // llvm.hexagon.V6.vmpyih.acc.128B
    hexagon_V6_vmpyihb,                        // llvm.hexagon.V6.vmpyihb
    hexagon_V6_vmpyihb_128B,                   // llvm.hexagon.V6.vmpyihb.128B
    hexagon_V6_vmpyihb_acc,                    // llvm.hexagon.V6.vmpyihb.acc
    hexagon_V6_vmpyihb_acc_128B,               // llvm.hexagon.V6.vmpyihb.acc.128B
    hexagon_V6_vmpyiowh,                       // llvm.hexagon.V6.vmpyiowh
    hexagon_V6_vmpyiowh_128B,                  // llvm.hexagon.V6.vmpyiowh.128B
    hexagon_V6_vmpyiwb,                        // llvm.hexagon.V6.vmpyiwb
    hexagon_V6_vmpyiwb_128B,                   // llvm.hexagon.V6.vmpyiwb.128B
    hexagon_V6_vmpyiwb_acc,                    // llvm.hexagon.V6.vmpyiwb.acc
    hexagon_V6_vmpyiwb_acc_128B,               // llvm.hexagon.V6.vmpyiwb.acc.128B
    hexagon_V6_vmpyiwh,                        // llvm.hexagon.V6.vmpyiwh
    hexagon_V6_vmpyiwh_128B,                   // llvm.hexagon.V6.vmpyiwh.128B
    hexagon_V6_vmpyiwh_acc,                    // llvm.hexagon.V6.vmpyiwh.acc
    hexagon_V6_vmpyiwh_acc_128B,               // llvm.hexagon.V6.vmpyiwh.acc.128B
    hexagon_V6_vmpyiwub,                       // llvm.hexagon.V6.vmpyiwub
    hexagon_V6_vmpyiwub_128B,                  // llvm.hexagon.V6.vmpyiwub.128B
    hexagon_V6_vmpyiwub_acc,                   // llvm.hexagon.V6.vmpyiwub.acc
    hexagon_V6_vmpyiwub_acc_128B,              // llvm.hexagon.V6.vmpyiwub.acc.128B
    hexagon_V6_vmpyowh,                        // llvm.hexagon.V6.vmpyowh
    hexagon_V6_vmpyowh_128B,                   // llvm.hexagon.V6.vmpyowh.128B
    hexagon_V6_vmpyowh_64_acc,                 // llvm.hexagon.V6.vmpyowh.64.acc
    hexagon_V6_vmpyowh_64_acc_128B,            // llvm.hexagon.V6.vmpyowh.64.acc.128B
    hexagon_V6_vmpyowh_rnd,                    // llvm.hexagon.V6.vmpyowh.rnd
    hexagon_V6_vmpyowh_rnd_128B,               // llvm.hexagon.V6.vmpyowh.rnd.128B
    hexagon_V6_vmpyowh_rnd_sacc,               // llvm.hexagon.V6.vmpyowh.rnd.sacc
    hexagon_V6_vmpyowh_rnd_sacc_128B,          // llvm.hexagon.V6.vmpyowh.rnd.sacc.128B
    hexagon_V6_vmpyowh_sacc,                   // llvm.hexagon.V6.vmpyowh.sacc
    hexagon_V6_vmpyowh_sacc_128B,              // llvm.hexagon.V6.vmpyowh.sacc.128B
    hexagon_V6_vmpyss_parts,                   // llvm.hexagon.V6.vmpyss.parts
    hexagon_V6_vmpyss_parts_128B,              // llvm.hexagon.V6.vmpyss.parts.128B
    hexagon_V6_vmpyub,                         // llvm.hexagon.V6.vmpyub
    hexagon_V6_vmpyub_128B,                    // llvm.hexagon.V6.vmpyub.128B
    hexagon_V6_vmpyub_acc,                     // llvm.hexagon.V6.vmpyub.acc
    hexagon_V6_vmpyub_acc_128B,                // llvm.hexagon.V6.vmpyub.acc.128B
    hexagon_V6_vmpyubv,                        // llvm.hexagon.V6.vmpyubv
    hexagon_V6_vmpyubv_128B,                   // llvm.hexagon.V6.vmpyubv.128B
    hexagon_V6_vmpyubv_acc,                    // llvm.hexagon.V6.vmpyubv.acc
    hexagon_V6_vmpyubv_acc_128B,               // llvm.hexagon.V6.vmpyubv.acc.128B
    hexagon_V6_vmpyuh,                         // llvm.hexagon.V6.vmpyuh
    hexagon_V6_vmpyuh_128B,                    // llvm.hexagon.V6.vmpyuh.128B
    hexagon_V6_vmpyuh_acc,                     // llvm.hexagon.V6.vmpyuh.acc
    hexagon_V6_vmpyuh_acc_128B,                // llvm.hexagon.V6.vmpyuh.acc.128B
    hexagon_V6_vmpyuhe,                        // llvm.hexagon.V6.vmpyuhe
    hexagon_V6_vmpyuhe_128B,                   // llvm.hexagon.V6.vmpyuhe.128B
    hexagon_V6_vmpyuhe_acc,                    // llvm.hexagon.V6.vmpyuhe.acc
    hexagon_V6_vmpyuhe_acc_128B,               // llvm.hexagon.V6.vmpyuhe.acc.128B
    hexagon_V6_vmpyuhv,                        // llvm.hexagon.V6.vmpyuhv
    hexagon_V6_vmpyuhv_128B,                   // llvm.hexagon.V6.vmpyuhv.128B
    hexagon_V6_vmpyuhv_acc,                    // llvm.hexagon.V6.vmpyuhv.acc
    hexagon_V6_vmpyuhv_acc_128B,               // llvm.hexagon.V6.vmpyuhv.acc.128B
    hexagon_V6_vmpyuhvs,                       // llvm.hexagon.V6.vmpyuhvs
    hexagon_V6_vmpyuhvs_128B,                  // llvm.hexagon.V6.vmpyuhvs.128B
    hexagon_V6_vmpyus_parts,                   // llvm.hexagon.V6.vmpyus.parts
    hexagon_V6_vmpyus_parts_128B,              // llvm.hexagon.V6.vmpyus.parts.128B
    hexagon_V6_vmpyuu_parts,                   // llvm.hexagon.V6.vmpyuu.parts
    hexagon_V6_vmpyuu_parts_128B,              // llvm.hexagon.V6.vmpyuu.parts.128B
    hexagon_V6_vmux,                           // llvm.hexagon.V6.vmux
    hexagon_V6_vmux_128B,                      // llvm.hexagon.V6.vmux.128B
    hexagon_V6_vnavgb,                         // llvm.hexagon.V6.vnavgb
    hexagon_V6_vnavgb_128B,                    // llvm.hexagon.V6.vnavgb.128B
    hexagon_V6_vnavgh,                         // llvm.hexagon.V6.vnavgh
    hexagon_V6_vnavgh_128B,                    // llvm.hexagon.V6.vnavgh.128B
    hexagon_V6_vnavgub,                        // llvm.hexagon.V6.vnavgub
    hexagon_V6_vnavgub_128B,                   // llvm.hexagon.V6.vnavgub.128B
    hexagon_V6_vnavgw,                         // llvm.hexagon.V6.vnavgw
    hexagon_V6_vnavgw_128B,                    // llvm.hexagon.V6.vnavgw.128B
    hexagon_V6_vnormamth,                      // llvm.hexagon.V6.vnormamth
    hexagon_V6_vnormamth_128B,                 // llvm.hexagon.V6.vnormamth.128B
    hexagon_V6_vnormamtw,                      // llvm.hexagon.V6.vnormamtw
    hexagon_V6_vnormamtw_128B,                 // llvm.hexagon.V6.vnormamtw.128B
    hexagon_V6_vnot,                           // llvm.hexagon.V6.vnot
    hexagon_V6_vnot_128B,                      // llvm.hexagon.V6.vnot.128B
    hexagon_V6_vor,                            // llvm.hexagon.V6.vor
    hexagon_V6_vor_128B,                       // llvm.hexagon.V6.vor.128B
    hexagon_V6_vpackeb,                        // llvm.hexagon.V6.vpackeb
    hexagon_V6_vpackeb_128B,                   // llvm.hexagon.V6.vpackeb.128B
    hexagon_V6_vpackeh,                        // llvm.hexagon.V6.vpackeh
    hexagon_V6_vpackeh_128B,                   // llvm.hexagon.V6.vpackeh.128B
    hexagon_V6_vpackhb_sat,                    // llvm.hexagon.V6.vpackhb.sat
    hexagon_V6_vpackhb_sat_128B,               // llvm.hexagon.V6.vpackhb.sat.128B
    hexagon_V6_vpackhub_sat,                   // llvm.hexagon.V6.vpackhub.sat
    hexagon_V6_vpackhub_sat_128B,              // llvm.hexagon.V6.vpackhub.sat.128B
    hexagon_V6_vpackob,                        // llvm.hexagon.V6.vpackob
    hexagon_V6_vpackob_128B,                   // llvm.hexagon.V6.vpackob.128B
    hexagon_V6_vpackoh,                        // llvm.hexagon.V6.vpackoh
    hexagon_V6_vpackoh_128B,                   // llvm.hexagon.V6.vpackoh.128B
    hexagon_V6_vpackwh_sat,                    // llvm.hexagon.V6.vpackwh.sat
    hexagon_V6_vpackwh_sat_128B,               // llvm.hexagon.V6.vpackwh.sat.128B
    hexagon_V6_vpackwuh_sat,                   // llvm.hexagon.V6.vpackwuh.sat
    hexagon_V6_vpackwuh_sat_128B,              // llvm.hexagon.V6.vpackwuh.sat.128B
    hexagon_V6_vpopcounth,                     // llvm.hexagon.V6.vpopcounth
    hexagon_V6_vpopcounth_128B,                // llvm.hexagon.V6.vpopcounth.128B
    hexagon_V6_vprefixqb,                      // llvm.hexagon.V6.vprefixqb
    hexagon_V6_vprefixqb_128B,                 // llvm.hexagon.V6.vprefixqb.128B
    hexagon_V6_vprefixqh,                      // llvm.hexagon.V6.vprefixqh
    hexagon_V6_vprefixqh_128B,                 // llvm.hexagon.V6.vprefixqh.128B
    hexagon_V6_vprefixqw,                      // llvm.hexagon.V6.vprefixqw
    hexagon_V6_vprefixqw_128B,                 // llvm.hexagon.V6.vprefixqw.128B
    hexagon_V6_vrdelta,                        // llvm.hexagon.V6.vrdelta
    hexagon_V6_vrdelta_128B,                   // llvm.hexagon.V6.vrdelta.128B
    hexagon_V6_vrmpybub_rtt,                   // llvm.hexagon.V6.vrmpybub.rtt
    hexagon_V6_vrmpybub_rtt_128B,              // llvm.hexagon.V6.vrmpybub.rtt.128B
    hexagon_V6_vrmpybub_rtt_acc,               // llvm.hexagon.V6.vrmpybub.rtt.acc
    hexagon_V6_vrmpybub_rtt_acc_128B,          // llvm.hexagon.V6.vrmpybub.rtt.acc.128B
    hexagon_V6_vrmpybus,                       // llvm.hexagon.V6.vrmpybus
    hexagon_V6_vrmpybus_128B,                  // llvm.hexagon.V6.vrmpybus.128B
    hexagon_V6_vrmpybus_acc,                   // llvm.hexagon.V6.vrmpybus.acc
    hexagon_V6_vrmpybus_acc_128B,              // llvm.hexagon.V6.vrmpybus.acc.128B
    hexagon_V6_vrmpybusi,                      // llvm.hexagon.V6.vrmpybusi
    hexagon_V6_vrmpybusi_128B,                 // llvm.hexagon.V6.vrmpybusi.128B
    hexagon_V6_vrmpybusi_acc,                  // llvm.hexagon.V6.vrmpybusi.acc
    hexagon_V6_vrmpybusi_acc_128B,             // llvm.hexagon.V6.vrmpybusi.acc.128B
    hexagon_V6_vrmpybusv,                      // llvm.hexagon.V6.vrmpybusv
    hexagon_V6_vrmpybusv_128B,                 // llvm.hexagon.V6.vrmpybusv.128B
    hexagon_V6_vrmpybusv_acc,                  // llvm.hexagon.V6.vrmpybusv.acc
    hexagon_V6_vrmpybusv_acc_128B,             // llvm.hexagon.V6.vrmpybusv.acc.128B
    hexagon_V6_vrmpybv,                        // llvm.hexagon.V6.vrmpybv
    hexagon_V6_vrmpybv_128B,                   // llvm.hexagon.V6.vrmpybv.128B
    hexagon_V6_vrmpybv_acc,                    // llvm.hexagon.V6.vrmpybv.acc
    hexagon_V6_vrmpybv_acc_128B,               // llvm.hexagon.V6.vrmpybv.acc.128B
    hexagon_V6_vrmpyub,                        // llvm.hexagon.V6.vrmpyub
    hexagon_V6_vrmpyub_128B,                   // llvm.hexagon.V6.vrmpyub.128B
    hexagon_V6_vrmpyub_acc,                    // llvm.hexagon.V6.vrmpyub.acc
    hexagon_V6_vrmpyub_acc_128B,               // llvm.hexagon.V6.vrmpyub.acc.128B
    hexagon_V6_vrmpyub_rtt,                    // llvm.hexagon.V6.vrmpyub.rtt
    hexagon_V6_vrmpyub_rtt_128B,               // llvm.hexagon.V6.vrmpyub.rtt.128B
    hexagon_V6_vrmpyub_rtt_acc,                // llvm.hexagon.V6.vrmpyub.rtt.acc
    hexagon_V6_vrmpyub_rtt_acc_128B,           // llvm.hexagon.V6.vrmpyub.rtt.acc.128B
    hexagon_V6_vrmpyubi,                       // llvm.hexagon.V6.vrmpyubi
    hexagon_V6_vrmpyubi_128B,                  // llvm.hexagon.V6.vrmpyubi.128B
    hexagon_V6_vrmpyubi_acc,                   // llvm.hexagon.V6.vrmpyubi.acc
    hexagon_V6_vrmpyubi_acc_128B,              // llvm.hexagon.V6.vrmpyubi.acc.128B
    hexagon_V6_vrmpyubv,                       // llvm.hexagon.V6.vrmpyubv
    hexagon_V6_vrmpyubv_128B,                  // llvm.hexagon.V6.vrmpyubv.128B
    hexagon_V6_vrmpyubv_acc,                   // llvm.hexagon.V6.vrmpyubv.acc
    hexagon_V6_vrmpyubv_acc_128B,              // llvm.hexagon.V6.vrmpyubv.acc.128B
    hexagon_V6_vror,                           // llvm.hexagon.V6.vror
    hexagon_V6_vror_128B,                      // llvm.hexagon.V6.vror.128B
    hexagon_V6_vrotr,                          // llvm.hexagon.V6.vrotr
    hexagon_V6_vrotr_128B,                     // llvm.hexagon.V6.vrotr.128B
    hexagon_V6_vroundhb,                       // llvm.hexagon.V6.vroundhb
    hexagon_V6_vroundhb_128B,                  // llvm.hexagon.V6.vroundhb.128B
    hexagon_V6_vroundhub,                      // llvm.hexagon.V6.vroundhub
    hexagon_V6_vroundhub_128B,                 // llvm.hexagon.V6.vroundhub.128B
    hexagon_V6_vrounduhub,                     // llvm.hexagon.V6.vrounduhub
    hexagon_V6_vrounduhub_128B,                // llvm.hexagon.V6.vrounduhub.128B
    hexagon_V6_vrounduwuh,                     // llvm.hexagon.V6.vrounduwuh
    hexagon_V6_vrounduwuh_128B,                // llvm.hexagon.V6.vrounduwuh.128B
    hexagon_V6_vroundwh,                       // llvm.hexagon.V6.vroundwh
    hexagon_V6_vroundwh_128B,                  // llvm.hexagon.V6.vroundwh.128B
    hexagon_V6_vroundwuh,                      // llvm.hexagon.V6.vroundwuh
    hexagon_V6_vroundwuh_128B,                 // llvm.hexagon.V6.vroundwuh.128B
    hexagon_V6_vrsadubi,                       // llvm.hexagon.V6.vrsadubi
    hexagon_V6_vrsadubi_128B,                  // llvm.hexagon.V6.vrsadubi.128B
    hexagon_V6_vrsadubi_acc,                   // llvm.hexagon.V6.vrsadubi.acc
    hexagon_V6_vrsadubi_acc_128B,              // llvm.hexagon.V6.vrsadubi.acc.128B
    hexagon_V6_vsatdw,                         // llvm.hexagon.V6.vsatdw
    hexagon_V6_vsatdw_128B,                    // llvm.hexagon.V6.vsatdw.128B
    hexagon_V6_vsathub,                        // llvm.hexagon.V6.vsathub
    hexagon_V6_vsathub_128B,                   // llvm.hexagon.V6.vsathub.128B
    hexagon_V6_vsatuwuh,                       // llvm.hexagon.V6.vsatuwuh
    hexagon_V6_vsatuwuh_128B,                  // llvm.hexagon.V6.vsatuwuh.128B
    hexagon_V6_vsatwh,                         // llvm.hexagon.V6.vsatwh
    hexagon_V6_vsatwh_128B,                    // llvm.hexagon.V6.vsatwh.128B
    hexagon_V6_vsb,                            // llvm.hexagon.V6.vsb
    hexagon_V6_vsb_128B,                       // llvm.hexagon.V6.vsb.128B
    hexagon_V6_vscattermh,                     // llvm.hexagon.V6.vscattermh
    hexagon_V6_vscattermh_128B,                // llvm.hexagon.V6.vscattermh.128B
    hexagon_V6_vscattermh_add,                 // llvm.hexagon.V6.vscattermh.add
    hexagon_V6_vscattermh_add_128B,            // llvm.hexagon.V6.vscattermh.add.128B
    hexagon_V6_vscattermhq,                    // llvm.hexagon.V6.vscattermhq
    hexagon_V6_vscattermhq_128B,               // llvm.hexagon.V6.vscattermhq.128B
    hexagon_V6_vscattermhw,                    // llvm.hexagon.V6.vscattermhw
    hexagon_V6_vscattermhw_128B,               // llvm.hexagon.V6.vscattermhw.128B
    hexagon_V6_vscattermhw_add,                // llvm.hexagon.V6.vscattermhw.add
    hexagon_V6_vscattermhw_add_128B,           // llvm.hexagon.V6.vscattermhw.add.128B
    hexagon_V6_vscattermhwq,                   // llvm.hexagon.V6.vscattermhwq
    hexagon_V6_vscattermhwq_128B,              // llvm.hexagon.V6.vscattermhwq.128B
    hexagon_V6_vscattermw,                     // llvm.hexagon.V6.vscattermw
    hexagon_V6_vscattermw_128B,                // llvm.hexagon.V6.vscattermw.128B
    hexagon_V6_vscattermw_add,                 // llvm.hexagon.V6.vscattermw.add
    hexagon_V6_vscattermw_add_128B,            // llvm.hexagon.V6.vscattermw.add.128B
    hexagon_V6_vscattermwq,                    // llvm.hexagon.V6.vscattermwq
    hexagon_V6_vscattermwq_128B,               // llvm.hexagon.V6.vscattermwq.128B
    hexagon_V6_vsh,                            // llvm.hexagon.V6.vsh
    hexagon_V6_vsh_128B,                       // llvm.hexagon.V6.vsh.128B
    hexagon_V6_vshufeh,                        // llvm.hexagon.V6.vshufeh
    hexagon_V6_vshufeh_128B,                   // llvm.hexagon.V6.vshufeh.128B
    hexagon_V6_vshuffb,                        // llvm.hexagon.V6.vshuffb
    hexagon_V6_vshuffb_128B,                   // llvm.hexagon.V6.vshuffb.128B
    hexagon_V6_vshuffeb,                       // llvm.hexagon.V6.vshuffeb
    hexagon_V6_vshuffeb_128B,                  // llvm.hexagon.V6.vshuffeb.128B
    hexagon_V6_vshuffh,                        // llvm.hexagon.V6.vshuffh
    hexagon_V6_vshuffh_128B,                   // llvm.hexagon.V6.vshuffh.128B
    hexagon_V6_vshuffob,                       // llvm.hexagon.V6.vshuffob
    hexagon_V6_vshuffob_128B,                  // llvm.hexagon.V6.vshuffob.128B
    hexagon_V6_vshuffvdd,                      // llvm.hexagon.V6.vshuffvdd
    hexagon_V6_vshuffvdd_128B,                 // llvm.hexagon.V6.vshuffvdd.128B
    hexagon_V6_vshufoeb,                       // llvm.hexagon.V6.vshufoeb
    hexagon_V6_vshufoeb_128B,                  // llvm.hexagon.V6.vshufoeb.128B
    hexagon_V6_vshufoeh,                       // llvm.hexagon.V6.vshufoeh
    hexagon_V6_vshufoeh_128B,                  // llvm.hexagon.V6.vshufoeh.128B
    hexagon_V6_vshufoh,                        // llvm.hexagon.V6.vshufoh
    hexagon_V6_vshufoh_128B,                   // llvm.hexagon.V6.vshufoh.128B
    hexagon_V6_vsub_hf,                        // llvm.hexagon.V6.vsub.hf
    hexagon_V6_vsub_hf_128B,                   // llvm.hexagon.V6.vsub.hf.128B
    hexagon_V6_vsub_hf_f8,                     // llvm.hexagon.V6.vsub.hf.f8
    hexagon_V6_vsub_hf_f8_128B,                // llvm.hexagon.V6.vsub.hf.f8.128B
    hexagon_V6_vsub_hf_hf,                     // llvm.hexagon.V6.vsub.hf.hf
    hexagon_V6_vsub_hf_hf_128B,                // llvm.hexagon.V6.vsub.hf.hf.128B
    hexagon_V6_vsub_qf16,                      // llvm.hexagon.V6.vsub.qf16
    hexagon_V6_vsub_qf16_128B,                 // llvm.hexagon.V6.vsub.qf16.128B
    hexagon_V6_vsub_qf16_mix,                  // llvm.hexagon.V6.vsub.qf16.mix
    hexagon_V6_vsub_qf16_mix_128B,             // llvm.hexagon.V6.vsub.qf16.mix.128B
    hexagon_V6_vsub_qf32,                      // llvm.hexagon.V6.vsub.qf32
    hexagon_V6_vsub_qf32_128B,                 // llvm.hexagon.V6.vsub.qf32.128B
    hexagon_V6_vsub_qf32_mix,                  // llvm.hexagon.V6.vsub.qf32.mix
    hexagon_V6_vsub_qf32_mix_128B,             // llvm.hexagon.V6.vsub.qf32.mix.128B
    hexagon_V6_vsub_sf,                        // llvm.hexagon.V6.vsub.sf
    hexagon_V6_vsub_sf_128B,                   // llvm.hexagon.V6.vsub.sf.128B
    hexagon_V6_vsub_sf_bf,                     // llvm.hexagon.V6.vsub.sf.bf
    hexagon_V6_vsub_sf_bf_128B,                // llvm.hexagon.V6.vsub.sf.bf.128B
    hexagon_V6_vsub_sf_hf,                     // llvm.hexagon.V6.vsub.sf.hf
    hexagon_V6_vsub_sf_hf_128B,                // llvm.hexagon.V6.vsub.sf.hf.128B
    hexagon_V6_vsub_sf_sf,                     // llvm.hexagon.V6.vsub.sf.sf
    hexagon_V6_vsub_sf_sf_128B,                // llvm.hexagon.V6.vsub.sf.sf.128B
    hexagon_V6_vsubb,                          // llvm.hexagon.V6.vsubb
    hexagon_V6_vsubb_128B,                     // llvm.hexagon.V6.vsubb.128B
    hexagon_V6_vsubb_dv,                       // llvm.hexagon.V6.vsubb.dv
    hexagon_V6_vsubb_dv_128B,                  // llvm.hexagon.V6.vsubb.dv.128B
    hexagon_V6_vsubbnq,                        // llvm.hexagon.V6.vsubbnq
    hexagon_V6_vsubbnq_128B,                   // llvm.hexagon.V6.vsubbnq.128B
    hexagon_V6_vsubbq,                         // llvm.hexagon.V6.vsubbq
    hexagon_V6_vsubbq_128B,                    // llvm.hexagon.V6.vsubbq.128B
    hexagon_V6_vsubbsat,                       // llvm.hexagon.V6.vsubbsat
    hexagon_V6_vsubbsat_128B,                  // llvm.hexagon.V6.vsubbsat.128B
    hexagon_V6_vsubbsat_dv,                    // llvm.hexagon.V6.vsubbsat.dv
    hexagon_V6_vsubbsat_dv_128B,               // llvm.hexagon.V6.vsubbsat.dv.128B
    hexagon_V6_vsubcarry,                      // llvm.hexagon.V6.vsubcarry
    hexagon_V6_vsubcarry_128B,                 // llvm.hexagon.V6.vsubcarry.128B
    hexagon_V6_vsubcarryo,                     // llvm.hexagon.V6.vsubcarryo
    hexagon_V6_vsubcarryo_128B,                // llvm.hexagon.V6.vsubcarryo.128B
    hexagon_V6_vsubh,                          // llvm.hexagon.V6.vsubh
    hexagon_V6_vsubh_128B,                     // llvm.hexagon.V6.vsubh.128B
    hexagon_V6_vsubh_dv,                       // llvm.hexagon.V6.vsubh.dv
    hexagon_V6_vsubh_dv_128B,                  // llvm.hexagon.V6.vsubh.dv.128B
    hexagon_V6_vsubhnq,                        // llvm.hexagon.V6.vsubhnq
    hexagon_V6_vsubhnq_128B,                   // llvm.hexagon.V6.vsubhnq.128B
    hexagon_V6_vsubhq,                         // llvm.hexagon.V6.vsubhq
    hexagon_V6_vsubhq_128B,                    // llvm.hexagon.V6.vsubhq.128B
    hexagon_V6_vsubhsat,                       // llvm.hexagon.V6.vsubhsat
    hexagon_V6_vsubhsat_128B,                  // llvm.hexagon.V6.vsubhsat.128B
    hexagon_V6_vsubhsat_dv,                    // llvm.hexagon.V6.vsubhsat.dv
    hexagon_V6_vsubhsat_dv_128B,               // llvm.hexagon.V6.vsubhsat.dv.128B
    hexagon_V6_vsubhw,                         // llvm.hexagon.V6.vsubhw
    hexagon_V6_vsubhw_128B,                    // llvm.hexagon.V6.vsubhw.128B
    hexagon_V6_vsububh,                        // llvm.hexagon.V6.vsububh
    hexagon_V6_vsububh_128B,                   // llvm.hexagon.V6.vsububh.128B
    hexagon_V6_vsububsat,                      // llvm.hexagon.V6.vsububsat
    hexagon_V6_vsububsat_128B,                 // llvm.hexagon.V6.vsububsat.128B
    hexagon_V6_vsububsat_dv,                   // llvm.hexagon.V6.vsububsat.dv
    hexagon_V6_vsububsat_dv_128B,              // llvm.hexagon.V6.vsububsat.dv.128B
    hexagon_V6_vsubububb_sat,                  // llvm.hexagon.V6.vsubububb.sat
    hexagon_V6_vsubububb_sat_128B,             // llvm.hexagon.V6.vsubububb.sat.128B
    hexagon_V6_vsubuhsat,                      // llvm.hexagon.V6.vsubuhsat
    hexagon_V6_vsubuhsat_128B,                 // llvm.hexagon.V6.vsubuhsat.128B
    hexagon_V6_vsubuhsat_dv,                   // llvm.hexagon.V6.vsubuhsat.dv
    hexagon_V6_vsubuhsat_dv_128B,              // llvm.hexagon.V6.vsubuhsat.dv.128B
    hexagon_V6_vsubuhw,                        // llvm.hexagon.V6.vsubuhw
    hexagon_V6_vsubuhw_128B,                   // llvm.hexagon.V6.vsubuhw.128B
    hexagon_V6_vsubuwsat,                      // llvm.hexagon.V6.vsubuwsat
    hexagon_V6_vsubuwsat_128B,                 // llvm.hexagon.V6.vsubuwsat.128B
    hexagon_V6_vsubuwsat_dv,                   // llvm.hexagon.V6.vsubuwsat.dv
    hexagon_V6_vsubuwsat_dv_128B,              // llvm.hexagon.V6.vsubuwsat.dv.128B
    hexagon_V6_vsubw,                          // llvm.hexagon.V6.vsubw
    hexagon_V6_vsubw_128B,                     // llvm.hexagon.V6.vsubw.128B
    hexagon_V6_vsubw_dv,                       // llvm.hexagon.V6.vsubw.dv
    hexagon_V6_vsubw_dv_128B,                  // llvm.hexagon.V6.vsubw.dv.128B
    hexagon_V6_vsubwnq,                        // llvm.hexagon.V6.vsubwnq
    hexagon_V6_vsubwnq_128B,                   // llvm.hexagon.V6.vsubwnq.128B
    hexagon_V6_vsubwq,                         // llvm.hexagon.V6.vsubwq
    hexagon_V6_vsubwq_128B,                    // llvm.hexagon.V6.vsubwq.128B
    hexagon_V6_vsubwsat,                       // llvm.hexagon.V6.vsubwsat
    hexagon_V6_vsubwsat_128B,                  // llvm.hexagon.V6.vsubwsat.128B
    hexagon_V6_vsubwsat_dv,                    // llvm.hexagon.V6.vsubwsat.dv
    hexagon_V6_vsubwsat_dv_128B,               // llvm.hexagon.V6.vsubwsat.dv.128B
    hexagon_V6_vswap,                          // llvm.hexagon.V6.vswap
    hexagon_V6_vswap_128B,                     // llvm.hexagon.V6.vswap.128B
    hexagon_V6_vtmpyb,                         // llvm.hexagon.V6.vtmpyb
    hexagon_V6_vtmpyb_128B,                    // llvm.hexagon.V6.vtmpyb.128B
    hexagon_V6_vtmpyb_acc,                     // llvm.hexagon.V6.vtmpyb.acc
    hexagon_V6_vtmpyb_acc_128B,                // llvm.hexagon.V6.vtmpyb.acc.128B
    hexagon_V6_vtmpybus,                       // llvm.hexagon.V6.vtmpybus
    hexagon_V6_vtmpybus_128B,                  // llvm.hexagon.V6.vtmpybus.128B
    hexagon_V6_vtmpybus_acc,                   // llvm.hexagon.V6.vtmpybus.acc
    hexagon_V6_vtmpybus_acc_128B,              // llvm.hexagon.V6.vtmpybus.acc.128B
    hexagon_V6_vtmpyhb,                        // llvm.hexagon.V6.vtmpyhb
    hexagon_V6_vtmpyhb_128B,                   // llvm.hexagon.V6.vtmpyhb.128B
    hexagon_V6_vtmpyhb_acc,                    // llvm.hexagon.V6.vtmpyhb.acc
    hexagon_V6_vtmpyhb_acc_128B,               // llvm.hexagon.V6.vtmpyhb.acc.128B
    hexagon_V6_vunpackb,                       // llvm.hexagon.V6.vunpackb
    hexagon_V6_vunpackb_128B,                  // llvm.hexagon.V6.vunpackb.128B
    hexagon_V6_vunpackh,                       // llvm.hexagon.V6.vunpackh
    hexagon_V6_vunpackh_128B,                  // llvm.hexagon.V6.vunpackh.128B
    hexagon_V6_vunpackob,                      // llvm.hexagon.V6.vunpackob
    hexagon_V6_vunpackob_128B,                 // llvm.hexagon.V6.vunpackob.128B
    hexagon_V6_vunpackoh,                      // llvm.hexagon.V6.vunpackoh
    hexagon_V6_vunpackoh_128B,                 // llvm.hexagon.V6.vunpackoh.128B
    hexagon_V6_vunpackub,                      // llvm.hexagon.V6.vunpackub
    hexagon_V6_vunpackub_128B,                 // llvm.hexagon.V6.vunpackub.128B
    hexagon_V6_vunpackuh,                      // llvm.hexagon.V6.vunpackuh
    hexagon_V6_vunpackuh_128B,                 // llvm.hexagon.V6.vunpackuh.128B
    hexagon_V6_vxor,                           // llvm.hexagon.V6.vxor
    hexagon_V6_vxor_128B,                      // llvm.hexagon.V6.vxor.128B
    hexagon_V6_vzb,                            // llvm.hexagon.V6.vzb
    hexagon_V6_vzb_128B,                       // llvm.hexagon.V6.vzb.128B
    hexagon_V6_vzh,                            // llvm.hexagon.V6.vzh
    hexagon_V6_vzh_128B,                       // llvm.hexagon.V6.vzh.128B
    hexagon_Y2_dccleana,                       // llvm.hexagon.Y2.dccleana
    hexagon_Y2_dccleaninva,                    // llvm.hexagon.Y2.dccleaninva
    hexagon_Y2_dcfetch,                        // llvm.hexagon.Y2.dcfetch
    hexagon_Y2_dcinva,                         // llvm.hexagon.Y2.dcinva
    hexagon_Y2_dczeroa,                        // llvm.hexagon.Y2.dczeroa
    hexagon_Y4_l2fetch,                        // llvm.hexagon.Y4.l2fetch
    hexagon_Y5_l2fetch,                        // llvm.hexagon.Y5.l2fetch
    hexagon_Y6_dmlink,                         // llvm.hexagon.Y6.dmlink
    hexagon_Y6_dmpause,                        // llvm.hexagon.Y6.dmpause
    hexagon_Y6_dmpoll,                         // llvm.hexagon.Y6.dmpoll
    hexagon_Y6_dmresume,                       // llvm.hexagon.Y6.dmresume
    hexagon_Y6_dmstart,                        // llvm.hexagon.Y6.dmstart
    hexagon_Y6_dmwait,                         // llvm.hexagon.Y6.dmwait
    hexagon_circ_ldb,                          // llvm.hexagon.circ.ldb
    hexagon_circ_ldd,                          // llvm.hexagon.circ.ldd
    hexagon_circ_ldh,                          // llvm.hexagon.circ.ldh
    hexagon_circ_ldub,                         // llvm.hexagon.circ.ldub
    hexagon_circ_lduh,                         // llvm.hexagon.circ.lduh
    hexagon_circ_ldw,                          // llvm.hexagon.circ.ldw
    hexagon_circ_stb,                          // llvm.hexagon.circ.stb
    hexagon_circ_std,                          // llvm.hexagon.circ.std
    hexagon_circ_sth,                          // llvm.hexagon.circ.sth
    hexagon_circ_sthhi,                        // llvm.hexagon.circ.sthhi
    hexagon_circ_stw,                          // llvm.hexagon.circ.stw
    hexagon_instrprof_custom,                  // llvm.hexagon.instrprof.custom
    hexagon_prefetch,                          // llvm.hexagon.prefetch
    hexagon_vmemcpy,                           // llvm.hexagon.vmemcpy
    hexagon_vmemset,                           // llvm.hexagon.vmemset
}; // enum
} // namespace llvm::Intrinsic
#endif

